import { Component, ViewChild, AfterViewInit } from '@angular/core';
import { ScrollPanel } from 'primeng/primeng';
import { Router, ActivatedRoute, RouterOutlet } from '@angular/router';
import { horizontalSlideAnimation, verticalSlideAnimation, stepAnimation } from './animations';
import { SwUpdate } from '@angular/service-worker';

@Component({
    selector: 'app-root',
    templateUrl: './app.component.html',
    styleUrls: ['./app.component.scss'],
    animations: [
        horizontalSlideAnimation,
        stepAnimation,
        verticalSlideAnimation
    ]
})
export class AppComponent implements AfterViewInit{

    menuMode = 'static';

    topbarMenuActive: boolean;

    overlayMenuActive: boolean;

    staticMenuDesktopInactive: boolean;

    staticMenuMobileActive: boolean;

    layoutMenuScroller: HTMLDivElement;

    menuClick: boolean;

    topbarItemClick: boolean;

    activeTopbarItem: any;

    resetMenu: boolean;

    menuHoverActive: boolean;

    rightPanelActive: boolean;

    rightPanelClick: boolean;

    topbarIconsActive: boolean;

    quickMenuButtonClick: boolean;

    @ViewChild('layoutMenuScroller') layoutMenuScrollerViewChild: ScrollPanel;

    ngAfterViewInit() {
        setTimeout(() => {
            if (this.layoutMenuScrollerViewChild != null) {
                this.layoutMenuScrollerViewChild.moveBar();
            }
        }, 100);

    }

    onLayoutClick() {
        if (!this.topbarItemClick) {
            this.activeTopbarItem = null;
            this.topbarMenuActive = false;
        }

        if (!this.rightPanelClick) {
            this.rightPanelActive = false;
        }

        if (!this.quickMenuButtonClick) {
            this.quickMenuButtonClick = false;
            this.topbarIconsActive = false;
        }

        if (!this.menuClick) {
            if (this.isHorizontal() || this.isSlim()) {
                this.resetMenu = true;
            }

            if (this.overlayMenuActive || this.staticMenuMobileActive) {
                this.hideOverlayMenu();
            }

            this.menuHoverActive = false;
        }

        this.topbarItemClick = false;
        this.quickMenuButtonClick = false;
        this.menuClick = false;
        this.rightPanelClick = false;
    }

    onMenuButtonClick(event) {
        this.menuClick = true;
        this.topbarMenuActive = false;

        if (this.isOverlay()) {
            this.overlayMenuActive = !this.overlayMenuActive;
        }
        if (this.isDesktop()) {
            this.staticMenuDesktopInactive = !this.staticMenuDesktopInactive;
        } else {
            this.staticMenuMobileActive = !this.staticMenuMobileActive;
        }

        event.preventDefault();
    }

    onQuickMenuButtonClick(event) {
        if (this.isMobile()) {
            this.topbarIconsActive = !this.topbarIconsActive;
            this.quickMenuButtonClick = true;
        }
        event.preventDefault();
    }

    onMenuClick() {
        this.menuClick = true;
        this.resetMenu = false;

        if (!this.isHorizontal()) {
            setTimeout(() => { this.layoutMenuScrollerViewChild.moveBar(); }, 500);
        }
    }

    onTopbarMenuButtonClick(event) {
        this.topbarItemClick = true;
        this.topbarMenuActive = !this.topbarMenuActive;

        this.hideOverlayMenu();

        event.preventDefault();
    }

    onTopbarItemClick(event, item) {
        this.topbarItemClick = true;

        if (this.activeTopbarItem === item) {
            this.activeTopbarItem = null;
        } else {
            this.activeTopbarItem = item;
        }

        event.preventDefault();
    }

    onTopbarSubItemClick(event) {
        event.preventDefault();
    }

    onRightPanelButtonClick(event) {
        this.rightPanelClick = true;
        this.rightPanelActive = !this.rightPanelActive;
        event.preventDefault();
    }

    onRightPanelClick() {
        this.rightPanelClick = true;
    }

    isHorizontal() {
        return this.menuMode === 'horizontal';
    }

    isSlim() {
        return this.menuMode === 'slim';
    }

    isOverlay() {
        return this.menuMode === 'overlay';
    }

    isStatic() {
        return this.menuMode === 'static';
    }

    isMobile() {
        return window.innerWidth < 1025;
    }

    isDesktop() {
        return window.innerWidth > 1024;
    }

    isTablet() {
        const width = window.innerWidth;
        return width <= 1024 && width > 640;
    }

    hideOverlayMenu() {
        this.overlayMenuActive = false;
        this.staticMenuMobileActive = false;
    }

    changeTheme(theme, style) {
        const layoutLink: HTMLLinkElement = <HTMLLinkElement>document.getElementById('layout-css');
        layoutLink.href = 'assets/layout/css/layout-' + theme + '.css';

        const themeLink: HTMLLinkElement = <HTMLLinkElement>document.getElementById('theme-css');

        if (style === 'color') {
            themeLink.href = 'assets/theme/' + theme + '/theme.css';
        }
        if (style === 'dark') {
            themeLink.href = 'assets/theme/' + theme + '/theme-dark.css';
        }
        if (style === 'light') {
            themeLink.href = 'assets/theme/' + theme + '/theme-light.css';
        }
    }

    constructor(
        updates: SwUpdate,
        private router: Router) {
        updates.available.subscribe(() => {
            updates.activateUpdate().then(() => {
                this.exibirDialog = true;
            });
        });
        
    }

    exibirDialog: boolean;
    loadingRequest: boolean;

    onHideDialog() {
        document.location.reload();
    }

    exibirTelaLogin() {
        return this.router.url === '/login';
    }

    exibirTelaAcessoNegado() {
        return this.router.url === '/acesso-negado';
    }

    exibirTelaPaginaNaoEncontrada() {
        return this.router.url === '/pagina-nao-encontrada';
    }

    exibirTelaRecuperarSenha() {
        return this.router.url === '/recuperar-senha';
    }

    getHorizontalState(outlet: RouterOutlet) {
        return outlet && outlet.activatedRouteData && outlet.activatedRouteData['animation'];
    }

    getStepAnimation(outlet: RouterOutlet) {
        return outlet && outlet.activatedRouteData && outlet.activatedRouteData['step'];
    }

    getVerticalState(outlet: RouterOutlet) {
        return outlet && outlet.activatedRouteData && outlet.activatedRouteData['menuIndex'];
    }

}
