import { NgModule, LOCALE_ID } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { HttpClientModule } from '@angular/common/http';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { LocationStrategy, PathLocationStrategy, HashLocationStrategy } from '@angular/common';
import { AppRoutes } from './app.routes';

import { BreadcrumbModule } from 'primeng/breadcrumb';
import { ButtonModule } from 'primeng/button';
import { CalendarModule } from 'primeng/calendar';
import { CheckboxModule } from 'primeng/checkbox';
import { DialogModule } from 'primeng/dialog';
import { FullCalendarModule } from 'primeng/fullcalendar';
import { InputTextModule } from 'primeng/inputtext';
import { InputTextareaModule } from 'primeng/inputtextarea';
import { PanelModule } from 'primeng/panel';
import { ScrollPanelModule } from 'primeng/scrollpanel';
import { TableModule } from 'primeng/table';
import { TabViewModule } from 'primeng/tabview';
import { ToastModule } from 'primeng/toast';

import { AppComponent } from './app.component';
import { AppRightPanelComponent } from './app.rightpanel.component';
import { AppMenuComponent, AppSubMenuComponent } from './app.menu.component';
import { AppTopBarComponent } from './app.topbar.component';
import { AppFooterComponent } from './app.footer.component';
import { AppBreadcrumbComponent } from './app.breadcrumb.component';
import { BreadcrumbService } from './breadcrumb.service';
import { ServiceWorkerModule, SwUpdate } from '@angular/service-worker';
import { environment } from '../environments/environment';
import { SegurancaModule } from './seguranca/seguranca.module';
import { InterceptorModule } from './seguranca/interceptor/interceptor.module';
import { JwtModule, JwtHelperService } from '@auth0/angular-jwt';

import { registerLocaleData } from '@angular/common';
import ptBr from '@angular/common/locales/pt';
import { OauthGuard } from './seguranca/oauth.guard';
import { MessageService, ConfirmationService } from 'primeng/api';
import { OauthService } from './seguranca/oauth.service';
import { ClientesModule } from './clientes/clientes.module';
import { UsuariosModule } from './usuarios/usuarios.module';
import { DashboardModule } from './dashboard/dashboard.module';
import { PessoasTModule } from './testes/pessoat/pessoast.module';
import { TimeModule } from './drdebug/time/time.module';
import { DueloDePontosModule } from './drdebug/dueloDePontos/dueloDePontos.module';
import { CampanhaModule } from './influenzer/campanha/campanha.module'
import { IpcModule } from './ipc/ipc.module';
import { GamepointsModule } from './gamepoints/gamepoints.module';
import { LocacoesModule } from './locacoes/locacoes.module';
import { DrdebugModule } from './drdebug/drdebug.module';
import { SoftwareModule } from './laboratory/software/software.module';
import { ProblemasModule } from './laboratory/problemas/problemas.module';
import { CompraModule } from './estoque/compras/compra.module';
import { ProdutoModule } from './estoque/produto/produto.module';
import {ContentModule} from './ipc/content/content/content.module';
import { MultiplaEscolhaModule } from './ipc/multiplaescolha/multiplaescolha.module';
import { ComputadoresModule } from './laboratory/computadores/computadores.module';
import { SolucaoModule } from './ipc/problemManager/Solucao/solucao.module';
import { CasoDeTesteModule } from './ipc/casodeteste/casodeteste.module';
import { MedalhaModule } from './gamepoints/medalha/medalha.module';
import { EnderesoModule } from './locacoes/endereso/endereso.module';
import { CompeticoesModule } from './ipc/competicao/competicoes.module';
import { CasosTestesModule } from './ipc/problemManager/casosTeste/casosTestes.module';
// import { PDFExportModule } from '@progress/kendo-angular-pdf-export';
import { LaboratoryModule } from './laboratory/laboratory.module';
import { AbertaModule } from './questao/aberta/aberta.module';


registerLocaleData(ptBr);

export function tokenGetter() {
    return localStorage.getItem('token');
}

@NgModule({
    imports: [
        BrowserModule,
        FormsModule,
        AppRoutes,
        HttpClientModule,
        BrowserAnimationsModule,
        ContentModule,

        BreadcrumbModule,
        ButtonModule,
        CalendarModule,
        CheckboxModule,
        DialogModule,
	    FullCalendarModule,
        InputTextModule,
        InputTextareaModule,
        PanelModule,
        ScrollPanelModule,
        TableModule,
        ToastModule,
        TabViewModule,
        CompeticoesModule,
        ServiceWorkerModule.register('ngsw-worker.js', { enabled: environment.production }),

        ClientesModule,
        DashboardModule,
        UsuariosModule,
        PessoasTModule,
        TimeModule,
        DueloDePontosModule,
        SolucaoModule,
        CampanhaModule,
        IpcModule,
        GamepointsModule,
        DrdebugModule,
        LocacoesModule,
        SoftwareModule,
        MedalhaModule,
        MultiplaEscolhaModule,
        EnderesoModule,
        DrdebugModule,
        ProblemasModule,
        CompeticoesModule,
        LaboratoryModule,
        CompraModule,
        ProdutoModule,
        ComputadoresModule,
        CasosTestesModule,
        CasoDeTesteModule,
        AbertaModule,
        //Módulos sempre Acima destes
        SegurancaModule,
        InterceptorModule,

        JwtModule.forRoot({
            config: {
                tokenGetter: tokenGetter,
                whitelistedDomains: environment.tokenWhitelistedDomains,
                blacklistedRoutes: environment.tokenBlacklistedRoutes,
                skipWhenExpired: false
            }
        }),

        // PDFExportModule,

    ],
    declarations: [
        AppComponent,
        AppMenuComponent,
        AppSubMenuComponent,
        AppTopBarComponent,
        AppFooterComponent,
        AppBreadcrumbComponent,
        AppRightPanelComponent
        
    ],
    providers: [
        { provide: LocationStrategy, useClass: PathLocationStrategy },
        { provide: LOCALE_ID, useValue: 'pt' },
        BreadcrumbService,
        MessageService,
        ConfirmationService,
        BreadcrumbService,
        JwtHelperService,
        OauthGuard,
        OauthService,
        SwUpdate
    ],
    bootstrap: [AppComponent]
})
export class AppModule { }
