import { Component, ViewChild, AfterViewInit, OnInit, OnChanges, Input, SimpleChanges, SimpleChange } from '@angular/core';
import { AppComponent } from './app.component';
import { ScrollPanel } from 'primeng/primeng';
import { OauthService } from './seguranca/oauth.service';
import { Router } from '@angular/router';
import { SwUpdate } from '@angular/service-worker';
import { ClientesService } from './clientes/clientes.service';
import { Cliente } from './clientes/cliente';

@Component({
    selector: 'app-rightpanel',
    templateUrl: './app.rightpanel.component.html'
})
export class AppRightPanelComponent implements AfterViewInit, OnInit, OnChanges {
  

    @ViewChild('scrollRightPanel') rightPanelMenuScrollerViewChild: ScrollPanel;

    versaoAtual: any;

    faturamento: number;
    calendarOptions: any;

    eventos: any[];

    @Input()
    nutricionista: string;
    dataAux: Date;
    tabIndex: number = 0;
    

    // Porcentagem da meta
    porcentagemMeta: number;
    valorMetaAtual: number;
    valormetaFinal: number;

    valorSalario: number;
    valorCustoFixo: number;
    valorCustoVariavel: number;

    // Cores nas bolas
    statusMeta: string;
    statusKilo: string;
    statusConsulta: string;

    // Mapa

    mostrarMapa: boolean = false;


    clientes: Cliente[];

    constructor(
        public app: AppComponent,
        updates: SwUpdate,
        private oauthService: OauthService,
        private router: Router,
        private clienteService: ClientesService,
    ) { 
        updates.activated.subscribe(event => {
            this.versaoAtual = event.current;
        });
    }
    ngOnInit() {
      
    }
    ngOnChanges(changes: SimpleChanges): void {
    
    }


    ngAfterViewInit() {
      setTimeout(() => { this.rightPanelMenuScrollerViewChild.moveBar(); }, 100);
    }

    onTabChange(event) {
        // this.recarregaMeta();
        setTimeout(() => { this.rightPanelMenuScrollerViewChild.moveBar(); }, 450);
    }

    logout() {
        this.oauthService.efetuarLogout();
        this.router.navigate(['/login']);
    }

    editarPerfil() {
        if (this.isAdministrador()) {
            this.router.navigate([`/administradores/${this.oauthService.jwtPayload.idUsuario}`])
        } else if (this.isCliente()) {
            this.router.navigate([`/clientes/${this.oauthService.jwtPayload.idUsuario}`])
        }
    }

    alterarSenha(){
        this.router.navigate([`alterar-senha/${this.oauthService.jwtPayload.idUsuario}`])
    }
    
    visualizarExtrato() {
        this.router.navigate([`/extrato/${this.oauthService.jwtPayload.idUsuario}`])
    }
    
    visualizarFinanceiro() {
        this.router.navigate([`/financeiro`])
    }

    isAdministrador() {
        return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
    }

    isCliente() {
        return this.oauthService.checkPermission('ROLE_CLIENTE');
    }
    verificaAtual(data: Date){
        let hoje = new Date();
        if(data.getFullYear() < hoje.getFullYear()){
          return false;
        } else if(data.getMonth() < hoje.getMonth()){
          return false;
        } else {
          return true;
        }
      }
    
      showMapa() {
        this.mostrarMapa = true;
        
      }
      getMes(mes:number){
        switch (mes) {
          case 0:
            return "Janeiro";
    
          case 1:
            return "Fevereiro";
          
          case 2:
            return "Março";
          
          case 3:
            return "Abril"; 
          
          case 4:
            return "Maio";
          
          case 5:
            return "Junho";
          
          case 6:
            return "Julho";
          
          case 7:
            return "Agosto";
          
          case 8:
            return "Setembro";
          
          case 9:
            return "Outubro";
          
          case 10:
            return "Novembro";
    
          case 11:
            return "Dezembro";
    
          default:
            break;
        }
      }
}
