import { Injectable } from '@angular/core';
import { Cliente } from './cliente';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { Observable } from 'rxjs';
import { Page } from '../utils/page';
import { map } from 'rxjs/operators';
import * as moment from 'moment';

@Injectable({
  providedIn: 'root'
})
export class ClientesService {

  httpOptions = {
    headers: new HttpHeaders({
      'Content-Type': 'application/json',
    })
  };

  url: string;
  clientes: Cliente[];
  idCount: number = 1;

  constructor(
    private http: HttpClient
  ) {
    this.url = `${environment.apiUrl}/pessoas`;
  }
  
  countClientesByEstados() {
    return this.http.get<any[]>(`${this.url}/informacoes/estados`);
  }

  countClientesByGenero() {
    return this.http.get<any[]>(`${this.url}/informacoes/generos`);
  }

  countClientesByComoConheceu() {
    return this.http.get<any[]>(`${this.url}/informacoes/como-conheceu`);
  }

  findById(id: number) {
    return this.http.get<Cliente>(`${this.url}/${id}`)
      .pipe(
        map((cliente: Cliente) => {
          const data = cliente.dadosPessoais.dataNascimento;
          cliente.dadosPessoais.dataNascimento = moment(data).toDate();
          return cliente;
        })
      );
    // return new Observable<Cliente>(
    //   (observer) => {
    //     observer.next(
    //       this.clientes.find(
    //         (cliente: Cliente) => {
    //           return cliente.idUsuario == id;
    //         }
    //       )
    //     )
    //   }
    // );
  }

  delete(id: number) {
    return this.http.delete<Cliente>(`${this.url}/${id}`);
    // return new Observable<Cliente>(
    //   (observer) => {
    //     const index = this.clientes.findIndex(
    //       (cliente: Cliente) => {
    //         return cliente.idUsuario == id;
    //       }
    //     );
    //     const cliente = this.clientes[index];
    //     this.clientes.splice(index, 1);
    //     observer.next(cliente)
    //   }
    // );
  }

  update(cliente: any, alterarSenha: boolean) {
    return this.http.put<Cliente>(`${this.url}/${cliente.idUsuario}?alterarSenha=${alterarSenha}`, cliente, this.httpOptions);
    // return new Observable<Cliente>(
    //   (observer) => {
    //     const index = this.clientes.findIndex(
    //       (elemento: Cliente) => {
    //         return elemento.idUsuario == cliente.idUsuario;
    //       }
    //     );
    //     this.clientes[index] = cliente;
    //     observer.next(cliente)
    //   }
    // );
  }

  insert(cliente: Cliente) {
    return this.http.post<Cliente>(this.url, cliente, this.httpOptions);
    // return new Observable<Cliente>(
    //   (observer) => {
    //     cliente.idUsuario = this.idCount++;
    //     this.clientes.push(cliente);
    //     observer.next(cliente)
    //   }
    // );
  }

  emailValidate(email: string) {
    return this.http.get<Cliente>(`${this.url}/validar-email/${email}`);
    // return new Observable<Cliente>(
    //   (observer) => {
    //     observer.next(
    //       this.clientes.find(
    //         (cliente: Cliente) => {
    //           return cliente.email == email;
    //         }
    //       )
    //     )
    //   }
    // );
  }
  loginValidate(login: string) {
    return this.http.get<Cliente>(`${this.url}/validar-login/${login}`);
    // return new Observable<Cliente>(
    //   (observer) => {
    //     observer.next(
    //       this.clientes.find(
    //         (cliente: Cliente) => {
    //           return cliente.login == login;
    //         }
    //       )
    //     )
    //   }
    // );
  }
  cpfValidate(cpf: string) {
    return this.http.get<Cliente>(`${this.url}/validar-cpf/${cpf}`);
  }
  
  findByCPF(cpf: string) {
    return this.http.get<Cliente>(`${this.url}/cpf/${cpf}`);
  }

  findByNome(nome: string, pagina: number) {
    return this.http.get<Page<Cliente>>(`${this.url}?nome=${nome}&pagina=${pagina}`);
  }
}
