import { Component, OnInit, Input, OnChanges, OnDestroy } from '@angular/core';
import * as moment from 'moment';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';
import { Cliente } from '../cliente';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ClientesService } from '../clientes.service';
import { listAnimation } from 'src/app/animations';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { MessageService } from 'primeng/api';
import { DadosPessoais } from '../dados-pessoais';
import { Reacordatorio } from '../reacordatorio';
import { Page } from 'src/app/utils/page';

declare var require: any;

@Component({
  selector: 'app-detalhes-cliente',
  templateUrl: './detalhes-cliente.component.html',
  styleUrls: ['./detalhes-cliente.component.css'],
  animations: [listAnimation]
})
export class DetalhesClienteComponent implements OnInit, OnChanges {

  dataAtual: Date;
  calendarLocale: any;
  cliente: Cliente;

  @Input('cliente') clienteInput: Cliente; // cliente quando utilizado por um componente externo

  dataNasc: string;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private clientesService: ClientesService,
    private activatedRoute: ActivatedRoute,
    private router: Router,
    private oauthService: OauthService,
  ) {
    this.cliente = new Cliente();

    const id = this.activatedRoute.snapshot.params['idCliente'];

    if (this.router.url.includes('/clientes')) {
      this.breadcrumbService.setItems([
        { label: 'Clientes', routerLink: ['/clientes'], visible: true },
        { label: 'Visualizar', routerLink: [`/clientes/${id}/detalhes`], visible: true }
      ]);
    }


    if (id) {
      this.clientesService.findById(id)
        .subscribe(
          (cliente: Cliente) => {
            if (cliente) {
              this.cliente = cliente;
              if (this.router.url.includes('/clientes')) {
                this.breadcrumbService.setItems([
                  { label: 'Clientes', routerLink: ['/clientes'], visible: true },
                  { label: this.cliente.nome, routerLink: [`/clientes/${id}`], visible: true },
                  { label: 'Detalhes', routerLink: [`/clientes/${id}/detalhes`], visible: true }
                ]);
              }

            } else {
              this.router.navigate(['/clientes']);
            }
          }
        )
    } else if (this.isAdministrador()) {
       //this.cliente = null;
    }


  }

  ngOnChanges() {
    if (this.clienteInput) {
      // prevencao de erros
      if (!this.clienteInput.dadosPessoais) {
        this.clienteInput.dadosPessoais = new DadosPessoais();
      }

      this.cliente = this.clienteInput;
    }
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  ngOnInit() {

    this.dataAtual = moment().toDate();
    this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
}
