import { Component, OnInit, OnDestroy, Input, OnChanges, Output, EventEmitter } from '@angular/core';
import { SelectItem, MessageService } from 'primeng/api';
import { FormBuilder, FormGroup, Validators, FormControl } from '@angular/forms';
import { EnderecoService } from '../endereco.service';
import { Endereco } from '../endereco';
import { Cidade } from '../cidade';
import { Observable } from 'rxjs';

declare var google: any; 

@Component({
  selector: 'app-cadastro-endereco',
  templateUrl: './cadastro-endereco.component.html',
  styleUrls: ['./cadastro-endereco.component.css']
})
export class CadastroEnderecoComponent implements OnInit, OnChanges {

  @Input() endereco: Endereco;
  @Input('obrigatorio') isObrigatorio: boolean;
  @Output() isEnderecoValido = new EventEmitter<boolean>();
  enderecoForm: FormGroup;
  estados: SelectItem[];
  cidades: SelectItem[];
  cepInformado: string;
  blockedPanel: boolean;
  cepInvalido: boolean = true;

  // Mapa
  options: any;
  overlays: any[];
  enderecoEncontrado: boolean;
  enderecoResposta: string;
  loading: boolean;
  latitude: number;
  longitude: number;

  dialogVisible: boolean;
  selectedPosition: any;
  infoWindow: any;

  constructor(
    private formBuilder: FormBuilder,
    private enderecoService: EnderecoService,
    private messageService: MessageService
  ) { 
    this.enderecoEncontrado = false;
    this.loading = true;
  }

  ngOnInit() {
    this.pesquisarEstados();

    this.configurarFormulario();
    if (this.endereco.cep) {
      this.pesquisarEndereco();
      this.cepInvalido = false;
    }

    this.enderecoForm.valueChanges.subscribe(
      (observer) => {
        this.enderecoService.setEndereco(this.getEndereco());
        this.isEnderecoValido.emit((this.enderecoForm.status == 'VALID') && !this.cepInvalido);
      }
    )

    this.options = {
      center: {lat: -19.0, lng: -42.0},
      zoom: 12
    };

    // this.overlays = [ new google.maps.Marker({position: {lat: -19.0, lng: -42.0}, title:"Template"})];
    this.overlays = [];

  }

  ngOnChanges() {
    if (this && this.enderecoForm) {
      //inicializa cidade, caso seja necessario
      if(!this.endereco.cidade){
        this.endereco.cidade = new Cidade();
      }

      this.enderecoForm.patchValue({
        cep: this.endereco.cep,
        numero: this.endereco.numero,
        observacao: this.endereco.observacao,
        bairro: this.endereco.bairro,
        complemento: this.endereco.complemento,
        logradouro: this.endereco.logradouro,
        latitude: this.endereco.latitude,
        longitude: this.endereco.longitude
      })
      this.pesquisarEndereco();
      this.cepInvalido = false;
    }
  }

  configurarFormulario() {
    this.enderecoForm = this.formBuilder.group({
      cep: [this.endereco.cep],
      logradouro: [this.endereco.logradouro],
      bairro: [this.endereco.bairro],
      numero: [this.endereco.numero],
      complemento: [this.endereco.complemento],
      observacao: [this.endereco.observacao],
      cidade: [null],
      estado: [null],
      latitude: [this.endereco.latitude],
      longitude: [this.endereco.longitude]
    });

    if (this.isObrigatorio) {
      this.enderecoForm.get('cep').setValidators([this.tamMinimoCEP.bind(this)]);
    }

    this.enderecoForm.get('cidade').disable();
  }

  tamMinimoCEP(): Validators {
    if (this.enderecoForm) {
      const input = this.enderecoForm.get('cep');
      if (input.value) {
        let cep = input.value.replace("-", "");
        cep = cep.replace("_", "");
        return (cep.length < 8) ? { tamMinimo: true } : null;
      } else {
        return { tamMinimo: true };
      }
    }
    return { tamMinimo: true };
  }

  pesquisarEndereco() {
    this.blockedPanel = true;
    if (this.enderecoForm && this.enderecoForm.get('cep').value) {
      const cep = this.enderecoForm.get('cep').value.replace("-", "");
      this.enderecoService.findByCEP(cep)
        .subscribe(
          (endereco: any) => {
            if (endereco) {
              this.enderecoService.findCidadeByIdIBGE(endereco.ibge)
                .subscribe(
                  (cidade: any) => {
                    this.blockedPanel = false;
                    this.cepInvalido = false;
                    endereco.cidade = cidade;
                    // pesquisa todas cidades do estado
                    this.pesquisarCidades({
                      value: {
                        id: endereco.cidade.microrregiao.mesorregiao.UF.id
                      }
                    });
                    // preenche o formulario com os dados recuperados

                    // caso o cep nao retorne alguns dados, prevalece os valores do banco
                    if(!endereco.bairro || endereco.bairro.length == 0){
                      endereco.bairro = this.endereco.bairro;
                    }

                    if(!endereco.logradouro || endereco.logradouro.length == 0){
                      endereco.logradouro = this.endereco.logradouro;
                    }
                    let adress;
                    if(this.endereco.latitude && this.endereco.longitude){
                      let marker = new google.maps.Marker({position: {lat: this.endereco.latitude, lng:  this.endereco.longitude}, title: 'Endereço Atual', draggable: true});
                      this.overlays[0] = marker;
                      // console.log("If: latitude, longitude: " +  this.endereco.latitude + "," +  this.endereco.longitude);
                      this.enderecoEncontrado = true;
                      this.loading = false;
                      this.options = {
                        center: {lat:  this.endereco.latitude, lng:  this.endereco.longitude},
                        zoom: 12
                      };
                      endereco.latitude = this.endereco.latitude;
                      endereco.longitude = this.endereco.longitude;

                      
                    }else if((endereco.bairro && endereco.cidade.nome) && endereco.cidade.microrregiao.mesorregiao.UF){
                        adress = endereco.bairro + " , " + endereco.cidade.nome + " , " + endereco.cidade.microrregiao.mesorregiao.UF + " , Brazil";
                        this.enderecoResposta = adress;
                        this.getLocation(adress).subscribe((local) =>{
                          endereco.latitude = local.lat();
                          endereco.longitude = local.lng();
                          this.latitude = endereco.latitude;
                          this.longitude = endereco.longitude;
                          this.enderecoEncontrado = true;
                          this.loading = false;
                          this.options = {
                            center: {lat: local.lat(), lng: local.lng()},
                            zoom: 12
                          };
                          let marker = new google.maps.Marker({position: {lat: this.latitude, lng: this.longitude}, title: 'Endereço Atual', draggable: true});
                          this.overlays[0] = marker;
                          
                          // console.log("Else: latitude, longitude: " + this.latitude + "," + this.longitude);
                        });
                      
                    }
                    
                    this.atualizarEndereco({
                      bairro: endereco.bairro,
                      cep: endereco.cep,
                      logradouro: endereco.logradouro,
                      cidade: endereco.cidade,
                      latitude: endereco.latitude,
                      longitude: endereco.longitude
                    });
                    this.enderecoService.setEndereco(this.getEndereco());
                  }
                );
            } else {
              this.blockedPanel = false;
              this.cepInvalido = true;
              this.enderecoForm.patchValue({
                bairro: null,
                complemento: null,
                logradouro: null,
                cidade: null,
                estado: null,
                latitude: null,
                longitude: null
              });
            }
          }
        );
    } else {
      this.blockedPanel = false;
    }
  }

  pesquisarEstados() {
    this.enderecoService.findAllEstados()
      .subscribe(
        (estados: SelectItem[]) => {
          this.estados = estados;
        }
      );
  }

  pesquisarCidades(event) {
    this.enderecoService.findAllCidadesByEstado(event.value.id)
      .subscribe(
        (cidades: SelectItem[]) => {
          this.cidades = cidades;
          this.enderecoForm.get('cidade').enable();
        }
      );
  }

  atualizarEndereco(endereco: any) {
    this.enderecoForm.patchValue({
      cep: endereco.cep,
      logradouro: endereco.logradouro,
      bairro: endereco.bairro,
      cidade: endereco.cidade,
      estado: endereco.cidade.microrregiao.mesorregiao.UF,
      latitude: endereco.latitude,
      longitude: endereco.longitude
    });
  }

  getEndereco(): Endereco {

    this.endereco.bairro = this.enderecoForm.value.bairro;
    this.endereco.cep = this.enderecoForm.value.cep;
    this.endereco.complemento = this.enderecoForm.value.complemento;
    this.endereco.logradouro = this.enderecoForm.value.logradouro;
    this.endereco.numero = this.enderecoForm.value.numero;
    this.endereco.observacao = this.enderecoForm.value.observacao;
    // this.endereco.latitude = this.enderecoForm.value.latitude;
    // this.endereco.longitude = this.enderecoForm.value.longitude;
    
    if (this.enderecoForm.value.cidade) {
      this.endereco.cidade.nome = this.enderecoForm.value.cidade.nome;
      this.endereco.cidade.estado.nome = this.enderecoForm.value.cidade.microrregiao.mesorregiao.UF.nome;
      this.endereco.cidade.estado.uf = this.enderecoForm.value.cidade.microrregiao.mesorregiao.UF.sigla;
      
      
      if(this.endereco.latitude && this.endereco.longitude){
        this.enderecoEncontrado = true;
          this.loading = false;
          this.options = {
            center: {lat: this.endereco.latitude, lng: this.endereco.longitude},
            zoom: 12
          };
          // this.endereco.latitude = this.latitude;
          // this.endereco.longitude = this.latitude;
          let marker = new google.maps.Marker({position: {lat:  this.endereco.latitude, lng:  this.endereco.longitude}, title: 'Endereço Atual', draggable: true});
          this.overlays[0] = marker;

          // console.log("GetEnd: Entrou no IF -> latitude, longitude: " + this.latitude + "," + this.longitude);
      } else {
        let adress = this.endereco.bairro + " , " + this.endereco.cidade.nome + " , " + this.endereco.cidade.estado.nome + " , Brazil";
        this.getLocation(adress).subscribe((local) =>{
          this.endereco.latitude = local.lat();
          this.endereco.longitude = local.lng();
          this.enderecoEncontrado = true;
          this.enderecoResposta = adress;
          this.loading = false;
          this.options = {
            center: {lat: local.lat(), lng: local.lng()},
            zoom: 12
          };
          let marker = new google.maps.Marker({position: {lat: this.latitude, lng: this.longitude}, title: 'Endereço Atual', draggable: true});
          this.overlays[0] = marker;
          this.latitude = this.endereco.latitude;
          this.longitude = this.endereco.longitude;

          // if(this.latitude && this.longitude){
          //   this.endereco.latitude = this.latitude;
          //   this.endereco.longitude = this.latitude;
          // } else {
          //   this.latitude = this.endereco.latitude;
          //   this.longitude = this.endereco.longitude;
          // }
          
          // console.log("getEnd: Entrou no Else -> latitude, longitude: " + this.latitude + "," + this.longitude);
          
        });
      }
    }
    return this.endereco;
  }

  getLocation(address: string): Observable<any> {
    // console.log('Endereço: ', address);
    let geocoder = new google.maps.Geocoder();
    return Observable.create(observer => {
        geocoder.geocode({
            'address': address
        }, (results, status) => {
            if (status == google.maps.GeocoderStatus.OK) {
                observer.next(results[0].geometry.location);
                observer.complete();
            } else {
                console.log('Error: ', results, ' & Status: ', status);
                observer.error();
            }
        });
    });
  }
  handleMapClick(event) {
    this.dialogVisible = true;
    this.selectedPosition = event.latLng;
  }
  handleDragEnd(event) {
    this.messageService.add({severity:'info', summary:'Marcador de Endereço atualizado!', detail: event.overlay.getPosition()});
    // console.log("Nova posiçao: " + event.overlay.getPosition().lat() + ", " +  event.overlay.getPosition().lng());
    this.endereco.latitude =  event.overlay.getPosition().lat();
    this.endereco.longitude =  event.overlay.getPosition().lng();
  }
  handleOverlayClick(event) {
    let isMarker = event.overlay.getTitle != undefined;

    if(isMarker) {
        let title = event.overlay.getTitle();
        this.infoWindow.setContent('' + title + '');
        this.infoWindow.open(event.map, event.overlay);
        event.map.setCenter(event.overlay.getPosition());

        this.messageService.add({severity:'info', summary:'Marcador Selecionado', detail: title});
    }
    else {
        this.messageService.add({severity:'info', summary:'Marcador Selecionado', detail: ''});
    }
}

}
