import { Injectable } from '@angular/core';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { SelectItem } from 'primeng/api';
import { map } from 'rxjs/operators';
import { Observable, AsyncSubject } from 'rxjs';
import { Endereco } from './endereco';
import { environment } from 'src/environments/environment';

@Injectable({
  providedIn: 'root'
})
export class EnderecoService {

  private enderecoObservable: Observable<Endereco>;

  urlApi: string;

  constructor(
    private http: HttpClient
  ) {
    this.enderecoObservable = new Observable<Endereco>();
    this.urlApi = environment.apiUrl;
  }

  setEndereco(endereco: Endereco) {
    this.enderecoObservable = new Observable(
      (observer) => {
        observer.next(endereco);
        observer.complete();
      }
    )
  }

  getEndereco(): Observable<Endereco> {
    return this.enderecoObservable;
  }

  findByCEP(cep: string) {
    return this.http
      .get(`https://viacep.com.br/ws/${cep}/json/`)
      .pipe(
        map(
          (endereco: any) => {
            if (!endereco.erro) {
              return endereco;
            } else {
              return null;
            }
          })
      );
  }

  findAllEstados(): Observable<SelectItem[]> {
    return this.http
      .get(`https://servicodados.ibge.gov.br/api/v1/localidades/estados`)
      .pipe(
        map((estadosPesquisados: any[]) => {
          estadosPesquisados.sort(
            (e1, e2) => {
              return e1.nome.localeCompare(e2.nome);
            }
          );
          const estados: SelectItem[] = [];
          estadosPesquisados.forEach(
            (estado) => {
              estados.push({
                label: estado.nome,
                value: estado
              });
            });
          return estados;
        })
      );
  }

  findAllCidadesByEstado(uf: number): Observable<SelectItem[]> {
    return this.http
      .get(`https://servicodados.ibge.gov.br/api/v1/localidades/estados/${uf}/municipios`)
      .pipe(
        map(
          (cidadesPesquisadas: any[]) => {
            cidadesPesquisadas.sort(
              (c1, c2) => {
                return c1.nome.localeCompare(c2.nome);
              }
            );
            const cidades: SelectItem[] = [];
            cidadesPesquisadas.forEach(
              (cidade) => {
                cidades.push({
                  label: cidade.nome,
                  value: cidade
                });
              }
            );
            return cidades;
          }
        )
      );
  }

  findCidadeByIdIBGE(idIBGE: number): Observable<any> {
    return this.http
      .get(`https://servicodados.ibge.gov.br/api/v1/localidades/municipios/${idIBGE}`);
  }

}
