import { Component, OnInit } from '@angular/core';
import { Cliente } from '../cliente';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { ClientesService } from '../clientes.service';
import { ConfirmationService, MessageService, MenuItem } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Router } from '@angular/router';
import { InputMask } from 'primeng/primeng';
import { HttpErrorResponse } from '@angular/common/http';

@Component({
  selector: 'app-listagem-cliente',
  templateUrl: './listagem-cliente.component.html',
  styleUrls: ['./listagem-cliente.component.css']
})
export class ListagemClienteComponent implements OnInit {

  clientes: Cliente[];
  loading: boolean;
  clienteSelecionado: Cliente;
  visualizar: boolean;
  numTotalClientes: number;
  filtroCliente: string = '';

  splitButtonItens: MenuItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private clientesService: ClientesService,
    private router: Router,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
  ) {
    this.breadcrumbService.setItems([
      { label: 'Clientes', routerLink: ['/clientes'], visible: true }
    ]);

    this.clienteSelecionado = new Cliente();
  }
  
  ngOnInit() {
    this.listar(0);

    this.splitButtonItens = [
      {
        label: 'Adicionar',
        icon: 'pi pi-search',
        command: () => {
          this.onClickSplitButton('adicionar');
        }
      }
    ];
  }

  onClickSplitButton(acao: string) {
    if (acao == 'novo') {
      this.router.navigate(['/clientes/novo']);
    } else if (acao = 'adicionar') {
      this.visualizar = true;
    }
  }

  onCompleteInputMask(cpf: string) {
    this.clientesService.findByCPF(cpf)
      .subscribe(
        (cliente: Cliente) => {
          this.clienteSelecionado = cliente;
        },
        (erro: HttpErrorResponse) => {
          this.mostrarMensagemErro('Nenhum cliente foi encontrado com o CPF informado!')
        });
  }

  loadClientes(event) {
    //this.loading = true;
    console.log("---findByLoad----");
      this.clientesService.findByNome(this.filtroCliente, event.first / event.rows)
        .subscribe(
          (dados: Page<Cliente>) => {
            this.clientes = dados.content;
            this.numTotalClientes = dados.totalElements;
            let numClientes = 0;
            let r = event.first / event.rows;
          }
        )
    
  }

  excluir(cliente: Cliente) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o cliente(a) ${cliente.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.clientesService.delete(cliente.idUsuario)
          .subscribe(
            (cliente: Cliente) => {
              this.mostrarMensagemSucesso('Cliente removido com sucesso!');
              this.findByNome(this.filtroCliente);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  listar(pagina: number) {
    //this.loading = true;
    console.log("---findByNome listar----");

      this.clientesService.findByNome('', pagina)
        .subscribe(
          (dados: Page<Cliente>) => {
            this.clientes = dados.content;
            this.numTotalClientes = dados.totalElements;
            let numClientes = 0;
          }
        )
    

  }

  findByNome(nome: string) {
    this.filtroCliente = nome;
    this.loading = true;
    console.log("---findByNome passei----");
      this.clientesService.findByNome(nome, 0)
        .subscribe(
          (dados: Page<Cliente>) => {
            if(dados.totalElements<=0){
              this.loading = false;
              console.log("---findByNome false----");
            }
            this.clientes = dados.content;
            this.numTotalClientes = dados.totalElements;
            let numClientes = 0;
            let auxC = 0;

            console.log("---findByNome----");
          }, error =>{
            this.loading = false;
            console.log("---findByNome Error----");
          }
        )
  }

  visualizarDialog(cliente: Cliente) {
    this.clienteSelecionado = cliente;
    this.visualizar = true;
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
