import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { AtividadePratica } from '../atividadePratica';
import { AtividadePraticaService} from '../atividadePratica.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-atividadePratica',
  templateUrl: './cadastro-atividadePratica.component.html',
  styleUrls: ['./cadastro-atividadePratica.component.css']
})

export class CadastroAtividadePraticaComponent implements OnInit {

  titulo: string;
  atividadePratica: AtividadePratica;

  tipoAtividade: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private atividadePraticaService: AtividadePraticaService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.atividadePratica = new AtividadePratica();

    this.atividadePratica.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'AtividadesPraticas', routerLink: ['drdebug/atividadePratica'], visible: true },
      { label: 'Editar', routerLink: [`drdebug/atividadePratica${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['drdebug/atividadePratica/novo'], visible: !id },
    ]);
    if (id) {
      this.atividadePraticaService.findById(id)
        .subscribe(
          (atividadePratica: AtividadePratica) => {
            if (atividadePratica) {
              this.atividadePratica = atividadePratica;

              this.breadcrumbService.setItems([
                { label: 'AtividadesPraticas', routerLink: ['drdebug/atividadePratica'], visible: true },
                { label: this.atividadePratica.nome, routerLink: [`drdebug/atividadePratica/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['drdebug/atividadePratica']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    
    this.tipoAtividade = [
      { label: 'Exercicio', value: 'Exercicio' },
      { label: 'Avaliativo', value: 'AVALIATIVO' },
    ];

  }

  salvar() {
    const isCreate = !this.atividadePratica.id;
    if (isCreate) {
      this.atividadePraticaService.insert(this.atividadePratica)
        .subscribe(
          (atividadePratica: AtividadePratica) => {

            this.mostrarMensagemSucesso('Atividade cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['drdebug/atividadePratica'])
            }, 500)
          }
        )
    } else {
      this.atividadePraticaService.update(this.atividadePratica)
        .subscribe(
          (atividadePratica: AtividadePratica) => {
            this.mostrarMensagemSucesso('Atividade alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['drDebug/atividadePratica'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
