import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { AtividadePratica } from '../atividadePratica';
import { AtividadePraticaService } from '../atividadePratica.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-atividadePratica',
  templateUrl: './listagem-atividadePratica.component.html',
  styleUrls: ['./listagem-atividadePratica.component.css']
})
export class ListagemAtividadePraticaComponent implements OnInit {

  atividadesPraticas: AtividadePratica[];
  loading: boolean;
  visualizar: boolean;
  atividadePraticaSelecionado: AtividadePratica;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private atividadePraticaService: AtividadePraticaService
  ) {
    this.breadcrumbService.setItems([
      { label: 'AtividadePratica', routerLink: ['/drdebug/atividadePratica'], visible: true }
    ]);
  }

  ngOnInit() {
    this.atividadePraticaSelecionado = new AtividadePratica();
    this.loading = true;
    this.atividadePraticaService.findAll(0)
      .subscribe(
        (dados: Page<AtividadePratica>) => {
          this.atividadesPraticas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(atividadePratica: AtividadePratica) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a atividadePratica ${atividadePratica.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.atividadePraticaService.delete(atividadePratica.id)
          .subscribe(
            (atividadePratica: AtividadePratica) => {
              this.mostrarMensagemSucesso('Atividade removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.atividadePraticaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<AtividadePratica>) => {
          this.atividadesPraticas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirAtividadePratica(atividadePratica: AtividadePratica) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}