import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { DueloDePontos } from '../dueloDePontos';
import { DueloDePontosService } from '../dueloDePontos.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-dueloDePontos',
  templateUrl: './cadastro-dueloDePontos.component.html',
  styleUrls: ['./cadastro-dueloDePontos.component.css']
})
export class CadastroDueloDePontosComponent implements OnInit {

  titulo: string;
  dueloDePontos: DueloDePontos;

  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private dueloDePontosService: DueloDePontosService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.dueloDePontos = new DueloDePontos();
    this.dueloDePontos.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'DueloDePontos', routerLink: ['/drdebug/dueloDePontos'], visible: true },
      { label: 'Editar', routerLink: [`/drdebug/dueloDePontos/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/drdebug/dueloDePontos/novo'], visible: !id },
    ]);
    if (id) {
      this.dueloDePontosService.findById(id)
        .subscribe(
          (dueloDePontos: DueloDePontos) => {
            if (dueloDePontos) {
              this.dueloDePontos = dueloDePontos;

              this.breadcrumbService.setItems([
                { label: 'DueloDePontoss', routerLink: ['/drdebug/dueloDePontos'], visible: true },
                { label: this.dueloDePontos.jogador1, routerLink: [`/drdebug/dueloDePontos/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/drdebug/dueloDePontos']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    
  }

  salvar() {
    const isCreate = !this.dueloDePontos.id;
    if (isCreate) {
      this.dueloDePontosService.insert(this.dueloDePontos)
        .subscribe(
          (dueloDePontos: DueloDePontos) => {

            this.mostrarMensagemSucesso('DueloDePontos cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/drdebug/dueloDePontos'])
            }, 500)
          }
        )
    } else {
      this.dueloDePontosService.update(this.dueloDePontos)
        .subscribe(
          (dueloDePontos: DueloDePontos) => {
            this.mostrarMensagemSucesso('Duelo de pontos alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/drdebug/dueloDePontos'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
