import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { DueloDePontos } from '../dueloDePontos';
import { DueloDePontosService } from '../dueloDePontos.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-dueloDePontos',
  templateUrl: './listagem-dueloDePontos.component.html',
  styleUrls: ['./listagem-dueloDePontos.component.css']
})
export class ListagemDueloDePontosComponent implements OnInit {

  dueloDePontoss: DueloDePontos[];
  loading: boolean;
  visualizar: boolean;
  dueloDePontosSelecionado: DueloDePontos;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private dueloDePontosService: DueloDePontosService
  ) {
    this.breadcrumbService.setItems([
      { label: 'DueloDePontos', routerLink: ['/drdebug/dueloDePontos'], visible: true }
    ]);
  }

  ngOnInit() {
    this.dueloDePontosSelecionado = new DueloDePontos();
    this.loading = true;
    this.dueloDePontosService.findAll(0)
      .subscribe(
        (dados: Page<DueloDePontos>) => {
          this.dueloDePontoss = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(dueloDePontos: DueloDePontos) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${dueloDePontos.jogador1}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.dueloDePontosService.delete(dueloDePontos.id)
          .subscribe(
            (dueloDePontos: DueloDePontos) => {
              this.mostrarMensagemSucesso('DueloDePontos removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(jogador1: string) {
    this.filtro = jogador1;
    this.loading = true;
    this.dueloDePontosService.findByNome(jogador1, 0)
      .subscribe(
        (dados: Page<DueloDePontos>) => {
          this.dueloDePontoss = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirDueloDePontos(dueloDePontos: DueloDePontos) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
