import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Empresa } from '../empresa';
import { EmpresaService } from '../empresa.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-empresa',
  templateUrl: './cadastro-empresa.component.html',
  styleUrls: ['./cadastro-empresa.component.css']
})
export class CadastroEmpresaComponent implements OnInit {

  titulo: string;
  empresa: Empresa;

  tipo: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private parceirosService: EmpresaService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.empresa = new Empresa();
    //this.campanha.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Parceiros', routerLink: ['/drdebug/empresa'], visible: true },
      { label: 'Editar', routerLink: [`/drdebug/empresa/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/drdebug/empresa/novo'], visible: !id },
    ]);
    if (id) {
      this.parceirosService.findById(id)
        .subscribe(
          (empresa: Empresa) => {
            if (empresa) {
              this.empresa = empresa;

              this.breadcrumbService.setItems([
                { label: 'Parceiros', routerLink: ['/drdebug/empresa'], visible: true },
                { label: this.empresa.nome, routerLink: [`/drdebug/empresa/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/drdebug/empresa']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {
    this.tipo = [
      { label: 'INFORMATICA', value: 'INFORMATICA' },
      { label: 'CONSTRUCAO_CIVIL', value: 'CONSTRUCAO_CIVIL' },
      { label: 'MANUTENCAO', value: 'MANUTENCAO' },
    ];
  

  }

  salvar() {
    const isCreate = !this.empresa.id;
    if (isCreate) {
      this.parceirosService.insert(this.empresa)
        .subscribe(
          (pessoat: Empresa) => {

            this.mostrarMensagemSucesso('Empresa cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/drdebug/empresa'])
            }, 500)
          }
        )
    } else {
      this.parceirosService.update(this.empresa)
        .subscribe(
          (pessoat: Empresa) => {
            this.mostrarMensagemSucesso('Empresa alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/drdebug/empresa'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
