import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Empresa } from '../empresa';
import { EmpresaService } from '../empresa.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-empresa',
  templateUrl: './listagem-empresa.component.html',
  styleUrls: ['./listagem-empresa.component.css']
})
export class ListagemEmpresaComponent implements OnInit {

  empresas: Empresa[];
  loading: boolean;
  visualizar: boolean;
  empresaSelecionado: Empresa;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private empresaService: EmpresaService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Empresa', routerLink: ['/drdebug/empresa'], visible: true }
    ]);
  }

  ngOnInit() {
    this.empresaSelecionado = new Empresa();
    this.loading = true;
    this.empresaService.findAll(0)
      .subscribe(
        (dados: Page<Empresa>) => {
          this.empresas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(empresa: Empresa) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a empresa ${empresa.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.empresaService.delete(empresa.id)
          .subscribe(
            (empresa: Empresa) => {
              this.mostrarMensagemSucesso('Empresa removida com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.empresaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Empresa>) => {
          this.empresas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirEmpresa(empresa: Empresa) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
