import { Component, OnInit } from '@angular/core';
import { GameNivelService } from '../game-nivel.service';
import { MessageService, ConfirmationService, SelectItem } from 'primeng/api';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { GameNivel } from '../game-nivel';
import { Game } from '../../game/game';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Router, ActivatedRoute } from '@angular/router';
import { GameService } from '../../game/game.service';
import { Page } from 'src/app/utils/page';


@Component({
  selector: 'app-cadastrar-game-nivel',
  templateUrl: './cadastrar-game-nivel.component.html',
  styleUrls: ['./cadastrar-game-nivel.component.css']
})

export class CadastrarGameNivelComponent implements OnInit {

  titulo: string;
  gameNivel: GameNivel;
  gameNiveis: GameNivel[];
  listaGames: Game[];
  tipoStatus: SelectItem[];

  constructor(
    private gameNivelService: GameNivelService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private breadcrumbService: BreadcrumbService,
    private oauthService: OauthService,
    private router: Router,
    private activatedRoute: ActivatedRoute,
    private game: GameService
  ) {
    this.gameNivel = new GameNivel();
    this.gameNivel.status = (this.isAdministrador() ? 'PUBLICO':'PRIVADO'); 
    //this.listaGames = [];
    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: "Níveis de game", routerLink: ['/drdebug/gameNivel/listar'], visible: true},
      { label: "Novo nível", routerLink: ['/drdebug/gameNivel/novo'], visible: true}
    ])
    // this.gameNivel = new GameNivel();
    if(id) {
      this.gameNivelService.findById(id)
      .subscribe(
        (gnivel: GameNivel) => {
          if(gnivel) {
            this.gameNivel = gnivel;

            this.breadcrumbService.setItems([
              {label: 'Parceiros', routerLink: ['/drdebug/gameNivel/listar'], visible: true},
              {label: this.gameNivel.nome, routerLink: [`/drdebug/gameNivel/${id}`], visible: true}
            ]);
          } else {
            this.router.navigate(['/drdebug/gameNivel/listar']);
          }
        })
    }

    this.titulo = (id) ? 'Editar' : 'Cadastrar';
  }

  ngOnInit() {
    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' },
      { label: 'Ativo', value: 'ATIVO'},
      { label: 'Inativo', value: 'INATIVO' }
    ];
  }

  limpar() {
    this.gameNivel = new GameNivel();
  } 

  salvar() {
    const isCreate = !this.gameNivel.id;
    // if(isCreate) {
      this.gameNivelService.insert(this.gameNivel)
      .subscribe(
        (gnivel: GameNivel) => {
          this.mostrarMensagemSucesso('Nivel de game cadastrado com sucesso!');
          setTimeout(() => {
            this.router.navigate(['/drdebug/gameNivel/listar'])
          }, 500)
        }


      )
    // } else {
    //   this.gameNivelService.update(this.gameNivel)
    //   .subscribe(
    //     (gnivel: GameNivel) => {
    //       this.mostrarMensagemSucesso('Nivel de game alterado com sucesso!');
    //       setTimeout(() => {
    //         this.router.navigate(['/drdebug/gameNivel/listar'])
    //       }, 500)
    //     }
    //   )
    // }
  }


  findByNomeGame(nome: string) {
    return this.game.listar().
    subscribe(
      (dados: Game[]) => {
      this.listaGames = dados;
      console.log("lista games", this.listaGames);
    })
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'info', detail: mensagem });
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

}