import { Component, OnInit } from '@angular/core';
import { GameNivelService } from '../game-nivel.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Router } from '@angular/router';
import { GameNivel } from '../game-nivel';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listar-game-nivel',
  templateUrl: './listar-game-nivel.component.html',
  styleUrls: ['./listar-game-nivel.component.css']
})
export class ListarGameNivelComponent implements OnInit {

  // gameNivel: GameNivel;
  gameNiveis: GameNivel[];
  loading: boolean;
  visualizar: boolean;
  nivelSelecionado: GameNivel;

  numTotal: number;
  filtro: string = '';

  constructor(
    private gameNivelService: GameNivelService,
    private messageService: MessageService,
    // private router: Router,
    private confirmationService: ConfirmationService,
    private breadcrumbService: BreadcrumbService,
    private ouathService: OauthService,
  ) {
      this.breadcrumbService.setItems([
        { label: "Níveis de game", routerLink: ['/drdebug/gameNivel/listar'], visible: true}
      ])
  }

  ngOnInit() {
    this.nivelSelecionado = new GameNivel();
    this.loading = true;
    this.gameNivelService.findAll(0).subscribe(
      (dados: Page<GameNivel>) => {
        this.gameNiveis = dados.content;
        this.numTotal = dados.totalElements;
        this.loading = false;
      }
    )
  }

  excluir(gameNivel: GameNivel) {
    // console.log("Confirmeservice");
    this.confirmationService.confirm({
    
      message: `Deseja realmente excluir o nivel do game ${gameNivel.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      
      accept: () => {
        this.gameNivelService.delete(gameNivel.id)
          .subscribe(
            (gnivel: GameNivel) => {
              this.mostrarMensagemSucesso('Nivel do Game removido com sucesso.');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
          this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });
  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.gameNivelService.findByNome(nome, 0)
    .subscribe(
      (dados: Page<GameNivel>) => {
        console.log("gameNiveis");
        console.log(this.gameNiveis);
        this.gameNiveis = dados.content;
        this.numTotal = dados.totalElements;
        this.loading = false;
      }
    )
  }

  possuiPermissaoEditarExcluirGameNivel(gnivel: GameNivel) {
    return this.ouathService.checkPermission('ROLE_ADMINISTRADOR');
  }
  
  mostrarMensagemSucesso(mensagem: string) {
      this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
  
  mostrarMensagemInfo(mensagem: string) {
      this.messageService.add({ severity: 'info', summary: 'info', detail: mensagem });
  }
  
  mostrarMensagemErro(mensagem: string) {
      this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

}
