import { Component, OnInit } from '@angular/core';
import { Game } from '../game';
import { SelectItem, MessageService } from 'primeng/api';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ActivatedRoute, Router } from '@angular/router';
import { GameService } from '../game.service';
import {DropdownModule} from 'primeng/dropdown';
import { Disciplina } from 'src/app/ipc/school/disciplina/disciplina';
import { DisciplinaService } from 'src/app/ipc/school/disciplina/disciplina.service';
import { Page } from 'src/app/utils/page';

@Component({
  selector: 'app-cadastro',
  templateUrl: './cadastro.component.html',
  styleUrls: ['./cadastro.component.css']
})
export class CadastroComponent implements OnInit {

  titulo: string;
  game: Game;

  id: number;

  discs: Disciplina[];

  tNiveis: SelectItem[];
  tTipos: SelectItem[];
  
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private assocServices: GameService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router,
    private disciplinaService: DisciplinaService
  ) { 
    this.game = new Game();
    this.game.status = this.isAdministrador()? 'PUBLICO' : 'PRIVADO';
 
    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      {label: 'Editar', routerLink: [`/drdebug/game/${id}`], visible: id != undefined},
      {label: 'Novo', routerLink: ['/drdebug/game/novo'], visible: !id}
    ]);

    if(id){
      this.assocServices.findById(id)
      .subscribe(
        (game: Game)=>{
          if(game){
            this.game = game;
            this.breadcrumbService.setItems([
              {label: 'Associados', routerLink: ['/drdebug/game'], visible: true},
              {label: this.game.nome, routerLink: [`/drdebug/game/${id}`], visible: true}
            ]);
          }else{
            this.router.navigate(['/drdebug/game'])
          }
        }
      )
    }
  this.titulo=(id)? 'Editar' : 'Cadastrar'
  }

  ngOnInit() {
    this.tipoStatus = [
    { label: 'Público', value: 'PUBLICO' },
    { label: 'Privado', value: 'PRIVADO' }
  ];

  this.tNiveis = [
    { label: 'Rpg', value: 'RPG' },
    { label: 'Tabuleiro', value: 'TABULERIO' }
  ];

  this.tTipos = [
    { label: 'Superior', value: 'SUPERIOR' },
    { label: 'Técnico', value: 'TECNICO' }
  ];
  this.findDisc();
  }

  salvar(){
    this.id = 0;
    //const isCreate = !this.game.id;
    console.log(this.game);
    /*
    if(isCreate){
      this.assocServices.insert(this.game)
      .subscribe(
        (game: Game) => {          
          this.mostrarMensagemSucesso('Game cadastrado com sucesso.');
          setTimeout(() => {
            this.router.navigate(['/drdebug/game/'])
          },500)
        }
      )
    }else{
      this.assocServices.update(this.game)
      .subscribe(
        (game: Game) => {
          this.mostrarMensagemSucesso('Pessoa alterada com sucesso!');
          setTimeout(() => {
            this.router.navigate(['/drdebug/game/'])
          },500)
        }
      )
    }*/

    this.assocServices.insert(this.game)
    .subscribe(
      (game: Game) => {          
        this.mostrarMensagemSucesso('Game cadastrado com sucesso.');
        setTimeout(() => {
          this.router.navigate(['/drdebug/game/'])
        },500)
      }
    )

  }

  findDisc(){
    this.disciplinaService.findAll(0).subscribe(
      (dados: Page<Disciplina>)=>{
        console.log(dados.content);
        this.discs = dados.content;
      }
    )
  }

  isAdministrador(){
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string){
    this.messageService.add({severity:'erro', summary:'Erro', detail: mensagem});
  }

  mostrarMensagemInfo(mensagem: string){
    this.messageService.add({severity:'info', summary: 'Info', detail: mensagem});
  }

  mostrarMensagemSucesso(mensagem: string){
    this.messageService.add({severity: 'success', summary:'Sucesso', detail: mensagem});
  }

}
