import { Component, OnInit } from '@angular/core';
import { Game } from '../game';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, ConfirmationService } from 'primeng/api';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { GameService } from '../game.service';
import { Page } from 'src/app/utils/page';
import { Router } from '@angular/router';

@Component({
  selector: 'app-listagem-game',
  templateUrl: './listagem-game.component.html',
  styleUrls: ['./listagem-game.component.css']
})
export class ListagemGameComponent implements OnInit {


  games: Game[];
  loading: boolean;
  visualizar: boolean;
  gameSelecionado: Game;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService:ConfirmationService,
    private oauthService: OauthService,
    private gameService: GameService
  ) { 
    this.breadcrumbService.setItems(
      [
        {label: 'GameGame', routerLink: ['/drdebug/game/'], visible: true}
      ]
    )
  }

consultar(){
  this.gameService.listar().subscribe(resposta=> this.games = <any>resposta);
}

  ngOnInit() {
    /*this.gameSelecionado = new Game();
    this.loading = true;
    this.gameService.findAll(0)
      .subscribe(
        (dados: Page<Game>) =>{
          this.games = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;                
      }
    )*/
    this.consultar();
  }


  excluir(game: Game){
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o Game ${game.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',

      accept: () =>{
        this.gameService.delete(game.id)
        .subscribe(
          (game: Game) => {
          this.mostrarMensagemSucesso('Game removido com Sucesso!');
            this.findByNome(this.filtro);
          }
        );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });
  }

  findByNome(nome: string){
    this.filtro = nome;
    this.loading =true;
    this.gameService.findByNome(nome,0)
    .subscribe(
      (dados: Page<Game>) =>{
        this.games = dados.content;
        this.numTotal = dados.totalElements;
        this.loading = false;
      }
    )
  }

  possuiPermissaoEditarExcluirGame(game: Game){
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string){
    this.messageService.add({severity: 'erro', summary: 'Erro', detail: mensagem})
  }

  mostrarMensagemInfo(mensagem: string){
    this.messageService.add({severity: 'info', summary: 'Info', detail: mensagem});
  }

  mostrarMensagemSucesso(mensagem: string){
    this.messageService.add({severity:'success', summary:'Sucesso', detail: mensagem});
  }

}
