import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Time } from '../time';
import { TimeService } from '../time.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-time',
  templateUrl: './cadastro-time.component.html',
  styleUrls: ['./cadastro-time.component.css']
})
export class CadastroTimeComponent implements OnInit {

  titulo: string;
  time: Time;

  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private parceirosService: TimeService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.time = new Time();
    this.time.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Parceiros', routerLink: ['/testes/times'], visible: true },
      { label: 'Editar', routerLink: [`/testes/times/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/testes/times/novo'], visible: !id },
    ]);
    if (id) {
      this.parceirosService.findById(id)
        .subscribe(
          (time: Time) => {
            if (time) {
              this.time = time;

              this.breadcrumbService.setItems([
                { label: 'Parceiros', routerLink: ['/testes/times'], visible: true },
                { label: this.time.nome, routerLink: [`/testes/times/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/testes/times']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

  }

  salvar() {
    const isCreate = !this.time.id;
    if (isCreate) {
      this.parceirosService.insert(this.time)
        .subscribe(
          (time: Time) => {

            this.mostrarMensagemSucesso('Time Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/testes/times'])
            }, 500)
          }
        )
    } else {
      this.parceirosService.update(this.time)
        .subscribe(
          (time: Time) => {
            this.mostrarMensagemSucesso('Time Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/testes/times'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
