import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Time } from '../time';
import { TimeService } from '../time.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-time',
  templateUrl: './listagem-time.component.html',
  styleUrls: ['./listagem-time.component.css']
})
export class ListagemTimeComponent implements OnInit {

  times: Time[];
  loading: boolean;
  visualizar: boolean;
  timeSelecionado: Time;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private timeService: TimeService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Times', routerLink: ['/drdebug/time'], visible: true }
    ]);
  }

  ngOnInit() {
    this.timeSelecionado = new Time();
    this.loading = true;
    this.timeService.findAll(0)
      .subscribe(
        (dados: Page<Time>) => {
          this.times = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(time: Time) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o time ${time.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.timeService.delete(time.id)
          .subscribe(
            (time: Time) => {
              this.mostrarMensagemSucesso('time removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.timeService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Time>) => {
          this.times = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirTime(time: Time) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
