import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { ConfirmationService, MessageService, SelectItem} from 'primeng/api';
import { Compra } from '../compra';
import { CompraService } from '../compra.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';
import { Page } from 'src/app/utils/page';

@Component({
  selector: 'app-cadastro-compra',
  templateUrl: './cadastro-compra.component.html'
})
export class CadastroCompraComponent implements OnInit {

  titulo: string;
  compra: Compra;
  compras: Compra[];
  
  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
  
  calendarLocale: any;
  formaDePagamento: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private compraService: CompraService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.compra = new Compra();
    this.compra.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';

    const id = this.activatedRoute.snapshot.params['compraid'];

    this.breadcrumbService.setItems([
      { label: 'Compras', routerLink: ['/estoque/compra'], visible: true },
      { label: 'Editar', routerLink: [`/estoque/compra/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/estoque/compra/novo'], visible: !id },
    ]);
    
    if (id) {
      this.compraService.findById(id)
        .subscribe(
          (compra: Compra) => {
            if (compra) {
              this.compra = compra;

              this.breadcrumbService.setItems([
                { label: 'Compras', routerLink: ['/estoque/compra'], visible: true },
                { label: this.compra.produto, routerLink: [`/estoque/compra/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/estoque/compra']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    this.formaDePagamento = [
      { label: 'Parcelado', value: 'PARCELADO' },
      { label: 'À vista', value: 'A_VISTA' },
    ]

    this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }

  salvar() {
    const isCreate = !this.compra.compraid;
    
    if (isCreate) {
      this.compraService.insert(this.compra)
        .subscribe(
          (compra: Compra) => {

            this.mostrarMensagemSucesso('Compra cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/estoque/compra'])
            }, 500)
          }
        )
    } else {
      this.compraService.update(this.compra)
        .subscribe(
          (compra: Compra) => {
            this.mostrarMensagemSucesso('Compra alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/estoque/compra'])
            }, 500)
          }
        )
      }
  }
  
  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
