import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Compra } from '../compra';
import { CompraService } from '../compra.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Router } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Page } from 'src/app/utils/page';
@Component({
  selector: 'app-listagem-compra',
  templateUrl: './listagem-compra.component.html'
})
export class ListagemCompraComponent implements OnInit {

  compras: Compra[];
  loading: boolean;
  visualizar: boolean;
  compraSelecionada: Compra;
  numTotal: number;
  filtro : string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private compraService: CompraService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Compra', routerLink: ['/estoque/compra'], visible: true }
    ]);
  }

  ngOnInit() {
    this.compraSelecionada = new Compra();
    this.loading = true;
    this.compraService.findAll(0)
      .subscribe(
        (dados: Page<Compra>) => {
          this.compras = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }


  excluir(compra: Compra) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o produto ${compra.produto}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.compraService.delete(compra.compraid)
          .subscribe(
            (compra: Compra) => {
              this.mostrarMensagemSucesso('compra removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }
  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.compraService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Compra>) => {
          this.compras = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }
  possuiPermissaoEditarExcluirPessoa(compra: Compra) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
}
