import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Medalha } from '../medalha';
import { MedalhaService } from '../medalha.service';
import { PessoaT } from 'src/app/testes/pessoat/pessoat';
import { PessoasTService } from 'src/app/testes/pessoat/pessoast.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Page } from 'src/app/utils/page';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';

@Component({
  selector: 'app-cadastro-medalha',
  templateUrl: './cadastro-medalha.component.html',
  styleUrls: ['./cadastro-medalha.component.css']
})
export class CadastroMedalhaComponent implements OnInit {

  titulo: string;
  medalha: Medalha;
  pessoast: PessoaT[];
  calendarLocale: any;
  tiposcategory: SelectItem[];
  tipostype: SelectItem[];
  tiposrule: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private medalhaService: MedalhaService,
    private pessoaTService: PessoasTService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.medalha = new Medalha();
    this.medalha.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';

    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Medalha', routerLink: ['/gamepoints/medalha'], visible: true },
      { label: 'Editar', routerLink: [`/gamepoints/medalha/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/gamepoints/medalha/novo'], visible: !id },
    ]);
    if (id) {
      this.medalhaService.findById(id)
        .subscribe(
          (medalha: Medalha) => {
            if (medalha) {
              this.medalha = medalha;
              this.medalha.dataMedalha = new Date(medalha.dataMedalha);
              this.breadcrumbService.setItems([
                { label: 'Medalha', routerLink: ['/gamepoints/medalha'], visible: true },
                { label: this.medalha.nome, routerLink: [`/gamepoints/medalha/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/gamepoints/medalha']);
            }
          }
        )
    }

    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {
    this.calendarLocale = ConversorCalendario.getCalendarLocale();
    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    this.tiposcategory = [
      { label: 'CATEGORIA_1', value: 'CATEGORIA_1' },
      { label: 'CATEGORIA_2', value: 'CATEGORIA_2' },
      { label: 'CATEGORIA_3', value: 'CATEGORIA_3' },
      { label: 'CATEGORIA_4', value: 'CATEGORIA_4' },
      { label: 'CATEGORIA_5', value: 'CATEGORIA_5' }
    ];
    this.tipostype = [
      { label: 'TIPO_1', value: 'TIPO_1' },
      { label: 'TIPO_2', value: 'TIPO_2' },
      { label: 'TIPO_3', value: 'TIPO_3' },
      { label: 'TIPO_4', value: 'TIPO_4' },
      { label: 'TIPO_5', value: 'TIPO_5' }
    ];
    this.tiposrule = [
      { label: 'REGRA_1', value: 'REGRA_1' },
      { label: 'REGRA_2', value: 'REGRA_2' },
      { label: 'REGRA_3', value: 'REGRA_3' },
      { label: 'REGRA_4', value: 'REGRA_4' },
      { label: 'REGRA_5', value: 'REGRA_5' }
    ];

  }

  findByNome(nome: string) {
    this.pessoaTService.findByFiltro(nome, 0)
      .subscribe(
        (dados: Page<PessoaT>) => {
          this.pessoast = dados.content;
        }
      )
  }

  salvar() {
    const isCreate = !this.medalha.id;
    if (isCreate) {
      this.medalhaService.insert(this.medalha)
        .subscribe(
          (medalha: Medalha) => {

            this.mostrarMensagemSucesso('Medalha cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/gamepoints/medalha'])
            }, 500)
          }
        )
    } else {
      this.medalhaService.update(this.medalha)
        .subscribe(
          (medalha: Medalha) => {
            this.mostrarMensagemSucesso('Medalha alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/gamepoints/medalha'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
