import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Medalha } from '../medalha';
import { MedalhaService } from '../medalha.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-medalha',
  templateUrl: './detalhes-medalha.component.html',
  styleUrls: ['./detalhes-medalha.component.css']
})
export class DetalhesMedalhaComponent implements OnInit {

  titulo: string; 
  medalha: Medalha;
  statusMedalha: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private medalhaService: MedalhaService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.medalha = new Medalha();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Medalha', routerLink: ['/gamepoints/medalha'] , visible: true},
      { label: 'Editar', routerLink: [`/gamepoints/medalha/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/gamepoints/medalha/novo'] , visible: !id},
    ]);
    if (id) {
      this.medalhaService.findById(id)
        .subscribe(
          (medalha: Medalha) => {
            if(medalha){
              this.medalha = medalha;
              this.statusMedalha = (this.medalha.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Medalha', routerLink: ['/gamepoints/medalha'] , visible: true},
                { label: this.medalha.nome, routerLink: [`/gamepoints/medalha/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/gamepoints/medalha']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
