import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Medalha } from '../medalha';
import { MedalhaService } from '../medalha.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-medalha',
  templateUrl: './listagem-medalha.component.html',
  styleUrls: ['./listagem-medalha.component.css']
})
export class ListagemMedalhaComponent implements OnInit {

  medalhas: Medalha[];
  loading: boolean;
  visualizar: boolean;
  medalhaSelecionado: Medalha;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private medalhaService: MedalhaService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Medalha', routerLink: ['/gamepoints/medalha'], visible: true }
    ]);
  }

  ngOnInit() {
    this.medalhaSelecionado = new Medalha();
    this.loading = true;
    this.medalhaService.findAll(0)
      .subscribe(
        (dados: Page<Medalha>) => {
          this.medalhas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(medalha: Medalha) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a medalha ${medalha.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.medalhaService.delete(medalha.id)
          .subscribe(
            (medalha: Medalha) => {
              this.mostrarMensagemSucesso('Medalha removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.medalhaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Medalha>) => {
          this.medalhas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirMedalha(medalha: Medalha) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
