import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Campanha } from '../campanha';
import { CampanhaService } from '../campanha.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Page } from 'src/app/utils/page';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';

@Component({
  selector: 'app-cadastro-campanha',
  templateUrl: './cadastro-campanha.component.html',
  styleUrls: ['./cadastro-campanha.component.css']
})
export class CadastroCampanhaComponent implements OnInit {

  titulo: string;
  campanha: Campanha;
  campanhas: Campanha[];

  atualizacao: SelectItem[];
  tipoStatus: SelectItem[];

  dataconvertida: Date;
  calendarLocale: any;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private campanhaService: CampanhaService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.campanha = new Campanha();
    this.campanha.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    this.campanha.atualizacao = (this.isAdministrador()) ? 'DIÁRIA' : 'HORA' ; 'SEMANAL';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Campanha', routerLink: ['/influenzer/campanha'], visible: true },
      { label: 'Editar', routerLink: [`/influenzer/campanha/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/influenzer/campanha/novo'], visible: !id },
    ]);
    if (id) {
      this.campanhaService.findById(id)
        .subscribe(
          (campanha: Campanha) => {
            if (campanha) {
              this.campanha = campanha;
              this.campanha.dtInicio = this.converter(this.campanha.dtInicio)
              this.campanha.dtFim = this.converter(this.campanha.dtFim)
              this.breadcrumbService.setItems([
                { label: 'Campanhas', routerLink: ['/influenzer/campanha'], visible: true },
                { label: this.campanha.nome, routerLink: [`/influenzer/campanha/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/influenzer/campanha']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.atualizacao = [
      { label: 'DIÁRIA', value: 'DIÁRIA' },
      { label: 'HORA', value: 'HORA' },
      { label: 'SEMANAL', value: 'SEMANAL' }
    ];

    this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }

  salvar() {
    const isCreate = !this.campanha.id;
    if (isCreate) {
      this.campanhaService.insert(this.campanha)
        .subscribe(
          (campanha: Campanha) => {

            this.mostrarMensagemSucesso('Campanha cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/influenzer/campanha'])
            }, 500)
          }
        )
    } else {
      this.campanhaService.update(this.campanha)
        .subscribe(
          (campanha: Campanha) => {
            this.mostrarMensagemSucesso('Campanha alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/influenzer/campanha'])
            }, 500)
          }
        )
    }

  }

  findByNome(nome: string) {
    this.campanhaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Campanha>) => {
          this.campanhas = dados.content;
        }
      )
  }

  converter(data: Date){
    this.dataconvertida = new Date(data)
    return this.dataconvertida
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
