import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Campanha } from '../campanha';
import { CampanhaService } from '../campanha.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-campanha',
  templateUrl: './detalhes-campanha.component.html',
  styleUrls: ['./detalhes-campanha.component.css']
})
export class DetalhesCampanhaComponent implements OnInit {

  titulo: string;
  campanha: Campanha;
  statusCampanha: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private campanhaService: CampanhaService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.campanha = new Campanha();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Campanha', routerLink: ['/influenzer/campanha'] , visible: true},
      { label: 'Editar', routerLink: [`/influenzer/campanha/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/influenzer/campanha/novo'] , visible: !id},
    ]);
    if (id) {
      this.campanhaService.findById(id)
        .subscribe(
          (campanha: Campanha) => {
            if(campanha){
              this.campanha = campanha;
              this.statusCampanha = (this.campanha.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Campanha', routerLink: ['/influenzer/campanha'] , visible: true},
                { label: this.campanha.nome, routerLink: [`/influenzer/campanha/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/influenzer/campanha']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
