import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Campanha } from '../campanha';
import { CampanhaService } from '../campanha.service';
import { ConfirmationService, MessageService, SelectItem } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-campanha',
  templateUrl: './listagem-campanha.component.html',
  styleUrls: ['./listagem-campanha.component.css']
})
export class ListagemCampanhaComponent implements OnInit {

  campanhas: Campanha[];
  loading: boolean;
  visualizar: boolean;
  campanhaSelecionado: Campanha;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private campanhaService: CampanhaService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Campanha', routerLink: ['/influenzer/campanha'], visible: true }
    ]);
  }

  ngOnInit() {
    this.campanhaSelecionado = new Campanha();
    this.loading = true;
    this.campanhaService.findAll(0)
      .subscribe(
        (dados: Page<Campanha>) => {
          this.campanhas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(campanha: Campanha) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a campanha ${campanha.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.campanhaService.delete(campanha.id)
          .subscribe(
            (campanha: Campanha) => {
              this.mostrarMensagemSucesso('Campanha removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.campanhaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Campanha>) => {
          this.campanhas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirCampanha(campanha: Campanha) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
