import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { CasoDeTeste } from '../casodeteste';
import { CasoDeTesteService} from '../casodeteste.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-casodeteste',
  templateUrl: './cadastro-casodeteste.component.html',
  styleUrls: ['./cadastro-casodeteste.component.css']
})

export class CadastroCasoDeTesteComponent implements OnInit {

  titulo: string;
  casodeteste: CasoDeTeste;

  tiposVisibilidade: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private casodetesteService: CasoDeTesteService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.casodeteste = new CasoDeTeste();

    this.casodeteste.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'CasosDeTeste', routerLink: ['ipc/casodeteste'], visible: true },
      { label: 'Editar', routerLink: [`ipc/casodeteste${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['ipc/casodeteste/novo'], visible: !id },
    ]);
    if (id) {
      this.casodetesteService.findById(id)
        .subscribe(
          (casodeteste: CasoDeTeste) => {
            if (casodeteste) {
              this.casodeteste = casodeteste;

              this.breadcrumbService.setItems([
                { label: 'CasosDeTeste', routerLink: ['ipc/casodeteste'], visible: true },
                { label: this.casodeteste.descricao, routerLink: [`ipc/casodeteste/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['ipc/casodeteste']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    
    this.tiposVisibilidade = [
      { label: 'Apenas Admnistradores', value: 'APENAS_ADMINISTRADORES' },
      { label: 'Administradores e Usuários', value: 'ADMNISTRADORES_E_USUÁRIOS' },
    ];

  }

  salvar() {
    const isCreate = !this.casodeteste.id;
    if (isCreate) {
      this.casodetesteService.insert(this.casodeteste)
        .subscribe(
          (casodeteste: CasoDeTeste) => {

            this.mostrarMensagemSucesso('Caso de Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/casodeteste'])
            }, 500)
          }
        )
    } else {
      this.casodetesteService.update(this.casodeteste)
        .subscribe(
          (casodeteste: CasoDeTeste) => {
            this.mostrarMensagemSucesso('Caso de Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/casodeteste'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
