import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { CasoDeTeste } from '../casodeteste';
import { CasoDeTesteService } from '../casodeteste.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-casodeteste',
  templateUrl: './listagem-casodeteste.component.html',
  styleUrls: ['./listagem-casodeteste.component.css']
})
export class ListagemCasoDeTesteComponent implements OnInit {

  casosdeteste: CasoDeTeste[];
  loading: boolean;
  visualizar: boolean;
  casodetesteSelecionado: CasoDeTeste;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private casodetesteService: CasoDeTesteService
  ) {
    this.breadcrumbService.setItems([
      { label: 'CasoDeTeste', routerLink: ['/ipc/casodeteste'], visible: true }
    ]);
  }

  ngOnInit() {
    this.casodetesteSelecionado = new CasoDeTeste();
    this.loading = true;
    this.casodetesteService.findAll(0)
      .subscribe(
        (dados: Page<CasoDeTeste>) => {
          this.casosdeteste = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(casodeteste: CasoDeTeste) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o Caso de Teste ${casodeteste.id}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.casodetesteService.delete(casodeteste.id)
          .subscribe(
            (casodeteste: CasoDeTeste) => {
              this.mostrarMensagemSucesso('Caso de Teste removido com sucesso!');
              this.findByDescricao(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByDescricao(descricao: string) {
    this.filtro = descricao;
    this.loading = true;
    this.casodetesteService.findByDescricao(descricao, 0)
      .subscribe(
        (dados: Page<CasoDeTeste>) => {
          this.casosdeteste = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirCasoDeTeste(casodeteste: CasoDeTeste) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}