import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Competicao } from '../competicao';
import { CompeticoesService } from '../competicoes.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-competicoes',
  templateUrl: './cadastro-competicoes.component.html',
  styleUrls: ['./cadastro-competicoes.component.css']
})
export class CadastroCompeticaoComponent implements OnInit {

  titulo:string;
  competicao:Competicao;

  constructor(
    private competicaoService: CompeticoesService,
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {

    this.competicao = new Competicao();
    //this.pessoat.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';


    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Competicoes', routerLink: ['/ipc/competicoes'], visible: true },
      { label: 'Editar', routerLink: [`/ipc/competicoes/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/competicoes/novo'], visible: !id },
    ]);
    if (id) {
      this.competicaoService.findById(id)
        .subscribe(
          (competicao: Competicao) => {
            if (competicao) {
              this.competicao = competicao;

              this.breadcrumbService.setItems([
                { label: 'Competicoes', routerLink: ['/ipc/competicoes'], visible: true },
                { label: this.competicao.name, routerLink: [`/ipc/competicoes/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/ipc/competicoes']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    /* this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ]; */

  }

  salvar() {
    const isCreate = !this.competicao.cid;
    if (isCreate) {
      this.competicaoService.insert(this.competicao)
        .subscribe(
          (competicao: Competicao) => {

            this.mostrarMensagemSucesso('Competicao cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/competicoes'])
            }, 500)
          }
        )
    } else {
      this.competicaoService.update(this.competicao)
        .subscribe(
          (competicao: Competicao) => {
            this.mostrarMensagemSucesso('Competicao alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/competicoes'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}


/* nome = "Usuário Admin";

  competicao = {};
  competicoes = []

  constructor(private CompeticaoService: CompeticaoService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private competicaoService: CompeticaoService,
  ) {
  } */



 // ngOnInit() {

 //this.consultar();

  //  }

/*
  consultar() {
    this.competicaoService.listar()
      .subscribe(resposta => this.competicoes = <any>resposta)
  }

  adicionar() {
    this.competicaoService.adicionar(this.competicao)
      .subscribe(() => {
        this.competicao = {};
        this.consultar();

        this.messageService.add({
          severity: 'success',
          summary: 'Competição adicionada com sucesso!'
        });
      },
        resposta => {
          let msg = 'Erro inesperado. Tente novamente.';

          if (resposta.error.message) {
            msg = resposta.error.message;
          }

          this.messageService.add({
            severity: 'error',
            summary: msg
          });
        });
  }

  excluir(competicao: any) {

    console.log("Confirmservice");
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a competicao ${competicao.name}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.competicaoService.delete(competicao.cid)
          .subscribe(
            () => {
              this.mostrarMensagemSucesso('Competição removida com sucesso!');
              this.consultar();
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });


  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
*/





//}
