import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Competicao } from '../competicao';
import { CompeticoesService } from '../competicoes.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-competicoes',
  templateUrl: './listagem-competicoes.component.html',
  styleUrls: ['./listagem-competicoes.component.css']
})
export class ListagemCompeticaoComponent implements OnInit {

  competicoes: Competicao[];
  loading: boolean;
  visualizar: boolean;
  competicaoSelecionada: Competicao;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private competicoesService: CompeticoesService,
    private oauthService: OauthService

  ) {
    this.breadcrumbService.setItems([
      { label: 'Competicoes', routerLink: ['/ipc/competicoes'], visible: true }
    ]);
  }

  ngOnInit() {
    this.competicaoSelecionada = new Competicao();
    this.loading = true;
    this.competicoesService.findAll(0)

      .subscribe(
        (dados: Page<Competicao>) => {
          this.competicoes = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
         // console.log("Passei ak");
         // console.log(dados);
        }
      )
  }

  excluir(competicao: Competicao) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a competição ${competicao.name}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.competicoesService.delete(competicao.cid)
          .subscribe(
            (competicao: Competicao) => {
              this.mostrarMensagemSucesso('Competicao removida com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.competicoesService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Competicao>) => {
          this.competicoes = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirCompeticao(competicao: Competicao) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
