import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Content } from '../content';
import { ContentService } from '../content.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Page } from 'src/app/utils/page';
import { GameService } from 'src/app/drdebug/game/game.service';
import { Game } from 'src/app/drdebug/game/game';
@Component({
  selector: 'app-cadastro-content',
  templateUrl: './cadastro-content.component.html',
  styleUrls: ['./cadastro-content.component.css']
})
export class CadastroContentComponent implements OnInit {
  titulo: string;
  content: Content;
  contents: Content[];
  listaGames: Game[];
  linguagem: SelectItem[];
  nivel: SelectItem[];
  constructor(private breadcrumbService: BreadcrumbService,
    private messageService: MessageService, private parceirosService: ContentService,
    private oauthService: OauthService, private activatedRoute: ActivatedRoute,
    private router: Router, private game: GameService) {
    this.content = new Content();
    const id = this.activatedRoute.snapshot.params['id'];
    if (id) {
      this.parceirosService.findById(id)
        .subscribe(
          (content: Content) => {
            if (content) {
              this.content = content;
              this.breadcrumbService.setItems([
                { label: 'Parceiros', routerLink: ['conteudo/listagemConteudo'], visible: true },
                { label: this.content.nome, routerLink: [`/conteudo/cadastro/${ id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/conteudo/listagemConteudo']);
            }

          }
        );
    }
    this.titulo = (id) ? 'Editar' : 'Cadastrar';
  }

  ngOnInit( ) {
    this.linguagem = [
      { label: 'Java', value: 'Java' },
      { label: 'C++', value: 'C' },
      { label: 'Portugol', value: 'Portugol' },
      { label: 'PAScal', value: 'PAScal' },
      { label: 'PHP', value: 'PHP' }
  ];
  this.nivel = [{ label: 'Iniciante', value: 'Iniciante' },
  { label: 'Medio', value: 'Medio' },
   { label: 'Avancado', value: 'Avancado' }
  ];
  }
  salvar() {
    const isCreate = !this.content.id;


    if (isCreate) {
      console.log(this.content.dataCriacao)
      this.parceirosService.insert(this.content)
        .subscribe(
          (content: Content) => {
            this.mostrarMensagemSucesso('Conteudo Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['conteudo/listagemConteudo']);
            }, 500);
          }
        );
    } else {
      this.parceirosService.update(this.content)
        .subscribe(
          (content: Content) => {
            this.mostrarMensagemSucesso('Pessoa Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['conteudo/listagemConteudo']);
            }, 500);
          }
        );
    }

  }

  findByNomeContent(nome: string) {
    return this.game.listar()
    .subscribe(
      (dados: Game[]) => {
      this.listaGames = dados;
      console.log("lista games", this.listaGames);
    })
  }
  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }
  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }


}
