import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import {Content} from '../content';
import {ContentService} from '../content.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';
@Component({
  selector: 'app-listagen-content',
  templateUrl: './listagen-content.component.html',
  styleUrls: ['./listagen-content.component.css']
})
export class ListagenContentComponent implements OnInit {
 content: Content[];
 loading: boolean;
 visualizar: boolean;
 contentSelecionado: Content;

 numTotal: number;
 filtro: string = '';
  constructor(  private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private contentService: ContentService) {
   this.breadcrumbService.setItems([
     {label: 'Content', routerLink: ['conteudo/cadastroConteudo'], visible: true}
   ]);
   }

  ngOnInit() {
    this.contentSelecionado = new Content();
    this.loading = true;
    this.contentService.findAll(0).subscribe
    ((dados: Page<Content>) => {
      this.content = dados.content;
      this.numTotal = dados.totalElements;
      this.loading = false;
    }
    );
  }
  excluir(content: Content) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o content de id ${content.id}`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
      this.contentService.delete(content.id).subscribe(
        (content: Content) => {
          this.mostrarMensagemSucesso('Pessoa removido com sucesso!');
          this.findByNome(this.filtro);
        }
        );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operacao foi realizada! ');
      }
    });
  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.contentService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Content>) => {
          this.content = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      );
  }
  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
  possuiPermissaoEditarExcluirPessoa(content: Content) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }
}
