import { Component, OnInit } from '@angular/core';
import { SelectItem } from 'primeng/api';
import { Disciplina } from '../../school/disciplina/disciplina';
import { DisciplinaService } from '../../school/disciplina/disciplina.service'
import { Page } from 'src/app/utils/page';
import { Game } from 'src/app/drdebug/game/game';
import { ActivatedRoute, Router } from '@angular/router';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { GameServiceService } from '../game-service.service';
import {MessageService} from 'primeng/components/common/messageservice';

@Component({
  selector: 'app-cadastro-game',
  templateUrl: './cadastro-game.component.html',
  styleUrls: ['./cadastro-game.component.css']
})
export class CadastroGameComponent implements OnInit {


  /* O que cadastro precisa ter????
      1) Método salvar
      2) Mensagens de Erro e Sucesso
      3) População dos dropdowns
    */


  /* Criação dos vetores de enumeráveis: */
  niveis: SelectItem[];
  tipos: SelectItem[];
  disciplinas: Disciplina[];

  /* Criação do objeto do tipo Game: */
  game: Game;

  /*Vamos criar uma variável título, 
  pois a mesma tela será usada para 
  editar e cadastrar games. Assim,
  para cada função, alteraremos o 
  título.*/
  titulo: string;

  constructor(
    /* Vamos criar variáveis objeto 
      relativos às importações acima:*/
    private disciplina: Disciplina,
    private disciplinaService: DisciplinaService,
    private activatedRoute: ActivatedRoute,
    private breadcrumbservice: BreadcrumbService,
    private gameService: GameServiceService,
    private router: Router,
    private mensageService: MessageService
  ) { 
    
    /*Essa classe funciona como uma classe
    factory. Seu sentido é criar e editar
    objetos. Por isso, primeiramente é 
    necessário que uma classe game seja 
    criado. E é salvo apenas quando isso 
    é exigido pelo usuário.*/

    /* Primeiro, vamos instanciar a classe 
    Game: */
    this.game = new Game();


    /* Segundamente, vamos criar uma variável
    para sabermos se o id passado existe ou 
    não no banco de dados.
    Para isso, vamos usar a interface 
    activatedRoute /,que contem a informação 
    sobre a rota carregada na saída.
    Nessa interface vamos acessar o snapshot,
    que possui informações sobre uma rota 
    associada a um "componente" carregado no 
    momento.
    No snapshot, acessaremos o "parents", 
    que é uma coleção de parâmetros.
    */

    const id = this.activatedRoute.snapshot.params['id'];

    /* Aqui, vamos tratar do breadcrumb.
      Esse componente é um componente do 
      primeNg. Esse componente é aquele
      retângulo superior que mostra de 
      forma simples o caminho percorrido 
      até este momento:
      Ipc > game > novo
    */

    this.breadcrumbservice.setItems([
      {label: 'Game', routerLink:['/ipc/game'], visible: true},
      { label: 'Editar', routerLink: ['/ipc/game/${id}'], visible: id!=undefined},
      { label: 'Novo', routerLink: ['/game/game/novo'], visible: !id}
    ])


    /* Abaixo vamos testar o valor da 
    variável id, declarada acima como 
    constante. 
    Caso seja true, vamos dizer que o
    game instanciado acima receberá o 
    valor desse id*/

    if(id){
      /*Caso o valor seja "positivo", 
      saberemos que existe um registro
      desse no banco de dados.Logo, 
      vamos buscá-lo: */

      this.gameService.findById(id).subscribe(
        (gameG: Game) =>{
          if(gameG){
            this.game = gameG;

            this.breadcrumbservice.setItems([
              {label: 'Ganes', routerLink: ['/ipc/game'], visible: true},
              {label: this.game.nome, routerLink: [`/ipc/game/${id}`], visible: true}
            ]);

          }else{
            this.router.navigate(['/ipc/game'])
          }
        }
      )
    }

    this.titulo = (id)? 'Editar': 'Cadastro';

  }

  ngOnInit() {

    console.log('Component Cadastro está começando!!!')
    /*  Esse métoco é executado logo após a
      inicialização das diretivas da classe.
      Esse método é definido para lidar com 
      tarefas adicionais da INICIALIZAÇão.
      Vamos definir aqui os enumeráveis 
      usados no cadastro: Tipo de Jogo, 
      Nível de Game.
      Vamos chamar os métodos de população:
      */

    this.populandoTipos();
    this.populandoNiveis();
   // this.populandoDisciplinas();   

  }


  /*Vamos definir métodos para popular os vetore para os dropdonws */
  populandoNiveis(){
    /* Vamos passar um vetor para essa essa
      variável com lable e valor: 
      label -> Valor a aparecer no html
      value -> Valor recebido pela api 
            e armazenado no banco de 
            Dados
      */
    this.niveis = [
      { label: 'Superior', value: 'SUPERIOR' },
      { label: 'Técnico', value: 'TECNICO'}
    ];
  }

  populandoTipos(){
     /* Vamos passar um vetor para essa essa
      variável com lable e seu valor: 
      label -> Valor a aparecer no html
      value -> Valor recebido pela api 
            e armazenado no banco de 
            Dados
      */      
    this.tipos=[
      { label: 'Rpg', value: 'RPG'},
      { label: 'Tabuleiro', value: 'TABULEIRO'}
      ];
  }

  /*populandoDisciplinas(){
    /* Vamos popular o dropdown de disciplinas.
      Esses valores devem vir do service de 
      disciplinas.
      Para isso, vamos definir uma função com
      o operador angular "=>". Com esse 
      operador, se fizermos (a)=>{}, estamos 
      fazendo o funcion(a){};
      Somado a isso, usaremos a função subscribe 
      da classe Observable. Esse método especifica
      um promisse, ou seja, uma promessa de envio.
      Desta forma, aquele que quer receber o resul-
      tado se "subscreve" e quando não quiser 
      receber mais, invalida a subscrição. Essa
      promessa está ligada a conceitos de programa-
      ção assíncrona, ou seja, a página continua a 
      ser construída enquanto os valores ainda 
      estão sendo buscados e devolvidos pela API.
      Isse esconde a demora, dando ao usuário a 
      impresão de fluidez na página, mesmo que 
      isso não ocorra sempre na prática.
      /-/-/-Falta um fechar comentário
    this.disciplinaService.findAll(0).subscribe(
      (dados: Page<Disciplina>)=>{
        /* Não encontrei material sobre, mas o 
          .content retorna todos os "Objetos" 
          para disciplina do findAll para. 
          Por que é necessário o subscribe??
          Pois como dissemos é necessário 
          fazer uma promessa. Em programação 
          assincrona, as coisas não ocorrem 
          necessáriamente na ordem. Neste 
          caso usamos o subscribe para requerer
          um promisse e assim, continuar 
          construindo a página web. Aqui, o 
          service de disciplina irá acessar a 
          api, que por sua vez, acessará o banco 
          de dados e retornara para a ui todos os 
          tipos disciplina cadastrados no Bd. 
          Isso pode ser lento e a página pode
          não executar.
          Falta um fechar comentário        
        /-/-/-this.disciplinas=dados.content;
      }
    )
}*/

  findByNomeDisciplina(nome: string){
    this.disciplinaService.listar().subscribe(
      (dados: Disciplina[])=>{
        this.disciplinas = dados;
        console.log("Find Disciplina", this.disciplinas);
      }
    )
  } 

  /* Vamos construir o método de salvamento para o cadastro. */
  salvar(){
    /* O que temos que fazer para 
    salvarmos um deteminado game?
    Primeiramente, vamos testar
    se esse id já existe no banco. 
    Como?
    Esse teste é feito na constante 
    declarada logo abaixo:
    */
    
    const isCreate = !this.game.id;

    /* Caso não seja criada ainda,
    vamos criar um Game */
    if(isCreate){
      this.gameService.insert(this.game).subscribe(
        (game: Game) => {
         
          this.mensagemSucesso('Cadastro Bem sucedido.')
          setTimeout(()=>{
            this.router.navigate(['/ipc/game'])
          }, 500)
        }
      )
    }else{
      
      this.gameService.update(this.game).subscribe(
        (game: Game) => {
          this.mensagemSucesso('Game Alterado sem erros');
          setTimeout(()=>{
            this.router.navigate(['/ipc/game'])
          }, 500)
        }
      )

    }
        
    
  }

  /* As mensagens seguintes são geradas pelo componente
  de mensagens do prime Ng. A sintaxe básica utilizada é:
  this.messageService.add({severity:'success', summary:'
      Service Message', detail:'Via MessageService'});
   */

  mensagemSucesso(mensagem: string){
   this.mensageService.add({severity:'success', summary:'Sua operação Foi Bem sucedida', detail:mensagem});
  }

  mensagemError(mensagem: string){
    this.mensageService.add({severity:'error', summary:'Sua operação foi finalizada com erro', detail:mensagem});
  }  

}
