import { Component, OnInit } from '@angular/core';
import { MessageService } from 'primeng/components/common/messageservice';
import { ConfirmationService } from 'primeng/api';
import { Game } from 'src/app/drdebug/game/game';
import { GameServiceService } from 'src/app/ipc/game/game-service.service';
import { Page } from 'src/app/utils/page';
import { BreadcrumbService } from 'src/app/breadcrumb.service';

@Component({
  selector: 'app-game-listagem',
  templateUrl: './game-listagem.component.html',
  styleUrls: ['./game-listagem.component.css']
})
export class GameListagemComponent implements OnInit {

  filtro: string = '';
  loading: boolean;
  numTot: number;

  /* Vamos criar um veto que armazene games. 
  Esse vetor será usado para listar e buscar 
  games: */

  games: Game[];
  gameSelect: Game;

  constructor(
    private mensageService: MessageService,
    private confirmationService: ConfirmationService,
    private gameService: GameServiceService,
    private breadcrumbservice: BreadcrumbService
  ) { 
    this.breadcrumbservice.setItems([
      {label: 'Game', routerLink: ['/ipc/game'], visible: true}
    ])
  }

  ngOnInit(){
  this.gameSelect = new Game();
  this.loading = true;
  this.gameService.findAll().subscribe(
    (dados: Page<Game>) =>{
      this.games = dados.content;
      this.numTot = dados.totalElements;
      this.loading = false;
    }
  )
  }


  delete(game: Game){
        /* Vamos criar a funcionalidade de exclusão.
    Antes de qualquer coisa, temos que permitir 
    ao usupario desfazer qualquer de suas ações.
    Por isso, lançaremos uma mensagem de confir-
    mação de exclussão:
    */

    this.confirmationService.confirm({
      message: `Deseja realmente excluir o game ${game.nome}?`,
      header:'Confirmação',
      icon: 'pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',

      /* Caso a resposta seja sim, vamos definir um
      método que define os acontecimentos da aceitação: */
      accept: ()=>{
        this.gameService.delete(game.id).subscribe(
          (game: Game) => {
            this.mensagemSucesso('Remoção efetuada com sucesso!');
            this.findByNome(this.filtro);
          }
        )
      },

      /* Caso a resposta seja não, vamos definir no
      método abaixo que uma mensagem de aviso seja
      impressa na tela. */
      reject: ()=>{
        this.mensagemInfo('Nenhuma remoção foi concluída.')
      }
    })
  }

  findByNome(nome: string){
    this.filtro = nome;
    this.loading = true;

    this.gameService.findByNome(nome).subscribe(
      (dados: Page<Game>) => {
        this.games = dados.content;
        this.numTot = dados.totalElements;
        this.loading = false;
      }
    )

  }

    /* As mensagens seguintes são geradas pelo componente
  de mensagens do prime Ng. A sintaxe básica utilizada é:
  this.messageService.add({severity:'success', summary:'
      Service Message', detail:'Via MessageService'});
   */
  mensagemSucesso(mensagem: string){
    this.mensageService.add({severity:'success', summary:'Sua operação Foi Bem sucedida', detail:mensagem});
   }
 
   mensagemError(mensagem: string){
     this.mensageService.add({severity:'error', summary:'Sua operação foi finalizada com erro', detail:mensagem});
   }  

   mensagemInfo(mensagem: string){
     this.mensageService.add({severity:'info', summary: 'Information', detail: mensagem});
   }
}
