import { Injectable } from '@angular/core';
import { Game } from './game';
import { environment } from 'src/environments/environment';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { Page } from 'src/app/utils/page';

@Injectable({
  providedIn: 'root'
})
export class GameServiceService {

  /* O que é um http??
  http é um protocolo proveniente da camada de rede, 
  definido pelo modelo OSI. Esse protocolo é na 
  prática um cabeçalho adicionado np pacote de dados
  para que esete(o pacote) esteja habilitado a ser
  transportado, estabelecendo uma conexão.*/

  /* Vamos definir as propriedades do protocolo e
  criar o cabeçalho: 
  Para isso, vamos conectar seu cabeçalho e passar um objeto 
  {} como parâmetro. Vejamos:
  */

  httpOptions = {
    headers: new HttpHeaders({
      /* Estamos estabelecendo que o tipo de conteúdo que será
      passado, será sempre um Json. Dessa maneira, definimos 
      nossa regra de cmunicação.*/
      'Content-Type': 'application/json'  
    })
  }

  /* Vamos criar a classe que faz conexão entre 
  a ui e a api. Essa classe é a conexão entre a 
  visão e o banco de dados. Para cria-la, preci-
  samos chamar a url que irá conectar a api ao 
  front end: */
  /*Inicialmente declaramos a url como uma string. */
  url: string;


  constructor(
    /* Agora vamos definir uma variável http
    como objeto de HttpClient. Essa HttpClient
    irá fornecer diversos serviços de 
    comunicação api<->ui, entre eles get, post, 
    delete ... atraveés de comunicação via Json.*/
    private http: HttpClient
    
  ) { 
    /* Vamos preencher o valor a string declarada acima 
    com um valor proveniente do endereço da api. Mas,
    onde esse endereço está armazenado?
    Simples, ele está na no pacote de environments. 
    Neste pacote existe um arquivo .ts contendo o endereço
    da api. Esse endereço é:
                "http://localhost:8080/restJPA"
    */ 
    this.url = `${environment.apiUrl}/drdebug/game/`;
  }

  findAll(){
        /* Vamos declarar nome como  vazio, pois não temos interesse em apenas um único game,
    mas queremos que todos os games resente no banco de dados sejam retornados. 
    Declaramos a variável nome como let, para que ao fim do escopo {}, ela deixe de 
    existir.*/
    let nome = '';
    /* Vamos usar http para acesar o método get e retornar todos os games salvos*/
    return this.http.get<Page<Game>>(`${this.url}?nome=${nome}`);
  }

  findById(id:number){
      /* Vamos acessar aqui o método findById da api que exige um id como parâmetro:
    public Optional<Game> findById(Long id);*/
    return this.http.get<Game>(`${this.url}?${id}`);
  }

  findByNome(nome: string){
    /* Vamos acessar aqui o método findByNome da api que exige um nome como parâmetro:
    public Optional<Game> findByNome(String nome);
    */
    return this.http.get<Page<Game>>(`${this.url}?nome=${nome}`)
  }

  update(game: Game){
    return this.http.put<Game>(`${this.url}/${game.id}`, game, this.httpOptions);
  }

  delete(id: number){
    return this.http.delete<Game>(`${this.url}/${id}`);
  }

  insert(game: Game){
    /* Estamos estabelecendo uma comunicação entre a ui e a api, passando um Json como
    Parâmetro para perpetuá-lo no banco de dados. Observe que httOption é passado por 
    parâetro, o mesmo que define o conteúdo do cabeçalho. */
    return this.http.post<Game>(this.url, game, this.httpOptions);
  }
}
