import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import * as moment from 'moment';
import { MultiplaEscolha } from '../multiplaescolha';
import { MultiplaEscolhaService } from '../multiplaescolha.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';
import { listAnimation } from 'src/app/animations';
@Component({
  selector: 'app-cadastrar-multiplaescolha',
  templateUrl: './cadastrar-multiplaescolha.component.html',
  styleUrls: ['./cadastrar-multiplaescolha.component.css'],
 
})
export class CadastroMultiplaEscolhaComponent implements OnInit {

  titulo: string;
  multiplaescolha: MultiplaEscolha;
  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
    calendarLocale: any;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private parceirosService: MultiplaEscolhaService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.multiplaescolha = new MultiplaEscolha();
    this.multiplaescolha.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Múltipla Escolha', routerLink: ['ipc/Multiplaescolha'], visible: true },
      { label: 'Editar', routerLink: [`/ipc/MultiplaEscolha/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/MultiplaEscolha/novo'], visible: !id },
    ]);
    if (id) {
      this.parceirosService.findById(id)
        .subscribe(
          (multiplaescolha: MultiplaEscolha) => {
            if (multiplaescolha) {
              this.multiplaescolha = multiplaescolha;

              this.breadcrumbService.setItems([
                { label: 'Múltipla Escolha', routerLink: ['ipc/MultiplaEscolha'], visible: true },
                { label: this.multiplaescolha.enunciado, routerLink: [`ipc/MultiplaEscolha/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['ipc/MultiplaEscolha']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

     this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }

  salvar() {
    const isCreate = !this.multiplaescolha.id;
    if (isCreate) {
      this.parceirosService.insert(this.multiplaescolha)
        .subscribe(
          (multiplaescolha: MultiplaEscolha) => {

            this.mostrarMensagemSucesso('Pessoa Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/MultiplaEscolha'])
            }, 500)
          }
        )
    } else {
      this.parceirosService.update(this.multiplaescolha)
        .subscribe(
          (multiplaescolha: MultiplaEscolha) => {
            this.mostrarMensagemSucesso('Pessoa Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/MultiplaEscolha'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
