import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MultiplaEscolha } from '../multiplaescolha';
import { MultiplaEscolhaService } from '../multiplaescolha.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listar-multiplaescolha',
  templateUrl: './listar-multiplaescolha.component.html',
  styleUrls: ['./listar-multiplaescolha.component.css']
})
export class ListagemMultiplaEscolhaComponent implements OnInit {

  multiplaescolhas: MultiplaEscolha[];
  loading: boolean;
  visualizar: boolean;
  multiplaescolhaSelecionado: MultiplaEscolha;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private multiplaescolhaService: MultiplaEscolhaService
  ) {
    this.breadcrumbService.setItems([
      { label: 'MultiplaEscolhaTeste', routerLink: ['ipc/MultiplaEscolha'], visible: true }
    ]);
  }

  ngOnInit() {
    this.multiplaescolhaSelecionado = new MultiplaEscolha();
    this.loading = true;
    this.multiplaescolhaService.findAll(0)
      .subscribe(
        (dados: Page<MultiplaEscolha>) => {
          this.multiplaescolhas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(multiplaescolha: MultiplaEscolha) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${multiplaescolha.id}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.multiplaescolhaService.delete(multiplaescolha.id)
          .subscribe(
            (multiplaescolha: MultiplaEscolha) => {
              this.mostrarMensagemSucesso('multiplaescolha removido com sucesso!');
            //  this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  

  possuiPermissaoEditarExcluirMultiplaEscolha(multiplaescolha: MultiplaEscolha) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
