import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Solucao } from '../solucao';
import { SolucaoService } from '../solucao.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-solucao',
  templateUrl: './cadastro-solucao.component.html',
  styleUrls: ['./cadastro-solucao.component.css']
})
export class CadastroSolucaoComponent implements OnInit {

  titulo: string;
  solucao: Solucao;

  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
  tiposopcaolinguagem: SelectItem[];
  sistemaoperacional: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private solucaoService: SolucaoService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.solucao = new Solucao();
    this.solucao.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    this.solucao.opcaolinguagem = (this.isAdministrador()) ? 'PHP' : 'C' ; 'PYTON';'JAVA';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Solucao', routerLink: ['/ipc/problemManager/solucao'], visible: true },
      { label: 'Editar', routerLink: [`/ipc/problemManager/solucao/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/problemManager/solucao/novo'], visible: !id },
    ]);
    if (id) {
      this.solucaoService.findById(id)
        .subscribe(
          (solucao: Solucao) => {
            if (solucao) {
              this.solucao = solucao;

              this.breadcrumbService.setItems([
                { label: 'Solucao', routerLink: ['/ipc/problemManager/solucao'], visible: true },
                { label: this.solucao.codigofonte, routerLink: [`/ipc/problemManager/solucao/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/ipc/problemManager/solucao']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tiposopcaolinguagem = [
      { label: 'PHP', value: 'PHP' },
      { label: 'C', value: 'C' },
      { label: 'PYTON', value: 'PYTON' },
      { label: 'JAVA', value: 'JAVA' }
    ];
  }

  salvar() {
    const isCreate = !this.solucao.id;
    if (isCreate) {
      this.solucaoService.insert(this.solucao)
        .subscribe(
          (solucao: Solucao) => {

            this.mostrarMensagemSucesso('Solucao cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/problemManager/solucao'])
            }, 500)
          }
        )
    } else {
      this.solucaoService.update(this.solucao)
        .subscribe(
          (solucao: Solucao) => {
            this.mostrarMensagemSucesso('Solucao alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/problemManager/solucao'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
