import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Solucao } from '../solucao';
import { SolucaoService } from '../solucao.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-solucao',
  templateUrl: './detalhes-solucao.component.html',
  styleUrls: ['./detalhes-solucao.component.css']
})
export class DetalhesSolucaoComponent implements OnInit {

  titulo: string; 
  solucao: Solucao;
  statusSolucao: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private solucaoService: SolucaoService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.solucao = new Solucao();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Solucao', routerLink: ['/ipc/problemManager/solucao'] , visible: true},
      { label: 'Editar', routerLink: [`/ipc/problemManager/solucao/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/problemManager/solucao/novo'] , visible: !id},
    ]);
    if (id) {
      this.solucaoService.findById(id)
        .subscribe(
          (solucao: Solucao) => {
            if(solucao){
              this.solucao = solucao;
              this.statusSolucao = (this.solucao.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Solucao', routerLink: ['/ipc/problemManager/solucao'] , visible: true},
                { label: this.solucao.codigofonte, routerLink: [`/ipc/problemManager/solucao/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/ipc/problemManager/solucao']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
