import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Solucao } from '../solucao';
import { SolucaoService } from '../solucao.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-solucao',
  templateUrl: './listagem-solucao.component.html',
  styleUrls: ['./listagem-solucao.component.css']
})
export class ListagemSolucaoComponent implements OnInit {

  solucoes: Solucao[];
  loading: boolean;
  visualizar: boolean;
  solucaoSelecionado: Solucao;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private solucaoService: SolucaoService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Solucao', routerLink: ['/ipc/problemManager/solucao'], visible: true }
    ]);
  }

  ngOnInit() {
    this.solucaoSelecionado = new Solucao();
    this.loading = true;
    this.solucaoService.findAll(0)
      .subscribe(
        (dados: Page<Solucao>) => {
          this.solucoes = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(solucao: Solucao) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${solucao.codigofonte}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.solucaoService.delete(solucao.id)
          .subscribe(
            (solucao: Solucao) => {
              this.mostrarMensagemSucesso('Solucao removido com sucesso!');
              this.findByCodigofonte(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByCodigofonte(codigofonte: string) {
    this.filtro = codigofonte;
    this.loading = true;
    this.solucaoService.findByCodigofonte(codigofonte, 0)
      .subscribe(
        (dados: Page<Solucao>) => {
          this.solucoes = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirSolucao(solucao: Solucao) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
