import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { CasosTeste } from '../casosTeste';
import { CasosTestesService } from '../casosTestes.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-casosTeste',
  templateUrl: './cadastro-casosTeste.component.html',
  styleUrls: ['./cadastro-casosTeste.component.css']
})
export class CadastroCasosTesteComponent implements OnInit {

  titulo: string;
  casosTeste: CasosTeste;

  nivelDificuldade: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private parceirosService: CasosTestesService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.casosTeste = new CasosTeste();
    //this.casosTeste.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Parceiros', routerLink: ['/ipc/problemManager/casosTeste'], visible: true },
      { label: 'Editar', routerLink: [`/ipc/problemManager/casosTeste/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/problemManager/casosTeste/novo'], visible: !id },
    ]);
    if (id) {
      this.parceirosService.findById(id)
        .subscribe(
          (casosTeste: CasosTeste) => {
            if (casosTeste) {
              this.casosTeste = casosTeste;

              this.breadcrumbService.setItems([
                { label: 'Parceiros', routerLink: ['/ipc/problemManager/casosTeste'], visible: true },
                { label: this.casosTeste.nome, routerLink: [`/ipc/problemManager/casosTeste/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/ipc/problemManager/casosTeste']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.nivelDificuldade = [
      { label: 'FÁCIL', value: 'FÁCIL' },
      { label: 'MÉDIO', value: 'MÉDIO' },
      { label: 'DIFÍCIL', value: 'DIFÍCIL' },
    ];

  }

  salvar() {
    const isCreate = !this.casosTeste.id;
    if (isCreate) {
      this.parceirosService.insert(this.casosTeste)
        .subscribe(
          (casosTeste: CasosTeste) => {

            this.mostrarMensagemSucesso('Casos de Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/problemManager/casosTeste'])
            }, 500)
          }
        )
    } else {
      this.parceirosService.update(this.casosTeste)
        .subscribe(
          (casosTeste: CasosTeste) => {
            this.mostrarMensagemSucesso('Casos de Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/problemManager/casosTeste'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
