import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { CasosTeste } from '../casosTeste';
import { CasosTestesService } from '../casosTestes.service';
import { ConfirmationService, MessageService, SelectItem } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-casosTeste',
  templateUrl: './listagem-casosTeste.component.html',
  styleUrls: ['./listagem-casosTeste.component.css']
})
export class ListagemCasosTesteComponent implements OnInit {

  casosTestes: CasosTeste[];
  loading: boolean;
  visualizar: boolean;
  casosTesteSelecionado: CasosTeste;
  nivelDificuldade: SelectItem[];

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private casosTesteService: CasosTestesService
  ) {
    this.breadcrumbService.setItems([
      { label: 'CasosTestes', routerLink: ['/ipc/problemManager/casosTestes'], visible: true }
    ]);
  }

  ngOnInit() {
    this.nivelDificuldade = [
      { label: 'FÁCIL', value: 'FÁCIL' },
      { label: 'MÉDIO', value: 'MÉDIO' },
      { label: 'DIFÍCIL', value: 'DIFÍCIL' },
    ];

    this.casosTesteSelecionado = new CasosTeste();
    this.loading = true;
    this.casosTesteService.findAll(0)
      .subscribe(
        (dados: Page<CasosTeste>) => {
          this.casosTestes = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(casosTeste: CasosTeste) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${casosTeste.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.casosTesteService.delete(casosTeste.id)
          .subscribe(
            (casosTeste: CasosTeste) => {
              this.mostrarMensagemSucesso('Casos de Teste removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.casosTesteService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<CasosTeste>) => {
          this.casosTestes = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirCasosTeste(casosTeste: CasosTeste) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
