import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Aluno } from '../aluno';
import { AlunoService } from '../aluno.service';
//import { Disciplina } from 'src/app/ipc/school/disciplina/disciplina';
//import { DisciplinaService } from 'src/app/ipc/school/disciplina/disciplina.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';
import { Page } from 'src/app/utils/page';

@Component({
  selector: 'app-cadastro-aluno',
  templateUrl: './cadastro-aluno.component.html',
  styleUrls: ['./cadastro-aluno.component.css']
})
export class CadastroAlunoComponent implements OnInit {

  titulo: string;
  aluno: Aluno;
  //disciplina: Disciplina[];
  calendarLocale: any;
  //tiposDesconto: SelectItem[];
  //tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
  tipossexo: SelectItem[];
  tiposcurso: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private alunoService: AlunoService,
    //private disciplinaService: DisciplinaService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.aluno = new Aluno();
    this.aluno.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.aluno.sexo = (this.isAdministrador()) ? 'sexo_1' : 'sexo_2' ;
    //this.aluno.curso = (this.isAdministrador()) ? 'curso_1' : 'curso_2' ; 'curso_3'; 'curso_4';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Aluno', routerLink: ['/ipc/school/aluno'], visible: true },
      { label: 'Editar', routerLink: [`/ipc/school/aluno/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/school/aluno/novo'], visible: !id },
    ]);
    if (id) {
      this.alunoService.findById(id)
        .subscribe(
          (aluno: Aluno) => {
            if (aluno) {
              this.aluno = aluno;
              this.aluno.dtnasc = new Date(aluno.dtnasc);
              this.breadcrumbService.setItems([
                { label: 'Aluno', routerLink: ['/ipc/school/aluno'], visible: true },
                { label: this.aluno.nome, routerLink: [`/ipc/school/aluno/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/ipc/school/aluno']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {
    this.calendarLocale = ConversorCalendario.getCalendarLocale();
    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    this.tipossexo = [
      { label: 'Masculino', value: 'Masculino' },
      { label: 'Feminino', value: 'Feminino' }
    ];
    this.tiposcurso = [
      { label: 'Desenvolvimento_de_Sistemas', value: 'Desenvolvimento_de_Sistemas' },
      { label: 'Química', value: 'Química' },
      { label: 'Edficações', value: 'Edficações' },
      { label: 'Metarlugia', value: 'Metarlugia' }
    ];
  }

 /* findByNome(nome: string) {
    this.disciplinaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Disciplina>) => {
          this.disciplina = dados.content;
        }
      )
  }*/

  salvar() {
    const isCreate = !this.aluno.id;
    if (isCreate) {
      this.alunoService.insert(this.aluno)
        .subscribe(
          (aluno: Aluno) => {

            this.mostrarMensagemSucesso('Aluno cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/school/aluno'])
            }, 500)
          }
        )
    } else {
      this.alunoService.update(this.aluno)
        .subscribe(
          (aluno: Aluno) => {
            this.mostrarMensagemSucesso('Aluno alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/ipc/school/aluno'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
