import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Aluno } from '../aluno';
import { AlunoService } from '../aluno.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-aluno',
  templateUrl: './detalhes-aluno.component.html',
  styleUrls: ['./detalhes-aluno.component.css']
})
export class DetalhesAlunoComponent implements OnInit {

  titulo: string;
  aluno: Aluno;
  statusAluno: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private alunoService: AlunoService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.aluno = new Aluno();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Aluno', routerLink: ['/ipc/school/aluno'] , visible: true},
      { label: 'Editar', routerLink: [`/ipc/school/aluno/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/ipc/school/aluno/novo'] , visible: !id},
    ]);
    if (id) {
      this.alunoService.findById(id)
        .subscribe(
          (aluno: Aluno) => {
            if(aluno){
              this.aluno = aluno;
              this.statusAluno = (this.aluno.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Aluno', routerLink: ['/ipc/school/aluno'] , visible: true},
                { label: this.aluno.nome, routerLink: [`/ipc/school/aluno/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/ipc/school/aluno']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
