import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Aluno } from '../aluno';
import { AlunoService } from '../aluno.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-aluno',
  templateUrl: './listagem-aluno.component.html',
  styleUrls: ['./listagem-aluno.component.css']
})
export class ListagemAlunoComponent implements OnInit {

  alunos: Aluno[];
  loading: boolean;
  visualizar: boolean;
  alunoSelecionado: Aluno;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private alunoService: AlunoService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Aluno', routerLink: ['/ipc/school/aluno'], visible: true }
    ]);
  }

  ngOnInit() {
    this.alunoSelecionado = new Aluno();
    this.loading = true;
    this.alunoService.findAll(0)
      .subscribe(
        (dados: Page<Aluno>) => {
          this.alunos = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(aluno: Aluno) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o aluno ${aluno.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.alunoService.delete(aluno.id)
          .subscribe(
            (aluno: Aluno) => {
              this.mostrarMensagemSucesso('Aluno removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

 findByNome(nome: string) {
   this.filtro = nome;
   this.loading = true;
   this.alunoService.findByNome(nome, 0)
     .subscribe(
       (dados: Page<Aluno>) => {
         this.alunos = dados.content;
         this.numTotal = dados.totalElements;
         this.loading = false;
       }
    )
  }

  possuiPermissaoEditarExcluirAluno(aluno: Aluno) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
