import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Disciplina } from '../disciplina';
import { DisciplinaService} from '../disciplina.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';

@Component({
  selector: 'app-cadastro-disciplina',
  templateUrl: './cadastro-disciplina.component.html',
  styleUrls: ['./cadastro-disciplina.component.css']
})

export class CadastroDisciplinaComponent implements OnInit {

  titulo: string;
  disciplina: Disciplina;

  tiposNivelEnsino: SelectItem[];
  tiposTempo: SelectItem[];
  tipoStatus: SelectItem[];

  calendarLocale: any;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private disciplinaService: DisciplinaService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.disciplina = new Disciplina();

    this.disciplina.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Disciplinas', routerLink: ['ipc/school/disciplina'], visible: true },
      { label: 'Editar', routerLink: [`ipc/school/disciplina${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['ipc/school/disciplina/novo'], visible: !id },
    ]);
    if (id) {
      this.disciplinaService.findById(id)
        .subscribe(
          (disciplina: Disciplina) => {
            if (disciplina) {
              this.disciplina = disciplina;
              this.disciplina.dtCadastro = new Date(disciplina.dtCadastro);
              this.breadcrumbService.setItems([
                { label: 'Disciplinas', routerLink: ['ipc/school/disciplina'], visible: true },
                { label: this.disciplina.nome, routerLink: [`ipc/school/disciplina/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['ipc/school/disciplina']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    
    this.tiposNivelEnsino = [
      { label: 'Infantil', value: 'INFANTIL' },
      { label: 'Fundamental', value: 'FUNDAMENTAL' },
      { label: 'Médio ', value: 'MÉDIO' },
      { label: 'Superior', value: 'SUPERIOR' }
    ];

    this.tiposTempo = [
      { label: 'Anual', value: 'ANUAL' },
      { label: 'Semestral', value: 'SEMESTRAL' }
    ];

    this.calendarLocale = ConversorCalendario.getCalendarLocale();

  }

  salvar() {
    const isCreate = !this.disciplina.id;
    if (isCreate) {
      this.disciplinaService.insert(this.disciplina)
        .subscribe(
          (disciplina: Disciplina) => {

            this.mostrarMensagemSucesso('Disciplina cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/school/disciplina'])
            }, 500)
          }
        )
    } else {
      this.disciplinaService.update(this.disciplina)
        .subscribe(
          (disciplina: Disciplina) => {
            this.mostrarMensagemSucesso('Disciplina alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/school/disciplina'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
