import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Disciplina } from '../disciplina';
import { DisciplinaService } from '../disciplina.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-disciplina',
  templateUrl: './detalhes-disciplina.component.html',
  styleUrls: ['./detalhes-disciplina.component.css']
})
export class DetalhesDisciplinaComponent implements OnInit {

  titulo: string;
  disciplina: Disciplina;
  statusDisciplina: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private disciplinaService: DisciplinaService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.disciplina = new Disciplina();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Disciplina', routerLink: ['ipc/school/disciplina'] , visible: true},
      { label: 'Editar', routerLink: [`ipc/school/disciplina/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['ipc/school/disciplina/novo'] , visible: !id},
    ]);
    if (id) {
      this.disciplinaService.findById(id)
        .subscribe(
          (disciplina: Disciplina) => {
            if(disciplina){
              this.disciplina = disciplina;
              this.statusDisciplina = (this.disciplina.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Disciplina', routerLink: ['ipc/school/disciplina'] , visible: true},
                { label: this.disciplina.nome, routerLink: [`ipc/school/disciplina/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['ipc/school/disciplina']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
