import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Disciplina } from '../disciplina';
import { DisciplinaService } from '../disciplina.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-disciplina',
  templateUrl: './listagem-disciplina.component.html',
  styleUrls: ['./listagem-disciplina.component.css']
})
export class ListagemDisciplinaComponent implements OnInit {

  disciplinas: Disciplina[];
  loading: boolean;
  visualizar: boolean;
  disciplinaSelecionado: Disciplina;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private disciplinaService: DisciplinaService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Disciplina', routerLink: ['/ipc/school/disciplina'], visible: true }
    ]);
  }

  ngOnInit() {
    this.disciplinaSelecionado = new Disciplina();
    this.loading = true;
    this.disciplinaService.findAll(0)
      .subscribe(
        (dados: Page<Disciplina>) => {
          this.disciplinas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(disciplina: Disciplina) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a disciplina ${disciplina.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.disciplinaService.delete(disciplina.id)
          .subscribe(
            (disciplina: Disciplina) => {
              this.mostrarMensagemSucesso('Disciplina removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.disciplinaService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Disciplina>) => {
          this.disciplinas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirDisciplina(disciplina: Disciplina) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}