import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Universidade } from '../universidade';
import { UniversidadeService} from '../universidade.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-universidade',
  templateUrl: './cadastro-universidade.component.html',
  styleUrls: ['./cadastro-universidade.component.css']
})

export class CadastroUniversidadeComponent implements OnInit {

  titulo: string;
  universidade: Universidade;

  cursos: SelectItem[];
  estados: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private universidadeService: UniversidadeService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {

    this.universidade = new Universidade();

    this.universidade.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Universidades', routerLink: ['ipc/school/universidade'], visible: true },
      { label: 'Editar', routerLink: [`ipc/school/universidade${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['ipc/school/universidade/novo'], visible: !id },
    ]);
    if (id) {
      this.universidadeService.findById(id)
        .subscribe(
          (universidade: Universidade) => {
            if (universidade) {
              this.universidade = universidade;

              this.breadcrumbService.setItems([
                { label: 'Universidades', routerLink: ['ipc/school/universidade'], visible: true },
                { label: this.universidade.nome, routerLink: [`ipc/school/universidade/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['ipc/school/universidade']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.cursos = [
      {label: 'Desenvolvimento de Software', value: 'DESENVOLVIMENTO_DE_SOFTWARE' },      
      {label: 'Química', value: 'QUIMICA'},
      {label: 'Edificações', value: 'EDIFICAÇOES'},
      {label: 'Engenharia de Computação', value: 'ENGENHARIA_DE_COMPUTAÇAO'},
      {label: 'Engenharia Mecanica', value: 'ENGENHARIA_MECANICA'},
      {label: 'Engenharia Civil', value: 'ENGENHARIA_CIVIL'},
      {label: 'Engenharia de Software', value: 'ENGENHARIA_DE_SOFTWARE'},

    ];
    
    this.estados = [
      {label: 'Acre', value: 'AC' },      
      {label: 'Alagoas', value: 'AL'},
      {label: 'Amapá', value: 'AP'},
      {label: 'Amazonas', value: 'AM'},
      {label: 'Bahia', value: 'BA'},
      {label: 'Ceará', value: 'CE'},
      {label: 'Distrito Federal', value: 'DF'},
      {label: 'Espírito Santo', value: 'ES' },      
      {label: 'Goiás', value: 'GO'},
      {label: 'Maranhão', value: 'MA'},
      {label: 'Mato Grosso', value: 'MT'},
      {label: 'Mato Grosso do Sul', value: 'MS'},
      {label: 'Minas Gerais', value: 'MG'},
      {label: 'Pará', value: 'PA'},
      {label: 'Paraíba', value: 'PB' },      
      {label: 'Paraná', value: 'PR'},
      {label: 'Pernambuco', value: 'PE'},
      {label: 'Piauí', value: 'PI'},
      {label: 'Rio de Janeiro', value: 'RJ'},
      {label: 'Rio Grande Do Norte', value: 'RN'},
      {label: 'Rio Grande do Sul', value: 'RS'},
      {label: 'Rondônia', value: 'RO' },      
      {label: 'Roraima', value: 'RR'},
      {label: 'Santa Catarina', value: 'SC'},
      {label: 'São Paulo', value: 'SP'},
      {label: 'Sergipe', value: 'SE'},
      {label: 'Tocantins', value: 'TO'},

    ];

  }

  salvar() {
    const isCreate = !this.universidade.id;
    if (isCreate) {
      this.universidadeService.insert(this.universidade)
        .subscribe(
          (universidade: Universidade) => {

            this.mostrarMensagemSucesso('Universidade cadastrada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/school/universidade'])
            }, 500)
          }
        )
    } else {
      this.universidadeService.update(this.universidade)
        .subscribe(
          (universidade: Universidade) => {
            this.mostrarMensagemSucesso('Universidade alterada com sucesso!');
            setTimeout(() => {
              this.router.navigate(['ipc/school/universidade'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
