import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Universidade } from '../universidade';
import { UniversidadeService } from '../universidade.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-universidade',
  templateUrl: './detalhes-universidade.component.html',
  styleUrls: ['./detalhes-universidade.component.css']
})
export class DetalhesUniversidadeComponent implements OnInit {

  titulo: string;
  universidade: Universidade;
  statusUniversidade: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private universidadeService: UniversidadeService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.universidade = new Universidade();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Universidade', routerLink: ['ipc/school/universidade'] , visible: true},
      { label: 'Editar', routerLink: [`ipc/school/universidade/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['ipc/school/universidade/novo'] , visible: !id},
    ]);
    if (id) {
      this.universidadeService.findById(id)
        .subscribe(
          (universidade: Universidade) => {
            if(universidade){
              this.universidade = universidade;
              this.statusUniversidade = (this.universidade.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Universidade', routerLink: ['ipc/school/universidade'] , visible: true},
                { label: this.universidade.nome, routerLink: [`ipc/school/universidade/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['ipc/school/universidade']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
