import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Universidade } from '../universidade';
import { UniversidadeService } from '../universidade.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-universidade',
  templateUrl: './listagem-universidade.component.html',
  styleUrls: ['./listagem-universidade.component.css']
})
export class ListagemUniversidadeComponent implements OnInit {

  universidades: Universidade[];
  loading: boolean;
  visualizar: boolean;
  universidadeSelecionado: Universidade;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private universidadeService: UniversidadeService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Universidade', routerLink: ['/ipc/school/universidade'], visible: true }
    ]);
  }

  ngOnInit() {
    this.universidadeSelecionado = new Universidade();
    this.loading = true;
    this.universidadeService.findAll(0)
      .subscribe(
        (dados: Page<Universidade>) => {
          this.universidades = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(universidade: Universidade) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a universidade ${universidade.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.universidadeService.delete(universidade.id)
          .subscribe(
            (universidade: Universidade) => {
              this.mostrarMensagemSucesso('Universidade removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.universidadeService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Universidade>) => {
          this.universidades = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirUniversidade(universidade: Universidade) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}