import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Validators, FormControl, FormGroup, FormBuilder, FormControlDirective } from '@angular/forms';
import { SubmissionClass } from '../submission';
import { SubmissionService } from '../submission.service';
import { MessageService } from 'primeng/api';
import { Competicao } from '../../competicao/competicao';
import { CompeticoesService } from '../../competicao/competicoes.service';
import { Page } from 'src/app/utils/page';
import { TimeService } from 'src/app/drdebug/time/time.service';
import { Time } from 'src/app/drdebug/time/time';

@Component({
  selector: 'app-cadastrar-submission',
  templateUrl: './cadastrar-submission.component.html',
  styleUrls: ['./cadastrar-submission.component.css']
})

export class CadastrarSubmissionComponent implements OnInit {

  userform: FormGroup;
  visualizar: boolean;
  selectedValue: string = 'val1';
  submission: SubmissionClass;
  contests: Competicao[];
  selectedContest: Competicao;
  teams: Time[];
  selectedTeam: Time;


  constructor(
    private submissionService: SubmissionService,
    private competicaoService: CompeticoesService,
    private teamService: TimeService,
    private messageService: MessageService,
    private breadcrumbService: BreadcrumbService,
    private fb: FormBuilder
  ) {

    this.contests = [];
    this.submission = new SubmissionClass;
    this.selectedContest = new Competicao;
    this.selectedTeam = new Time;
    this.breadcrumbService.setItems([
      { label: 'Submission', routerLink: ['/ipc/submissoes'], visible: true },
      { label: 'Novo', routerLink: ['/ipc/submissoes/novo'], visible: true }
    ]);
    console.log('contests: ', this.contests);
  }

  ngOnInit() {

    this.userform = this.fb.group({
      'contestForm': new FormControl(''),
      'teamForm': new FormControl(''),
      'entr': new FormControl('', Validators.required),
      'hjud': new FormControl('', Validators.required),
      'sid': new FormControl('', Validators.required),
      'pid': new FormControl('', Validators.required),
      'tim': new FormControl('', Validators.required),
      'lid': new FormControl('', Validators.required),
      'resesp': new FormControl('', Validators.required),
      'val': new FormControl('val1'),
      'exid': new FormControl(''),
      'orsid': new FormControl(''),
      'rejid': new FormControl(''),
      'resext': new FormControl('')
    });

    this.competicaoService.returnAllContests().subscribe((dados: Page<Competicao>) => {
      this.contests = dados.content;
    });

    this.teamService.findAll(0).subscribe((dados: Page<Time>) => {
      this.teams = dados.content;
    });
  }

  adicionar() {

    console.log("Nova Submission:\n", this.submission);

    this.submission["valid"] = ( this.selectedValue === "val1" ) ? 1 : 0;
    this.submission["submittime"] = Number(this.submission["submittime"]);
    this.submission["submitid"] = Number(this.submission["submitid"]);
    this.submission["probid"] = Number(this.submission["probid"]);
    this.submission["origsubmitid"] = Number(this.submission["origsubmitid"]);
    this.submission["langid"] = Number(this.submission["langid"]);
    this.submission["cid"] = Number(this.submission["cid"]);
    this.submission["teamid"] = Number(this.submission["teamid"]);
    this.submission["rejudgingid"] = Number(this.submission["rejudgingid"]);
    this.submission["externalid"] = this.submission["externalid"];

    this.submissionService
      .adicionar(this.submission)
      .subscribe(() => {
        this.submission = new SubmissionClass;
        this.messageService.add({
          severity: 'success',
          summary: 'Submission cadastrada!'
        });

      },
        error => {
          let msg = 'Erro durante o cadastro. Tente novamente';
          if (error.error.message) {
            msg = error.error.message;
          }
          this.messageService.add({
            severity: 'error',
            summary: msg
          });
        });
  }

  limpar() {
    this.submission = new SubmissionClass;
  }
}