import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { SubmissionClass } from '../submission';
import { MessageService } from 'primeng/api';
import { SubmissionService } from '../submission.service';
import { ActivatedRoute, Router } from '@angular/router';
import { ProgressSpinnerModule } from 'primeng/progressspinner';

@Component({
    selector: 'app-detalhar-submission',
    templateUrl: './detalhar-submission.component.html',
    styleUrls: ['./detalhar-submission.component.css']
})
export class DetalharSubmissionComponent implements OnInit {

    id: number;

    titulo: string;
    submission: SubmissionClass;
    statusSubmission: boolean = true;

    autoRefresh: boolean;
    destroyed: boolean;
    autoRefreshInterval: number = 1000;


    cols: any[];
    loading: boolean;

    constructor(
        private breadcrumbService: BreadcrumbService,
        private messageService: MessageService,
        private submissionService: SubmissionService,
        private activatedRoute: ActivatedRoute,
        private router: Router
    ) {

        this.submission = new SubmissionClass();

        const id = this.activatedRoute.snapshot.params['id'];

        this.breadcrumbService.setItems([
            { label: 'Submission', routerLink: ['/ipc/submissoes'], visible: true },
            { label: 'Editar', routerLink: [`/testes/submissoes/editar/${id}`], visible: id != undefined },
            { label: 'Novo', routerLink: ['/testes/submissoes/novo'], visible: !id },
        ]);




        if (id) {

            this.id = id;
            this.autoRefresh = true;
            this.loading = true;
            this.refresh();
        }

        this.titulo = 'Detalhes';
    }

    ngOnInit() {
    }

    ngOnDestroy() {
        this.destroyed = true;
        this.autoRefresh = false;
    }


    mostrarMensagemErro(mensagem: string) {
        this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
    }

    mostrarMensagemInfo(mensagem: string) {
        this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
    }

    mostrarMensagemSucesso(mensagem: string) {
        this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
    }


    refresh() {
        if (this.destroyed)
            return;

        this.submissionService
            .get(this.id)
            .subscribe(
                (submission: SubmissionClass) => {
                    if (submission) {
                        this.submission = submission;

                        this.breadcrumbService.setItems([
                            { label: 'Submission', routerLink: ['/ipc/submissoes'], visible: true },
                            { label: `${this.submission.submitid}`, routerLink: [`/ipc/submissoes/detalhes/${this.id}`], visible: true }
                        ]);

                        this.loading = false;

                        if (this.autoRefresh) {
                            setTimeout(() => this.refresh(), this.autoRefreshInterval);
                        }
                    } else {
                        this.router.navigate(['/ipc/submissoes']);
                    }
                }
            )


    }

    selectAllContent($event) {
        $event.target.select();
    }
}
