import { Component, OnInit } from '@angular/core';
import { Submission } from '../submission-model';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { ConfirmationService, MessageService, MenuItem } from 'primeng/api';
import { SubmissionService } from '../submission.service'
import { Router } from '@angular/router';
import { SubmissionClass } from '../submission';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Page } from 'src/app/utils/page';

@Component({
  selector: 'app-listar-submission',
  templateUrl: './listar-submission.component.html',
  styleUrls: ['./listar-submission.component.css']
})

export class ListarSubmissionComponent implements OnInit {

  submission: SubmissionClass;
  defaultValue: boolean = true;
  submissions: Submission[] = [];
  submissionSelecionada: Submission;
  visualizar: boolean;

  filtro: string = '';
  loading: boolean;

  constructor(
    private submissionService: SubmissionService,
    private messageService: MessageService,
    private router: Router,
    private breadcrumbService: BreadcrumbService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
  ) {

    this.breadcrumbService.setItems([
      { label: 'Submission', routerLink: ['/ipc/submissoes'], visible: true }
    ]);

    this.submissionSelecionada = new SubmissionClass();

  }

  ngOnInit() {
    this.consultar();
  }

  consultar() {
    this.submissionService
      .listar(0)
      .subscribe((response: Page<Submission>) => {
        this.submissions = response.content;
        // console.log(response);
        console.log(this.submissions);
      });
  }

  excluir(submission: SubmissionClass) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a submissão nº ${submission.submitid}`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.submissionService.delete(submission.submitid)
          .subscribe(
            (submission: SubmissionClass) => {
              this.mostrarMensagemSucesso('Submission removida!');
              this.consultar();
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Exclusão cancelada');
      }
    });
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
      
  visualizarDialog(submission: SubmissionClass) {
    this.submissionSelecionada = submission;
    this.visualizar = true;
  }

  closeDialog() {
    this.visualizar = false;
  }

  possuiPermissaoEditarExcluirSubmission() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }
}
