import { Injectable } from '@angular/core';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { Submission } from './submission-model';
import { Page } from 'src/app/utils/page';
import { environment } from 'src/environments/environment';

@Injectable({
    providedIn: 'root'
})

export class SubmissionService {

    apiUrl = `${environment.apiUrl}/submission/`

    httpOptions = {
        headers: new HttpHeaders({
            'Content-Type': 'application/json',
        })
    };

    constructor(private httpCliente: HttpClient) { }

    get(id: number) {
        return this.httpCliente.get(`${this.apiUrl}/${id}`);
    }

    listar(pagina: number) {
        let query = '';
        return this.httpCliente.get<Page<Submission>>(`${this.apiUrl}?query=${query}&pagina=${pagina}`);
    }


    listarByQuery(query: string, pagina: number) {
        return this.httpCliente.get<Page<Submission>>(`${this.apiUrl}?nome=${query}&pagina=${pagina}`);
    }

    adicionar(submission: any) {
        return this.httpCliente.post(`${this.apiUrl}`, submission);
    }

    delete(id: number) {
        return this.httpCliente.delete(`${this.apiUrl}${id}`);
    }

    update(submission: any) {
        return this.httpCliente.put(`${this.apiUrl}${submission.id}`, submission, this.httpOptions);
    }

    getClassDiagramUrl(submission: Submission): string {
        return `${this.apiUrl}${submission.submitid}/class-diagram.png`;
    }

    getClassDiagramThumbnailUrl(submission: Submission): string {
        return `${this.apiUrl}${submission.submitid}/class-diagram-thumbnail.png`;
    }

    getSequenceDiagramUrl(submission: Submission): string {
        return `${this.apiUrl}${submission.submitid}/sequence-diagram.png`;
    }

    getSequenceDiagramThumbnailUrl(submission: Submission): string {
        return `${this.apiUrl}${submission.submitid}/sequence-diagram-thumbnail.png`;
    }
}