import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Computador } from '../computador';
import { ComputadoresService } from '../computadores.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-computador',
  templateUrl: './cadastro-computador.component.html',
  styleUrls: ['./cadastro-computador.component.css']
})
export class CadastroComputadorComponent implements OnInit {

  titulo: string;
  computador: Computador;

  marca: SelectItem[];
  cor: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private computadoresService: ComputadoresService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.computador = new Computador();
    this.computador.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Computadores', routerLink: ['/laboratory/computadores'], visible: true },
      { label: 'Editar', routerLink: [`/laboratory/computadores/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/computadores/novo'], visible: !id },
    ]);
    if (id) {
      this.computadoresService.findById(id)
        .subscribe(
          (computador: Computador) => {
            if (computador) {
              this.computador = computador;

              this.breadcrumbService.setItems([
                { label: 'computadores', routerLink: ['/laboratory/computadores'], visible: true },
                { label: this.computador.modelo, routerLink: [`/laboratory/computadores/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/laboratory/computadores']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.marca = [
      { label: 'Sony', value: 'SONY' },
      { label: 'Acer', value: 'Acer' },
      { label: 'Samsung', value: 'SAMSUNG' },
      { label: 'Positivo', value: 'Positivo' },
      { label: 'Lenovo', value: 'LENOVO' },
      { label: 'DELL', value: 'DELL' },
      { label: 'HP', value: 'HP' }
    ];

    this.cor = [
      { label: 'Preto', value: 'Preto' },
      { label: 'Branco', value: 'Branco' },
      { label: 'Vermelho', value: 'Vermelho' },
      { label: 'Cinza', value: 'Cinza' },
      { label: 'Rosa', value: 'Rosa' },
    ];

  }

  salvar() {
    const isCreate = !this.computador.id;
    if (isCreate) {
      this.computadoresService.insert(this.computador)
        .subscribe(
          (computador: Computador) => {

            this.mostrarMensagemSucesso('Computador cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/computadores'])
            }, 500)
          }
        )
    } else {
      this.computadoresService.update(this.computador)
        .subscribe(
          (computador: Computador) => {
            this.mostrarMensagemSucesso('Computador alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/computadores'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
