import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Computador } from '../computador';
import { ComputadoresService } from '../computadores.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-computador',
  templateUrl: './detalhes-computador.component.html',
  styleUrls: ['./detalhes-computador.component.css']
})
export class DetalhesComputadorComponent implements OnInit {

  titulo: string;
  computador: Computador;
  statusComputador: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private computadoresService: ComputadoresService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.computador = new Computador();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Computadores', routerLink: ['/laboratory/computadores'] , visible: true},
      { label: 'Editar', routerLink: [`/laboratory/computadores/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/computadores/novo'] , visible: !id},
    ]);
    if (id) {
      this.computadoresService.findById(id)
        .subscribe(
          (computador: Computador) => {
            if(computador){
              this.computador = computador;
              this.statusComputador = (this.computador.status == 'ATIVO');
              this.breadcrumbService.setItems([
                { label: 'Computadores', routerLink: ['/computadores'] , visible: true},
                { label: this.computador.modelo, routerLink: [`/computadores/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/laboratory/computadores']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
