import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Computador } from '../computador';
import { ComputadoresService } from '../computadores.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-computador',
  templateUrl: './listagem-computador.component.html',
  styleUrls: ['./listagem-computador.component.css']
})
export class ListagemComputadorComponent implements OnInit {

  computadores: Computador[];
  loading: boolean;
  visualizar: boolean;
  computadorSelecionado: Computador;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private computadorService: ComputadoresService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Computadores', routerLink: ['/computadores'], visible: true }
    ]);
  }

  ngOnInit() {
    this.computadorSelecionado = new Computador();
    this.loading = true;
    this.computadorService.findAll(0)
      .subscribe(
        (dados: Page<Computador>) => {
          this.computadores = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(computador: Computador) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${computador.modelo}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.computadorService.delete(computador.id)
          .subscribe(
            (computador: Computador) => {
              this.mostrarMensagemSucesso('Computador removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(modelo: string) {
    this.filtro = modelo;
    this.loading = true;
    this.computadorService.findByNome(modelo, 0)
      .subscribe(
        (dados: Page<Computador>) => {
          this.computadores = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirComputador(computador: Computador) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
