import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Hardware } from '../hardware';
import { HardwareService } from '../hardware.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';


@Component({
  selector: 'app-cadastro-hardware',
  templateUrl: './cadastro-hardware.component.html',
  styleUrls: ['./cadastro-hardware.component.css']
})
export class CadastroHardwareComponent implements OnInit {

  titulo: string;
  hardware: Hardware;

  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private hardwareService: HardwareService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.hardware = new Hardware();
    this.hardware.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.hardware.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.hardware.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Hardware', routerLink: ['/laboratory/hardware'], visible: true },
      { label: 'Editar', routerLink: [`/laboratory/hardware/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/hardware/novo'], visible: !id },
    ]);
    if (id) {
      this.hardwareService.findById(id)
        .subscribe(
          (hardware: Hardware) => {
            if (hardware) {
              this.hardware = hardware;

              this.breadcrumbService.setItems([
                { label: 'Hardwares', routerLink: ['/laboratory/hardware'], visible: true },
                { label: this.hardware.modelo, routerLink: [`/laboratory/hardware/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/laboratory/hardware']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

  }

  salvar() {
    const isCreate = !this.hardware.id;
    if (isCreate) {
      this.hardwareService.insert(this.hardware)
        .subscribe(
          (hardware: Hardware) => {

            this.mostrarMensagemSucesso('Hardware cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/hardware'])
            }, 500)
          }
        )
    } else {
      this.hardwareService.update(this.hardware)
        .subscribe(
          (hardware: Hardware) => {
            this.mostrarMensagemSucesso('Hardware alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/hardware'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
