import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Hardware } from '../hardware';
import { HardwareService } from '../hardware.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-hardware',
  templateUrl: './detalhes-hardware.component.html',
  styleUrls: ['./detalhes-hardware.component.css']
})
export class DetalhesHardwareComponent implements OnInit {

  titulo: string;
  hardware: Hardware;
  statusHardware: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private hardwareService: HardwareService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.hardware = new Hardware();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Hardware', routerLink: ['/laboratory/hardware/'] , visible: true},
      { label: 'Editar', routerLink: [`/laboratory/hardware/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/hardware/novo'] , visible: !id},
    ]);
    if (id) {
      this.hardwareService.findById(id)
        .subscribe(
          (hardware: Hardware) => {
            if(hardware){
              this.hardware = hardware;
              this.statusHardware = (this.hardware.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Hardwares', routerLink: ['/laboratory/hardware'] , visible: true},
                { label: this.hardware.marca, routerLink: [`/laboratory/hardware/${id}`] , visible: true},
                { label: this.hardware.modelo, routerLink: [`/laboratory/hardware/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/laboratory/hardware']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
