import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Hardware } from '../hardware';
import { HardwareService } from '../hardware.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-hardware',
  templateUrl: './listagem-hardware.component.html',
  styleUrls: ['./listagem-hardware.component.css']
})
export class ListagemHardwareComponent implements OnInit {

  hardwares: Hardware[];
  loading: boolean;
  visualizar: boolean;
  hardwareSelecionado: Hardware;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private hardwareService: HardwareService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Hardware', routerLink: ['/laboratory/hardware'], visible: true }
    ]);
  }

  ngOnInit() {
    this.hardwareSelecionado = new Hardware();
    this.loading = true;
    this.hardwareService.findAll(0)
      .subscribe(
        (dados: Page<Hardware>) => {
          this.hardwares = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(hardware: Hardware) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${hardware.modelo}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.hardwareService.delete(hardware.id)
          .subscribe(
            (hardware: Hardware) => {
              this.mostrarMensagemSucesso('Hardware removido com sucesso!');
              this.findByModelo(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByModelo(modelo: string) {
    this.filtro = modelo;
    this.loading = true;
    this.hardwareService.findByModelo(modelo, 0)
      .subscribe(
        (dados: Page<Hardware>) => {
          this.hardwares = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirHardware(hardware: Hardware) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
