import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Problema } from '../problema';
import { ProblemasService } from '../problemas.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';
import { PessoaT } from 'src/app/testes/pessoat/pessoat';
import { PessoasTService } from 'src/app/testes/pessoat/pessoast.service';
import { Page } from 'src/app/utils/page';
@Component({
  selector: 'app-cadastro-problema',
  templateUrl: './cadastro-problema.component.html',
  styleUrls: ['./cadastro-problema.component.css']
})
export class CadastroProblemaComponent implements OnInit {

  titulo: string;
  problema: Problema;
  autores: PessoaT[];
  tipoStatus: SelectItem[];
  tipoProblemas: SelectItem[];
  calendarLocale: any;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private problemasService: ProblemasService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private autorService: PessoasTService,
    private router: Router
  ) {
    this.problema = new Problema();
    this.problema.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Problemas', routerLink: ['/laboratory/problemas'], visible: true },
      { label: 'Editar', routerLink: [`/laboratory/problemas/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/problemas/novo'], visible: !id },
    ]);
    if (id) {
      this.problemasService.findById(id)
        .subscribe(
          (problema: Problema) => {
            if (problema) {
              this.problema = problema;
              this.problema.data = new Date(problema.data);
              this.breadcrumbService.setItems([
                { label: 'problemas', routerLink: ['/laboratory/problemas'], visible: true },
                { label: this.problema.titulo, routerLink: [`/laboratory/problemas/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/laboratory/problemas']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.tipoProblemas = [
      { label: 'Iluminação', value: 'ILUMINACAO' },
      { label: 'Hardware', value: 'HARDWARE' },
      { label: 'Software', value: 'SOFTWARE' },
      { label: 'Tomada', value: 'TOMADA' },
      { label: 'Lixo', value: 'LIXO' },
    ];
    this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }
  
  findByNome(nome: string) {
    this.autorService.findByFiltro(nome, 0)
      .subscribe(
        (dados: Page<PessoaT>) => {
          this.autores = dados.content;
        }
      )
  }

  salvar() {
    const isCreate = !this.problema.id;
    console.log(this.problema);
    if (isCreate) {
      this.problemasService.insert(this.problema)
        .subscribe(
          (problema: Problema) => {

            this.mostrarMensagemSucesso('Problema Técnico cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/problemas'])
            }, 500)
          }
        )
    } else {
      console.log(this.problema);
      this.problemasService.update(this.problema)
        .subscribe(
          (problema: Problema) => {
            this.mostrarMensagemSucesso('Problema Técnico alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/problemas'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
