import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Problema } from '../problema';
import { ProblemasService } from '../problemas.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-problema',
  templateUrl: './detalhes-problema.component.html',
  styleUrls: ['./detalhes-problema.component.css']
})
export class DetalhesProblemaComponent implements OnInit {

  titulo: string;
  problema: Problema;
  statusProblema: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private problemasService: ProblemasService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.problema = new Problema();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Problema', routerLink: ['/laboratory/problemas'] , visible: true},
      { label: 'Editar', routerLink: [`/laboratory/problemas/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/problemas/novo'] , visible: !id},
    ]);
    if (id) {
      this.problemasService.findById(id)
        .subscribe(
          (problema: Problema) => {
            if(problema){
              this.problema = problema;
              this.statusProblema = (this.problema.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Problemas', routerLink: ['/laboratory/problemas'] , visible: true},
                { label: this.problema.titulo, routerLink: [`/laboratory/problemas/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/laboratory/problemas']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
