import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Problema } from '../problema';
import { ProblemasService } from '../problemas.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-problema',
  templateUrl: './listagem-problema.component.html',
  styleUrls: ['./listagem-problema.component.css']
})
export class ListagemProblemaComponent implements OnInit {

  problemas: Problema[];
  loading: boolean;
  visualizar: boolean;
  problemaSelecionado: Problema;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private problemaService: ProblemasService
  ) {
    this.breadcrumbService.setItems([
      { label: 'ProblemaTecnico', routerLink: ['/laboratory/problemas'], visible: true }
    ]);
  }

  ngOnInit() {
    this.problemaSelecionado = new Problema();
    this.loading = true;
    this.problemaService.findAll(0)
      .subscribe(
        (dados: Page<Problema>) => {
          this.problemas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(problema: Problema) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o problema técnico ${problema.titulo}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.problemaService.delete(problema.id)
          .subscribe(
            (problema: Problema) => {
              this.mostrarMensagemSucesso('Problema Técnico removido com sucesso!');
              this.findByTitulo(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByTitulo(titulo: string) {
    this.filtro = titulo;
    this.loading = true;
    this.problemaService.findBytitulo(titulo, 0)
      .subscribe(
        (dados: Page<Problema>) => {
          this.problemas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirProblema(problema: Problema) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
