import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Professor } from '../professor';
import { ProfessorService } from '../professor.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-professor',
  templateUrl: './cadastro-professor.component.html',
  styleUrls: ['./cadastro-professor.component.css']
})
export class CadastroProfessorComponent implements OnInit {

  titulo: string;
  professor: Professor;

  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
  tipo: SelectItem[];
  sistemaoperacional: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private professorService: ProfessorService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.professor = new Professor();
    this.professor.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    this.professor.sistemaoperacional = (this.isAdministrador()) ? 'LINUX' : 'WINDOWS' ; 'IOS';
    this.professor.tipo = (this.isAdministrador()) ? 'PAGO' : 'OPenSource' ; 'GRATUITO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Professor', routerLink: ['/laboratory/professor'], visible: true },
      { label: 'Editar', routerLink: [`/laboratory/professor/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/professor/novo'], visible: !id },
    ]);
    if (id) {
      this.professorService.findById(id)
        .subscribe(
          (professor: Professor) => {
            if (professor) {
              this.professor = professor;

              this.breadcrumbService.setItems([
                { label: 'Professores', routerLink: ['/laboratory/professor'], visible: true },
                { label: this.professor.nome, routerLink: [`/laboratory/professor/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/laboratory/professor']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.sistemaoperacional = [
      { label: 'LINUX', value: 'LINUX' },
      { label: 'WINDOWS', value: 'WINDOWS' },
      { label: 'IOS', value: 'IOS' }
    ];

    this.tipo = [
      { label: 'PAGO', value: 'PAGO' },
      { label: 'OPenSource', value: 'OPenSource' },
      { label: 'GRATUITO', value: 'GRATUITO' }
    ];
  }

  salvar() {
    const isCreate = !this.professor.id;
    if (isCreate) {
      this.professorService.insert(this.professor)
        .subscribe(
          (professor: Professor) => {

            this.mostrarMensagemSucesso('Professor cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/professor'])
            }, 500)
          }
        )
    } else {
      this.professorService.update(this.professor)
        .subscribe(
          (professor: Professor) => {
            this.mostrarMensagemSucesso('Professor alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/professor'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
