import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Professor } from '../professor';
import { ProfessorService } from '../professor.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-professor',
  templateUrl: './detalhes-professor.component.html',
  styleUrls: ['./detalhes-professor.component.css']
})
export class DetalhesProfessorComponent implements OnInit {

  titulo: string; 
  professor: Professor;
  statusProfessor: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private professorService: ProfessorService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.professor = new Professor();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Professor', routerLink: ['/laboratory/professor'] , visible: true},
      { label: 'Editar', routerLink: [`/laboratory/professor/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/professor/novo'] , visible: !id},
    ]);
    if (id) {
      this.professorService.findById(id)
        .subscribe(
          (professor: Professor) => {
            if(professor){
              this.professor = professor;
              this.statusProfessor = (this.professor.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Professor', routerLink: ['/laboratory/professor'] , visible: true},
                { label: this.professor.nome, routerLink: [`/laboratory/professor/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/laboratory/professor']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
