import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Professor } from '../professor';
import { ProfessorService } from '../professor.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-professor',
  templateUrl: './listagem-professor.component.html',
  styleUrls: ['./listagem-professor.component.css']
})
export class ListagemProfessorComponent implements OnInit {

  professores: Professor[];
  loading: boolean;
  visualizar: boolean;
  professorSelecionado: Professor;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private professorService: ProfessorService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Professor', routerLink: ['/laboratory/professor'], visible: true }
    ]);
  }

  ngOnInit() {
    this.professorSelecionado = new Professor();
    this.loading = true;
    this.professorService.findAll(0)
      .subscribe(
        (dados: Page<Professor>) => {
          this.professores = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(professor: Professor) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${professor.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.professorService.delete(professor.id)
          .subscribe(
            (professor: Professor) => {
              this.mostrarMensagemSucesso('Professor removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.professorService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Professor>) => {
          this.professores = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirProfessor(professor: Professor) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
