import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Software } from '../software';
import { SoftwareService } from '../software.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';
import { Page } from 'src/app/utils/page';
import { PessoaT } from 'src/app/testes/pessoat/pessoat';
import { PessoasTService } from 'src/app/testes/pessoat/pessoast.service';

@Component({
  selector: 'app-cadastro-software',
  templateUrl: './cadastro-software.component.html',
  styleUrls: ['./cadastro-software.component.css']
})
export class CadastroSoftwareComponent implements OnInit {

  titulo: string;
  software: Software;

  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
  tipo: SelectItem[];
  sistemaoperacional: SelectItem[];
  softwares: Software[];

  pessoas: PessoaT[];

  dataconvertida: Date;
  calendarLocale: any;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private softwareService: SoftwareService,
    private pessoastService: PessoasTService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.software = new Software();
    this.software.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    this.software.sistemaoperacional = (this.isAdministrador()) ? 'LINUX' : 'WINDOWS' ; 'IOS';
    this.software.tipo = (this.isAdministrador()) ? 'PAGO' : 'OPenSource' ; 'GRATUITO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Software', routerLink: ['/laboratory/software'], visible: true },
      { label: 'Editar', routerLink: [`/laboratory/software/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/software/novo'], visible: !id },
    ]);
    if (id) {
      this.softwareService.findById(id)
        .subscribe(
          (software: Software) => {
            if (software) {
              this.software = software;
              this.software.data = this.converter()
              this.breadcrumbService.setItems([
                { label: 'Softwares', routerLink: ['/laboratory/software'], visible: true },
                { label: this.software.nome, routerLink: [`/laboratory/software/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/laboratory/software']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.sistemaoperacional = [
      { label: 'LINUX', value: 'LINUX' },
      { label: 'WINDOWS', value: 'WINDOWS' },
      { label: 'IOS', value: 'IOS' }
    ];

    this.tipo = [
      { label: 'PAGO', value: 'PAGO' },
      { label: 'OPenSource', value: 'OPenSource' },
      { label: 'GRATUITO', value: 'GRATUITO' }
    ];
    this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }

  salvar() {
    const isCreate = !this.software.id;
    if (isCreate) {
      this.softwareService.insert(this.software)
        .subscribe(
          (software: Software) => {

            this.mostrarMensagemSucesso('Software cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/software'])
            }, 500)
          }
        )
    } else {
      this.softwareService.update(this.software)
        .subscribe(
          (software: Software) => {
            this.mostrarMensagemSucesso('Software alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/laboratory/software'])
            }, 500)
          }
        )
    }

  }

  findByNome(nome: string) {
    this.pessoastService.findByFiltro(nome, 0)
      .subscribe(
        (dados: Page<PessoaT>) => {
          this.pessoas = dados.content;
        }
      )
  }

  converter(){
    this.dataconvertida = new Date(this.software.data)
    return this.dataconvertida
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
