import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Software } from '../software';
import { SoftwareService } from '../software.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-software',
  templateUrl: './detalhes-software.component.html',
  styleUrls: ['./detalhes-software.component.css']
})
export class DetalhesSoftwareComponent implements OnInit {

  titulo: string; 
  software: Software;
  statusSoftware: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private softwareService: SoftwareService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.software = new Software();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Software', routerLink: ['/laboratory/software'] , visible: true},
      { label: 'Editar', routerLink: [`/laboratory/software/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/laboratory/software/novo'] , visible: !id},
    ]);
    if (id) {
      this.softwareService.findById(id)
        .subscribe(
          (software: Software) => {
            if(software){
              this.software = software;
              this.statusSoftware = (this.software.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Software', routerLink: ['/laboratory/software'] , visible: true},
                { label: this.software.nome, routerLink: [`/laboratory/software/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/laboratory/software']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
