import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Software } from '../software';
import { SoftwareService } from '../software.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-software',
  templateUrl: './listagem-software.component.html',
  styleUrls: ['./listagem-software.component.css']
})
export class ListagemSoftwareComponent implements OnInit {

  softwares: Software[];
  loading: boolean;
  visualizar: boolean;
  softwareSelecionado: Software;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private softwareService: SoftwareService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Software', routerLink: ['/laboratory/software'], visible: true }
    ]);
  }

  ngOnInit() {
    this.softwareSelecionado = new Software();
    this.loading = true;
    this.softwareService.findAll(0)
      .subscribe(
        (dados: Page<Software>) => {
          this.softwares = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(software: Software) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${software.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.softwareService.delete(software.id)
          .subscribe(
            (software: Software) => {
              this.mostrarMensagemSucesso('Software removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.softwareService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Software>) => {
          this.softwares = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirSoftware(software: Software) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
