import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Endereso } from '../endereso';
import { EnderesoService} from '../endereso.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-endereso',
  templateUrl: './cadastro-endereso.component.html',
  styleUrls: ['./cadastro-endereso.component.css']
})

export class CadastroEnderesoComponent implements OnInit {

  titulo: string;
  endereso: Endereso;

  tiposUF: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private enderesoService: EnderesoService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.endereso = new Endereso();

    this.endereso.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Enderesos', routerLink: ['location/endereso'], visible: true },
      { label: 'Editar', routerLink: [`location/endereso${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['location/endereso/novo'], visible: !id },
    ]);
    if (id) {
      this.enderesoService.findById(id)
        .subscribe(
          (endereso: Endereso) => {
            if (endereso) {
              this.endereso = endereso;

              this.breadcrumbService.setItems([
                { label: 'enderesos', routerLink: ['location/endereso'], visible: true },
                { label: this.endereso.cep, routerLink: [`location/endereso/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['location/endereso']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.tiposUF = [
      { value: 'AC', label: 'Acre'},
      { value: 'AL', label: 'Alagoas'},
      { value: 'AP', label: 'Amapá'},
      { value: 'AM', label: 'Amazonas'},
      { value: 'BA', label: 'Bahia'},
      { value: 'CE', label: 'Ceará'},
      { value: 'DF', label: 'Distrito Federal'},
      { value: 'ES', label: 'Espírito Santo'},
      { value: 'GO', label: 'Goiás'},
      { value: 'MA', label: 'Maranhão'},
      { value: 'MT', label: 'Mato Grosso'},
      { value: 'MS', label: 'Mato Grosso do Sul'},
      { value: 'MG', label: 'Minas Gerais'},
      { value: 'PA', label: 'Pará'},
      { value: 'PB', label: 'Paraíba'},
      { value: 'PR', label: 'Paraná'},
      { value: 'PE', label: 'Pernambuco'},
      { value: 'PI', label: 'Piauí'},
      { value: 'RJ', label: 'Rio de Janeiro'},
      { value: 'RN', label: 'Rio Grande do Norte'},
      { value: 'RS', label: 'Rio Grande do Sul'},
      { value: 'RO', label: 'Rondônia'},
      { value: 'RR', label: 'Roraima'},
      { value: 'SC', label: 'Santa Catarina'},
      { value: 'SP', label: 'São Paulo'},
      { value: 'SE', label: 'Sergipe'},
      { value: 'TO', label: 'Tocantins'},
    ];

  }

  salvar() {
    const isCreate = !this.endereso.id;
    if (isCreate) {
      this.enderesoService.insert(this.endereso)
        .subscribe(
          (endereso: Endereso) => {

            this.mostrarMensagemSucesso('Endereço cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['location/endereso'])
            }, 500)
          }
        )
    } else {
      this.enderesoService.update(this.endereso)
        .subscribe(
          (endereso: Endereso) => {
            this.mostrarMensagemSucesso('Endereço alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['location/endereso'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
