import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Endereso } from '../endereso';
import { EnderesoService } from '../endereso.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-endereso',
  templateUrl: './detalhes-endereso.component.html',
  styleUrls: ['./detalhes-endereso.component.css']
})
export class DetalhesEnderesoComponent implements OnInit {

  titulo: string;
  endereso: Endereso;
  statusEndereso: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private enderesoService: EnderesoService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.endereso = new Endereso();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Endereso', routerLink: ['location/endereso'] , visible: true},
      { label: 'Editar', routerLink: [`location/endereso/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['location/endereso/novo'] , visible: !id},
    ]);
    if (id) {
      this.enderesoService.findById(id)
        .subscribe(
          (endereso: Endereso) => {
            if(endereso){
              this.endereso = endereso;
              this.statusEndereso = (this.endereso.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Endereso', routerLink: ['location/endereso'] , visible: true},
                { label: this.endereso.cep, routerLink: [`location/endereso/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['location/endereso']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
