import { Injectable } from '@angular/core';
import { Endereso } from './endereso';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { Page } from '../../utils/page';

@Injectable({
  providedIn: 'root'
})
export class EnderesoService {

  httpOptions = {
    headers: new HttpHeaders({
      'Content-Type': 'application/json',
    })
  };

  url: string;
  idCount: number = 2;

  constructor(
    private http: HttpClient
  ) {
    this.url = `${environment.apiUrl}/location/endereso`;
  }

  findAll(pagina: number) {
    let proprietario = '';
    return this.http.get<Page<Endereso>>(`${this.url}?pagina=${pagina}`);
  }

  findByCep(cep: string, pagina: number) {
    return this.http.get<Page<Endereso>>(`${this.url}?cep=${cep}&pagina=${pagina}`);
  }

  findByProprietario(proprietario: string, pagina: number) {
    return this.http.get<Page<Endereso>>(`${this.url}?proprietario=${proprietario}&pagina=${pagina}`);
  }

  findById(id: number) {
    return this.http.get<Endereso>(`${this.url}/${id}`);
  }

  delete(id: number) {
    return this.http.delete<Endereso>(`${this.url}/${id}`);
  }

  update(endereso: Endereso) {
    return this.http.put<Endereso>(`${this.url}/${endereso.id}`, endereso, this.httpOptions);
  }

  insert(endereso: Endereso) {
    return this.http.post<Endereso>(this.url, endereso, this.httpOptions);
  }

}
