import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Endereso } from '../endereso';
import { EnderesoService } from '../endereso.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-endereso',
  templateUrl: './listagem-endereso.component.html',
  styleUrls: ['./listagem-endereso.component.css']
})
export class ListagemEnderesoComponent implements OnInit {

  enderesos: Endereso[];
  loading: boolean;
  visualizar: boolean;
  enderesoSelecionado: Endereso;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private enderesoService: EnderesoService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Enderesos', routerLink: ['/location/endereso'], visible: true }
    ]);
  }

  ngOnInit() {
    this.enderesoSelecionado = new Endereso();
    this.loading = true;
    this.enderesoService.findAll(0)
      .subscribe(
        (dados: Page<Endereso>) => {
          this.enderesos = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(endereso: Endereso) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o endereço ${endereso.cep}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.enderesoService.delete(endereso.id)
          .subscribe(
            (endereso: Endereso) => {
              this.mostrarMensagemSucesso('Endereço removido com sucesso!');
              this.findByCep(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByCep(cep: string) {
    this.filtro = cep;
    this.loading = true;
    this.enderesoService.findByCep(cep, 0)
      .subscribe(
        (dados: Page<Endereso>) => {
          this.enderesos = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirEndereso(endereso: Endereso) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}