import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Estado } from '../estado';
import { EstadoService} from '../estado.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-estado',
  templateUrl: './cadastro-estado.component.html',
  styleUrls: ['./cadastro-estado.component.css']
})

export class CadastroEstadoComponent implements OnInit {

  titulo: string;
  estado: Estado;

  tiposNivelEnsino: SelectItem[];
  tiposTempo: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private estadoService: EstadoService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.estado = new Estado();

    this.estado.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Estados', routerLink: ['location/estado'], visible: true },
      { label: 'Editar', routerLink: [`location/estado${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['location/estado/novo'], visible: !id },
    ]);
    if (id) {
      this.estadoService.findById(id)
        .subscribe(
          (estado: Estado) => {
            if (estado) {
              this.estado = estado;

              this.breadcrumbService.setItems([
                { label: 'Estados', routerLink: ['location/estado'], visible: true },
                { label: this.estado.nome, routerLink: [`location/estado/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['location/estado']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    

    this.tiposTempo = [
      { label: 'Anual', value: 'ANUAL' },
      { label: 'Semestral', value: 'SEMESTRAL' }
    ];

  }

  salvar() {
    const isCreate = !this.estado.id;
    if (isCreate) {
      this.estadoService.insert(this.estado)
        .subscribe(
          (estado: Estado) => {

            this.mostrarMensagemSucesso('Estado cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['location/estado'])
            }, 500)
          }
        )
    } else {
      this.estadoService.update(this.estado)
        .subscribe(
          (estado: Estado) => {
            this.mostrarMensagemSucesso('Estado alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['location/estado'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
