import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Estado } from '../estado';
import { EstadoService } from '../estado.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-estado',
  templateUrl: './detalhes-estado.component.html',
  styleUrls: ['./detalhes-estado.component.css']
})
export class DetalhesEstadoComponent implements OnInit {

  titulo: string;
  estado: Estado;
  statusEstado: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private estadoService: EstadoService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.estado = new Estado();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Estado', routerLink: ['location/estado'] , visible: true},
      { label: 'Editar', routerLink: [`location/estado/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['location/estado/novo'] , visible: !id},
    ]);
    if (id) {
      this.estadoService.findById(id)
        .subscribe(
          (estado: Estado) => {
            if(estado){
              this.estado = estado;
              this.statusEstado = (this.estado.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Estado', routerLink: ['location/estado'] , visible: true},
                { label: this.estado.nome, routerLink: [`location/estado/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['location/estado']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
