import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Estado } from '../estado';
import { EstadoService } from '../estado.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-estado',
  templateUrl: './listagem-estado.component.html',
  styleUrls: ['./listagem-estado.component.css']
})
export class ListagemEstadoComponent implements OnInit {

  estados: Estado[];
  loading: boolean;
  visualizar: boolean;
  estadoSelecionado: Estado;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private estadoService: EstadoService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Estado', routerLink: ['/location/estado'], visible: true }
    ]);
  }

  ngOnInit() {
    this.estadoSelecionado = new Estado();
    this.loading = true;
    this.estadoService.findAll(0)
      .subscribe(
        (dados: Page<Estado>) => {
          this.estados = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(estado: Estado) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a estado ${estado.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.estadoService.delete(estado.id)
          .subscribe(
            (estado: Estado) => {
              this.mostrarMensagemSucesso('Estado removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.estadoService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Estado>) => {
          this.estados = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirEstado(estado: Estado) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}