import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Pais } from '../pais';
import { PaisService} from '../pais.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-cadastro-pais',
  templateUrl: './cadastro-pais.component.html',
  styleUrls: ['./cadastro-pais.component.css']
})

export class CadastroPaisComponent implements OnInit {

  titulo: string;
  pais: Pais;

  tiposLinguas: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private paisService: PaisService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.pais = new Pais();

    this.pais.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Paises', routerLink: ['location/pais'], visible: true },
      { label: 'Editar', routerLink: [`location/pais${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['location/pais/novo'], visible: !id },
    ]);
    if (id) {
      this.paisService.findById(id)
        .subscribe(
          (pais: Pais) => {
            if (pais) {
              this.pais = pais;

              this.breadcrumbService.setItems([
                { label: 'Paises', routerLink: ['location/pais'], visible: true },
                { label: this.pais.nome, routerLink: [`location/pais/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['location/pais']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {
    
    this.tiposLinguas = [
      { label: 'Inglês', value: 'INGLÊS' },
      { label: 'Português', value: 'PORTUGUÊS' },
      { label: 'Espanhol', value: 'ESPANHOL' },
      { label: 'Francês', value: 'FRANCÊS' },
      { label: 'Espanhol', value: 'MANDARIM' },
      { label: 'Espanhol', value: 'HINDI' },
      { label: 'Espanhol', value: 'ÁRABE' },
      { label: 'Espanhol', value: 'RUSSO' },
      { label: 'Espanhol', value: 'BENGALI' }
    ];


  }

  salvar() {
    const isCreate = !this.pais.id;
    if (isCreate) {
      this.paisService.insert(this.pais)
        .subscribe(
          (pais: Pais) => {

            this.mostrarMensagemSucesso('Pais cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['location/pais'])
            }, 500)
          }
        )
    } else {
      this.paisService.update(this.pais)
        .subscribe(
          (pais: Pais) => {
            this.mostrarMensagemSucesso('Pais alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['location/pais'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
