import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Pais } from '../pais';
import { PaisService } from '../pais.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-pais',
  templateUrl: './detalhes-pais.component.html',
  styleUrls: ['./detalhes-pais.component.css']
})
export class DetalhesPaisComponent implements OnInit {

  titulo: string;
  pais: Pais;
  statusPais: boolean = true;
  
  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private paisService: PaisService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.pais = new Pais();

    const id = this.activatedRoute.snapshot.params['id'];
    
    this.breadcrumbService.setItems([
      { label: 'Pais', routerLink: ['location/pais'] , visible: true},
      { label: 'Editar', routerLink: [`location/pais/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['location/pais/novo'] , visible: !id},
    ]);
    if (id) {
      this.paisService.findById(id)
        .subscribe(
          (pais: Pais) => {
            if(pais){
              this.pais = pais;
              this.statusPais = (this.pais.status == 'ATIVO');
            
              this.breadcrumbService.setItems([
                { label: 'Pais', routerLink: ['location/pais'] , visible: true},
                { label: this.pais.nome, routerLink: [`location/pais/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['location/pais']);
            }
          }
        )
    } 

    this.titulo = 'Detalhes';
  }

  ngOnInit() {
    
  }
  
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
