import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { Pais } from '../pais';
import { PaisService } from '../pais.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-pais',
  templateUrl: './listagem-pais.component.html',
  styleUrls: ['./listagem-pais.component.css']
})
export class ListagemPaisComponent implements OnInit {

  paises: Pais[];
  loading: boolean;
  visualizar: boolean;
  paisSelecionado: Pais;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private paisService: PaisService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Pais', routerLink: ['/location/pais'], visible: true }
    ]);
  }

  ngOnInit() {
    this.paisSelecionado = new Pais();
    this.loading = true;
    this.paisService.findAll(0)
      .subscribe(
        (dados: Page<Pais>) => {
          this.paises = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(pais: Pais) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a pais ${pais.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.paisService.delete(pais.id)
          .subscribe(
            (pais: Pais) => {
              this.mostrarMensagemSucesso('Pais removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.paisService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Pais>) => {
          this.paises = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirPais(pais: Pais) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}