import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from '../../../breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { Sidade } from '../sidade';
import { SidadeService } from '../sidade.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from '../../../seguranca/oauth.service';


@Component({
  selector: 'app-cadastro-sidade',
  templateUrl: './cadastro-sidade.component.html',
  styleUrls: ['./cadastro-sidade.component.css']
})
export class CadastroSidadeComponent implements OnInit {

  titulo: string;
  sidade: Sidade;

  tiposUF: SelectItem[];
  tipoStatus: SelectItem[];

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private parceirosService: SidadeService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.sidade = new Sidade();
    this.sidade.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Parceiros', routerLink: ['/testes/sidades'], visible: true },
      { label: 'Editar', routerLink: [`/testes/sidades/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/testes/sidades/novo'], visible: !id },
    ]);
    if (id) {
      this.parceirosService.findById(id)
        .subscribe(
          (sidade: Sidade) => {
            if (sidade) {
              this.sidade = sidade;

              this.breadcrumbService.setItems([
                { label: 'Parceiros', routerLink: ['/testes/sidades'], visible: true },
                { label: this.sidade.nome, routerLink: [`/testes/sidades/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/testes/sidades']);
            }
          }
        )
    }


    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];

    this.tiposUF = [
      { label: 'MG', value: 'mg' },
      { label: 'SP', value: 'sp' }
    ];

  }

  salvar() {
    const isCreate = !this.sidade.id;
    if (isCreate) {
      this.parceirosService.insert(this.sidade)
        .subscribe(
          (sidade: Sidade) => {

            this.mostrarMensagemSucesso('Sidade Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/testes/sidades'])
            }, 500)
          }
        )
    } else {
      this.parceirosService.update(this.sidade)
        .subscribe(
          (sidade: Sidade) => {
            this.mostrarMensagemSucesso('Sidade Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/testes/sidades'])
            }, 500)
          }
        )
    }

  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
