import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from '../../../breadcrumb.service';
import { MessageService } from 'primeng/api';
import { Sidade } from '../sidade';
import { SidadeService } from '../sidade.service';
import { Router, ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-detalhes-sidade',
  templateUrl: './detalhes-sidade.component.html',
  styleUrls: ['./detalhes-sidade.component.css']
})
export class DetalhesSidadeComponent implements OnInit {

  titulo: string;
  sidade: Sidade;
  statusSidade: boolean = true;

  cols: any[];
  loading: boolean;


  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private sidadesService: SidadeService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.sidade = new Sidade();

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Sidades', routerLink: ['/location/sidades'] , visible: true},
      { label: 'Editar', routerLink: [`/location/sidades/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/location/sidades/novo'] , visible: !id},
    ]);
    if (id) {
      this.sidadesService.findById(id)
        .subscribe(
          (sidade: Sidade) => {
            if(sidade){
              this.sidade = sidade;
              this.statusSidade = (this.sidade.status == 'ATIVO');

              this.breadcrumbService.setItems([
                { label: 'Sidades', routerLink: ['/location/sidades'] , visible: true},
                { label: this.sidade.nome, routerLink: [`/location/sidades/${id}`] , visible: true}
              ]);
            } else {
              this.router.navigate(['/location/sidades']);
            }
          }
        )
    }

    this.titulo = 'Detalhes';
  }

  ngOnInit() {

  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
