import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from '../../../breadcrumb.service';
import { Sidade } from '../sidade';
import { SidadeService } from '../sidade.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from '../../../utils/page';
import { OauthService } from '../../../seguranca/oauth.service';

@Component({
  selector: 'app-listagem-sidade',
  templateUrl: './listagem-sidade.component.html',
  styleUrls: ['./listagem-sidade.component.css']
})
export class ListagemSidadeComponent implements OnInit {

  sidades: Sidade[];
  loading: boolean;
  visualizar: boolean;
  sidadeSelecionado: Sidade;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private sidadeService: SidadeService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Sidades', routerLink: ['/location/sidade'], visible: true }
    ]);
  }

  ngOnInit() {
    this.sidadeSelecionado = new Sidade();
    this.loading = true;
    this.sidadeService.findAll(0)
      .subscribe(
        (dados: Page<Sidade>) => {
          this.sidades = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(sidade: Sidade) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o sidade ${sidade.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.sidadeService.delete(sidade.id)
          .subscribe(
            (sidade: Sidade) => {
              this.mostrarMensagemSucesso('sidade removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.sidadeService.findByNome(nome, 0)
      .subscribe(
        (dados: Page<Sidade>) => {
          this.sidades = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirSidade(sidade: Sidade) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
