import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, ConfirmationService } from 'primeng/api';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { AbertaService } from '../aberta.service';
import { Aberta } from '../aberta';
import { Page } from 'src/app/utils/page';

@Component({
  selector: 'app-listagem-aberta',
  templateUrl: './listagem-aberta.component.html',
  styleUrls: ['./listagem-aberta.component.css']
})
export class ListagemAbertaComponent implements OnInit {
   
  abertas: Aberta[];
  abertaSelecionada: Aberta;
  loading: boolean;
  visualizar: boolean;
   
  numTotal: number;
  filtro: number;
   
  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private abertaService: AbertaService) {
      this.breadcrumbService.setItems([
        { label: 'Abertas', routerLink: ['/questao/aberta'], visible: true }
      ]);
     }

  ngOnInit() {
    this.abertaSelecionada = new Aberta();
    this.loading = true;
    this.abertaService.findAll()
      .subscribe(
        (dados: Page<Aberta>) => {
          this.abertas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }
   
  excluir(aberta: Aberta) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir a questão aberta número ${aberta.id}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.abertaService.delete(aberta.id)
          .subscribe(
            (aberta: Aberta) => {
              this.mostrarMensagemSucesso('Questão removida com sucesso!');
              //this.findById(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });
     
  }
   /*
  findById(nome: number) {
    this.filtro = nome;
    this.loading = true;
    this.abertaService.findById(nome)
      .subscribe(
        (dados: Page<Aberta>) => {
          this.abertas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }
   */
  possuiPermissaoEditarExcluirAberta(aberta: Aberta) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }
   
  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
   
  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }
   
  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }
   
}
