import { Component, OnInit } from '@angular/core';
import { OauthService } from '../oauth.service';
import { NgModel } from '@angular/forms';
import { HttpErrorResponse } from '@angular/common/http';
import { MessageService } from 'primeng/api';
import { Router } from '@angular/router';

@Component({
  selector: 'app-login-form',
  templateUrl: './login-form.component.html',
  styleUrls: ['./login-form.component.css']
})
export class LoginFormComponent implements OnInit {

  blockedDocument: boolean;

  constructor(
    private oauthService: OauthService,
    private messageService: MessageService,
    private router: Router) { }

  ngOnInit() {
  }

  validarLogin(login: NgModel, senha: NgModel) {
    this.blockedDocument = true;
    this.oauthService.efetuarLogin(login.value, senha.value).subscribe(
      (resposta) => {
        this.blockedDocument = false;
        this.router.navigate(['/']);
      },
      (erro: HttpErrorResponse) => {
        this.blockedDocument = false;
        if (erro.status === 400) {
          if (erro.error.error === 'invalid_grant') {
            this.mostrarMensagemErro('Login ou senha inválida!');
            senha.reset();
          } else {
            this.mostrarMensagemErro('Ocorreu um erro. Tente novamente!');
            throw new Error(erro.message);
          }

        }
      }
    );
  }

  loadRecuperarSenha(){
    this.router.navigate(['/recuperar-senha'])
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }
 
  isCliente() {
    return this.oauthService.checkPermission('ROLE_CLIENTE');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

}
