import { Injectable } from '@angular/core';
import { CanActivate, ActivatedRouteSnapshot, RouterStateSnapshot, Router } from '@angular/router';
import { Observable } from 'rxjs';
import { OauthService } from './oauth.service';

@Injectable({
  providedIn: 'root'
})
export class OauthGuard implements CanActivate {

  constructor(
    private router: Router,
    private oauthService: OauthService
  ) { }

  canActivate(
    next: ActivatedRouteSnapshot,
    state: RouterStateSnapshot): Observable<boolean> | Promise<boolean> | boolean {

    // verifica se o usuario esta logado
    if (!this.oauthService.isUsuarioLogado()) {
      this.router.navigate(['/login']);
      return false;
    }

    // verifica se o usuario possui permissao para acessar tal rota
    if (next.data.roles && !this.oauthService.usuarioPossuiAlgumaPermissaoValida(next.data.roles)) {
      this.router.navigate(['/acesso-negado']);
      return false;
    }

    return true;
  }
}
