import { Injectable } from '@angular/core';
import { HttpClient, HttpErrorResponse, HttpHeaders } from '@angular/common/http';
import { catchError, map } from 'rxjs/operators';
import { throwError } from 'rxjs';
import { JwtHelperService } from '@auth0/angular-jwt';
import { LogoutService } from './logout/logout.service';
import { environment } from '../../environments/environment';
import * as moment from 'moment';

const httpOptions = {
  headers: new HttpHeaders({
    'Content-Type': 'application/x-www-form-urlencoded',
    'Authorization': 'Basic c3dhZ2dlcjpAQzNmM3RNR0A='
  }),
  withCredentials: true
};

@Injectable({
  providedIn: 'root'
})
export class OauthService {

  urlOAuthToken: string;
  jwtPayload: any;

  constructor(
    private http: HttpClient,
    private jwtHelperService: JwtHelperService,
    private logoutService: LogoutService
  ) {

    this.urlOAuthToken = `${environment.apiUrl}/oauth/token`;
    this.carregarAccessToken();
  }

  efetuarLogin(login: string, senha: string) {
    const body = `username=${login}&password=${senha}&grant_type=password`;
    return this.http.post<any>(this.urlOAuthToken, body, httpOptions)
      .pipe(
        map((resposta) => {
          this.armazenarToken(resposta.access_token);
        })
      );
  }

  private armazenarToken(token: string) {
    const stringPayload = this.jwtHelperService.decodeToken(token);
    this.jwtPayload = JSON.parse(JSON.stringify(stringPayload));
    localStorage.setItem('token', token);
  }

  private carregarAccessToken() {
    const token = localStorage.getItem('token');
    const stringPayload = this.jwtHelperService.decodeToken(token);
    this.jwtPayload = JSON.parse(JSON.stringify(stringPayload));
  }

  novoAccessToken() {
    const body = 'grant_type=refresh_token';
    return this.http.post<any>(this.urlOAuthToken, body, httpOptions)
      .pipe(
        map((resposta) => {
          this.armazenarToken(resposta.access_token);
        })
      );
  }

  isAccessTokenInvalido() {
    const token = localStorage.getItem('token');
    return !token || this.jwtHelperService.isTokenExpired(token);
  }

  isUsuarioLogado() {
    if(this.isAccessTokenInvalido()){
      const token = localStorage.getItem('token');
      if(token){
        const dataExpiracao = this.jwtHelperService.getTokenExpirationDate(token);
        const dataAtual = moment().toDate();
        return (dataAtual.getTime() - dataExpiracao.getTime()) <= 1000 * 3600 * 24; // tolerancia de 24h
      } else {
        return false;
      }
    }
    return true;
  }

  private removerToken() {
    localStorage.removeItem('token');
    this.jwtPayload = null;
  }

  efetuarLogout() {
    this.logoutService.delete()
      .subscribe(
        () => {
          this.removerToken();
        }
      );
  }

  usuarioPossuiAlgumaPermissaoValida(permissoes: any[]) {
    let possui = false;
    permissoes.forEach(
      (permissao) => {
        if (this.checkPermission(permissao)) {
          possui = true;
        }
      }
    );
    return possui;
  }

  checkPermission(permissao: string) {
    if(!this.jwtPayload){
      return false;
    }
    const authorities = this.jwtPayload.authorities;
    return authorities.includes(permissao);
  }



}
