import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { MessageService, SelectItem } from 'primeng/api';
import { PessoaT } from '../pessoat';
import { PessoasTService } from '../pessoast.service';
import { Router, ActivatedRoute } from '@angular/router';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { Page } from 'src/app/utils/page';
import { ConversorCalendario } from 'src/app/calendario/conversor-calendario';

@Component({
  selector: 'app-cadastro-pessoat',
  templateUrl: './cadastro-pessoat.component.html',
  styleUrls: ['./cadastro-pessoat.component.css']
})
export class CadastroPessoaTComponent implements OnInit {

  titulo: string;
  pessoat: PessoaT;
  pessoast: PessoaT[];
  
  tiposDesconto: SelectItem[];
  tiposOnerarios: SelectItem[];
  tipoStatus: SelectItem[];
  
  calendarLocale: any;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private pessoaTService: PessoasTService,
    private oauthService: OauthService,
    private activatedRoute: ActivatedRoute,
    private router: Router
  ) {
    this.pessoat = new PessoaT();
    this.pessoat.status = (this.isAdministrador()) ? 'PUBLICO' : 'PRIVADO';
    //this.pessoat.onerario = (this.isAdministrador()) ? 'Nutrilight' : 'Nutricionista';
    //this.pessoat.tipoDesconto = 'Porcentagem';

    const id = this.activatedRoute.snapshot.params['id'];

    this.breadcrumbService.setItems([
      { label: 'Testes', visible: true},
      { label: 'Pessoas Teste', routerLink: ['/testes/pessoast'] , visible: true},
      { label: 'Editar', routerLink: [`/testes/pessoast/${id}`], visible: id != undefined },
      { label: 'Novo', routerLink: ['/testes/pessoast/novo'], visible: !id },
    ]);
    
    if (id) {
      this.pessoaTService.findById(id)
        .subscribe(
          (pessoat: PessoaT) => {
            if (pessoat) {
              this.pessoat = pessoat;

              console.log(pessoat.dtNascimento);
              console.log(this.pessoat.dtNascimento);
              this.breadcrumbService.setItems([
                { label: 'Testes', visible: true},
                { label: 'Pessoas Teste', routerLink: ['/testes/pessoast'] , visible: true},
                { label: this.pessoat.nome, routerLink: [`/testes/pessoast/${id}`], visible: true }
              ]);
            } else {
              this.router.navigate(['/testes/pessoast']);
            }
          }
        )
    }

    this.titulo = (id) ? 'Editar' : 'Cadastrar';

  }

  ngOnInit() {

    this.tipoStatus = [
      { label: 'Público', value: 'PUBLICO' },
      { label: 'Privado', value: 'PRIVADO' }
    ];
    this.calendarLocale = ConversorCalendario.getCalendarLocale();
  }

  salvar() {
    const isCreate = !this.pessoat.id;
    if (isCreate) {
      this.pessoaTService.insert(this.pessoat)
        .subscribe(
          (pessoat: PessoaT) => {

            this.mostrarMensagemSucesso('Pessoa Teste cadastrado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/testes/pessoast'])
            }, 500)
          }
        )
    } else {
      this.pessoaTService.update(this.pessoat)
        .subscribe(
          (pessoat: PessoaT) => {
            this.mostrarMensagemSucesso('Pessoa Teste alterado com sucesso!');
            setTimeout(() => {
              this.router.navigate(['/testes/pessoast'])
            }, 500)
          }
        )
      }
  }
  
  findByNome(nome: string) {
    this.pessoaTService.findByFiltro(nome, 0)
      .subscribe(
        (dados: Page<PessoaT>) => {
          this.pessoast = dados.content;
        }
      )
  }
  
  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
