import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { PessoaT } from '../pessoat';
import { PessoasTService } from '../pessoast.service';
import { ConfirmationService, MessageService } from 'primeng/api';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';

@Component({
  selector: 'app-listagem-pessoat',
  templateUrl: './listagem-pessoat.component.html',
  styleUrls: ['./listagem-pessoat.component.css']
})
export class ListagemPessoaTComponent implements OnInit {

  pessoas: PessoaT[];
  loading: boolean;
  visualizar: boolean;
  pessoaSelecionado: PessoaT;

  numTotal: number;
  filtro: string = '';

  constructor(
    private breadcrumbService: BreadcrumbService,
    private messageService: MessageService,
    private confirmationService: ConfirmationService,
    private oauthService: OauthService,
    private pessoaTService: PessoasTService
  ) {
    this.breadcrumbService.setItems([
      { label: 'PessoasTeste', routerLink: ['/testes/pessoast'], visible: true }
    ]);
  }

  ngOnInit() {
    this.pessoaSelecionado = new PessoaT();
    this.loading = true;
    this.pessoaTService.findAll(0)
      .subscribe(
        (dados: Page<PessoaT>) => {
          this.pessoas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  excluir(pessoa: PessoaT) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o parceiro ${pessoa.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.pessoaTService.delete(pessoa.id)
          .subscribe(
            (pessoa: PessoaT) => {
              this.mostrarMensagemSucesso('Pessoa removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    this.pessoaTService.findByFiltro(nome, 0)
      .subscribe(
        (dados: Page<PessoaT>) => {
          this.pessoas = dados.content;
          this.numTotal = dados.totalElements;
          this.loading = false;
        }
      )
  }

  possuiPermissaoEditarExcluirPessoa(pessoa: PessoaT) {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }


}
