import { Component, OnInit } from '@angular/core';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { ActivatedRoute, Router } from '@angular/router';
import { UsuariosService } from '../usuarios.service';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MessageService } from 'primeng/api';
import { Usuario } from '../usuario';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { HttpErrorResponse } from '@angular/common/http';

@Component({
  selector: 'app-alterar-senha',
  templateUrl: './alterar-senha.component.html',
  styleUrls: ['./alterar-senha.component.css']
})
export class AlterarSenhaComponent implements OnInit {

  usuario: Usuario;
  usuarioForm: FormGroup;
  isNutricionista: boolean;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private activatedRoute: ActivatedRoute,
    private administradoresService: UsuariosService,
    private oauthService: OauthService,
    private formBuilder: FormBuilder,
    private router: Router,
    private messageService: MessageService
  ) {
    this.usuario = new Usuario();
    const id = this.activatedRoute.snapshot.params['id'];
    this.isNutricionista = false;
    if (id) {
      this.administradoresService.findById(id)
        .subscribe(
          (usuario: Usuario) => {
            if (usuario) {
              this.usuario = usuario;
              if(this.isAdministrador() && this.isNutricionista){
                this.breadcrumbService.setItems([
                  { label: 'Nutricionistas', routerLink: [`/nutricionistas`],  visible: true },
                  { label: 'Alterar Senha', routerLink: [`/alterar-senha-nutri/${id}`], visible: true }
                ]);
              }else{
                this.breadcrumbService.setItems([
                  { label: 'Administradores', routerLink: [`/administradores`], visible: this.isAdministrador() },
                  { label: 'Clientes', routerLink: [`/clientes`], visible: this.isCliente() },
                  { label: 'Alterar Senha', routerLink: [`/alterar-senha/${id}`], visible: true }
                ]);
              }
              // console.log("tipoUsuario");
              this.ngOnInit();
            } else {
              this.router.navigate([this.getURL()]);
            }
          }
        )
    }
    
    
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

  isCliente() {
    return this.oauthService.checkPermission('ROLE_CLIENTE');
  }

  ngOnInit() {

    const statusDefault = (this.usuario.status == 'ATIVO');
    this.usuarioForm = this.formBuilder.group({
      senha: [null, [Validators.required, Validators.minLength(3)]],
      novaSenha: [null, [Validators.required, Validators.minLength(3)]]
    });

  }

  salvar() {
    this.copyProperties();
    this.administradoresService.update(this.usuario, true)
      .subscribe(
        (a: Usuario) => {
          this.mostrarMensagemSucesso('Cadastro atualizado com sucesso!');
          setTimeout(() => {
            if(this.isNutricionista){
              this.router.navigate(['/nutricionistas']);
            }else{
              this.router.navigate([this.getURL()]);
            }
            
          }, 500)
        },
        (erro: HttpErrorResponse) => {
          if(erro.status == 400) {
            this.mostrarMensagemErro('Senha informada não corresponde a senha atual')
          }
        }
      )
  }

  private getURL(): string {
    if (this.isAdministrador()) {
      return '/administradores';
    } else if (this.isCliente()) {
      return '/clientes';
    }
  }

  isNovoUsuario() {
    return this.usuario.idUsuario == null;
  }

  private copyProperties() {
    const aux = this.usuarioForm.value;
    
    aux.idUsuario = this.usuario.idUsuario;
    aux.login = this.usuario.login;
    aux.email = this.usuario.email;
    aux.nome = this.usuario.nome;
    aux.permissoes = this.usuario.permissoes;
    aux.status = this.usuario.status;

    this.usuario = aux;
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }
}
