import { Component, OnInit } from '@angular/core';
import { Transacao } from '../transacao';
import { TransacoesService } from '../transacoes.service';
import { Page } from 'src/app/utils/page';
import { OauthService } from 'src/app/seguranca/oauth.service';
import { BreadcrumbService } from 'src/app/breadcrumb.service';

@Component({
  selector: 'app-financeiro',
  templateUrl: './financeiro.component.html',
  styleUrls: ['./financeiro.component.css']
})
export class FinanceiroComponent implements OnInit {

  transacoes: Transacao[];
  loading: boolean;
  dataInicio: Date;
  dataFim: Date;
  numTotal: number;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private transacoesService: TransacoesService,
    private oauthService: OauthService
  ) {
    this.breadcrumbService.setItems([
      { label: 'Financeiro', routerLink: ['/financeiro'], visible: true }
    ]);
   }

  ngOnInit() {
    this.loadDados({ first: 0, rows: 10 })
  }

  loadDados(event) {
    this.loading = true;
    if(this.isAdministrador()){
      this.transacoesService.findAll(event.first / event.rows)
        .subscribe(
          (dados: Page<Transacao>) => {
            this.transacoes = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    }
  }

  isAdministrador() {
    return this.oauthService.checkPermission('ROLE_ADMINISTRADOR');
  }

}
