import { Component, OnInit } from '@angular/core';
import { Usuario } from '../usuario';
import { BreadcrumbService } from 'src/app/breadcrumb.service';
import { UsuariosService } from '../usuarios.service';
import { MessageService, ConfirmationService } from 'primeng/api';
import { Page } from 'src/app/utils/page';

@Component({
  selector: 'app-listagem-administrador',
  templateUrl: './listagem-administrador.component.html',
  styleUrls: ['./listagem-administrador.component.css']
})
export class ListagemAdministradorComponent implements OnInit {

  administradores: Usuario[];
  loading: boolean;
  adminSelecionado: Usuario;
  visualizar: boolean;
  numTotal: number;
  filtro: string = '';
  exibirInativos: boolean;

  constructor(
    private breadcrumbService: BreadcrumbService,
    private confirmationService: ConfirmationService,
    private messageService: MessageService,
    private administradoresService: UsuariosService

  ) {
    this.breadcrumbService.setItems([
      { label: 'Administradores', routerLink: ['/administradores'], visible: true }
    ]);
  }

  ngOnInit() {
    this.adminSelecionado = new Usuario();
    this.listar();
  }

  onChangeStatus(event) {
    this.exibirInativos = event.checked;
    this.findByNome(this.filtro);
  }

  excluir(administrador: Usuario) {
    this.confirmationService.confirm({
      message: `Deseja realmente excluir o administrador(a) ${administrador.nome}?`,
      header: 'Confirmação',
      icon: 'pi pi-exclamation-triangle',
      acceptLabel: 'Sim',
      rejectLabel: 'Não',
      accept: () => {
        this.administradoresService.delete(administrador.idUsuario)
          .subscribe(
            (administrador: Usuario) => {
              this.mostrarMensagemSucesso('Administrador(a) removido com sucesso!');
              this.findByNome(this.filtro);
            }
          );
      },
      reject: () => {
        this.mostrarMensagemInfo('Nenhuma operação foi realizada!');
      }
    });

  }

  listar() {
    this.loading = true;
    if (this.exibirInativos) {
      this.administradoresService.findAll(0)
        .subscribe(
          (dados: Page<Usuario>) => {
            this.administradores = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    } else {
      this.administradoresService.findByNomeAndStatus('', 'ATIVO', 0)
        .subscribe(
          (dados: Page<Usuario>) => {
            this.administradores = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    }
  }

  loadDados(event) {
    this.loading = true;
    if (this.exibirInativos) {
      this.administradoresService.findByNome(this.filtro, event.first / event.rows)
        .subscribe(
          (dados: Page<Usuario>) => {
            this.administradores = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    } else {
      this.administradoresService.findByNomeAndStatus(this.filtro, 'ATIVO', event.first / event.rows)
        .subscribe(
          (dados: Page<Usuario>) => {
            this.administradores = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    }
  }

  findByNome(nome: string) {
    this.filtro = nome;
    this.loading = true;
    if (this.exibirInativos) {
      this.administradoresService.findByNome(nome, 0)
        .subscribe(
          (dados: Page<Usuario>) => {
            this.administradores = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    } else {
      this.administradoresService.findByNomeAndStatus(nome, 'ATIVO', 0)
        .subscribe(
          (dados: Page<Usuario>) => {
            this.administradores = dados.content;
            this.numTotal = dados.totalElements;
            this.loading = false;
          }
        )
    }
  }


  visualizarDialog(admin: Usuario) {
    this.adminSelecionado = admin;
    this.visualizar = true;
  }

  mostrarMensagemErro(mensagem: string) {
    this.messageService.add({ severity: 'error', summary: 'Erro', detail: mensagem });
  }

  mostrarMensagemInfo(mensagem: string) {
    this.messageService.add({ severity: 'info', summary: 'Info', detail: mensagem });
  }

  mostrarMensagemSucesso(mensagem: string) {
    this.messageService.add({ severity: 'success', summary: 'Sucesso', detail: mensagem });
  }

}
