import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders, HttpErrorResponse } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { throwError } from 'rxjs';
import { Usuario } from './usuario';
import { Page } from '../utils/page';

@Injectable({
  providedIn: 'root'
})
export class UsuariosService {

  httpOptions = {
    headers: new HttpHeaders({
      'Content-Type': 'application/json',
    })
  };

  url: string;
  administradores: Usuario[];
  idCount: number = 1;

  constructor(
    private http: HttpClient
  ) {
    this.url = `${environment.apiUrl}/usuarios`;
    this.administradores = [];
  }

  findAll(pagina: number) {
    return this.findByNome('', pagina);
  }

  findById(id: number) {
    return this.http.get<Usuario>(`${this.url}/${id}`);
  }

  findByNome(nome: string, pagina: number) {
    return this.http.get<Page<Usuario>>(`${this.url}?nome=${nome}&pagina=${pagina}`);
  }
  
  findByNomeAndStatus(nome: string, status: string, pagina: number) {
    return this.http.get<Page<Usuario>>(`${this.url}?nome=${nome}&status=${status}&pagina=${pagina}`);
  }

  delete(id: number) {
    return this.http.delete<Usuario>(`${this.url}/${id}`);
  }

  update(administrador: any, alterarSenha: boolean) {
    return this.http.put<Usuario>(`${this.url}/${administrador.idUsuario}?alterarSenha=${alterarSenha}`, administrador, this.httpOptions);
  }
  
  updateFoto(foto: FormData, id: number) {
    return this.http.post<any>(`${this.url}/foto/${id}`, foto);
  }

  insert(administrador: Usuario) {
    return this.http.post<Usuario>(`${this.url}`, administrador, this.httpOptions);
  }

  emailValidate(email: string) {
    return this.http.get<Usuario>(`${this.url}/validar-email/${email}`);
  }
  
  loginValidate(login: string) {
    return this.http.get<Usuario>(`${this.url}/validar-login/${login}`);
  }
  
  recuperarSenha(email: string) {
    return this.http.post(`${this.url}/recuperar-senha/${email}`, {});
  }

}


