package com.alessiojr.account.model;

import com.alessiojr.account.serializer.ContaSerializer;
import com.alessiojr.location.model.Endereco;
import com.alessiojr.security.model.Usuario;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import java.util.List;
import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.PrimaryKeyJoinColumn;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.OnDelete;
import org.hibernate.annotations.OnDeleteAction;

@Entity
@Table(
        name = "Pessoa",
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Pessoa_cpf", columnNames = "cpf")
        })
@PrimaryKeyJoinColumn(
        name = "idUsuario",
        foreignKey = @ForeignKey(name = "FK_Pessoa_usuario"),
        referencedColumnName = "idUsuario")
@Getter
@Setter
public class Pessoa extends Usuario{
    
    @Embedded
    private DadosPessoais dadosPessoais;
    
    @OneToOne(fetch = FetchType.EAGER)
    @OnDelete(action = OnDeleteAction.CASCADE)
    @JoinColumn(
            foreignKey = @ForeignKey(name = "FK_Pessoa_endereco"),
            name = "endereco_idEndereco",
            referencedColumnName = "idEndereco")
    private Endereco endereco;
  
    @OneToMany(mappedBy = "pessoa", fetch = FetchType.LAZY)
    @OnDelete(action = OnDeleteAction.CASCADE)
    private List<FotoPessoa> fotos;
    
    
    @JsonSerialize(using = ContaSerializer.class)
    @OneToOne(fetch = FetchType.EAGER, orphanRemoval = true)
    @OnDelete(action = OnDeleteAction.CASCADE)
    @JoinColumn(
            foreignKey = @ForeignKey(name = "FK_Pessoa_conta"),
            name = "conta_idConta",
            nullable = false,
            referencedColumnName = "idConta")
    private Conta conta;

}
