package com.alessiojr.account.model;

import com.alessiojr.account.serializer.TransacaoSerializer;
import com.alessiojr.security.model.Auditable;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import javax.persistence.Entity;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;

@Entity
@Table(name = "Transacao")
@Getter
@Setter
@EqualsAndHashCode(onlyExplicitlyIncluded = true, callSuper = true)
@JsonSerialize(using = TransacaoSerializer.class)
public class Transacao extends Auditable{

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @EqualsAndHashCode.Include
    private Long idTransacao;

    @ManyToOne
    @JoinColumn(
            foreignKey = @ForeignKey(name = "FK_Transacao_tipo"),
            name = "tipo_idTipoTransacao",
//            nullable = false,
            referencedColumnName = "nome")
    private TipoTransacao tipo;
    
    @NotNull
    private LocalDateTime dataHora;

    @NotNull
    @NotEmpty
    private String descricao;

    @NotNull
    private BigDecimal valor;

    @ManyToOne
    @JoinColumn(
            foreignKey = @ForeignKey(name = "FK_Transacao_conta"),
            name = "conta_idConta",
            nullable = false,
            referencedColumnName = "idConta")
    private Conta conta;

}
