package com.alessiojr.account.repository;

import com.alessiojr.account.model.Transacao;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Set;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;

public interface TransacaoRepository extends JpaRepository<Transacao, Long> {

    @Query("SELECT t FROM Transacao t WHERE t.conta.idConta = :conta")
    public Page<Transacao> findByConta(Long conta, Pageable pageable);

    public Page<Transacao> findByDataHoraBetween(LocalDateTime inicio, LocalDateTime fim, Pageable pageable);

    public Page<Transacao> findByDataHoraAfter(LocalDateTime dataHora, Pageable pageable);

    public Page<Transacao> findByDataHoraBefore(LocalDateTime dataHora, Pageable pageable);

    @Query(value = "SELECT (c1.valor - c2.valor  - c3.valor) as 'Faturamento' FROM "
            + "(SELECT COALESCE(SUM(valor), 0) as valor FROM Transacao WHERE descricao LIKE 'Recebimento consulta%' AND conta_idConta = :conta AND MONTH(dataHora)= :mes AND YEAR(dataHora)= :ano ) as c1, "
            + "(SELECT COALESCE(SUM(valor), 0) as valor FROM Transacao WHERE descricao LIKE 'Pagamento comissão%' AND conta_idConta = :conta  AND MONTH(dataHora)= :mes AND YEAR(dataHora)= :ano ) as c2, "
            + "(SELECT COALESCE(SUM(valor), 0) as valor FROM Transacao WHERE descricao LIKE 'Desconto%' AND conta_idConta = :conta  AND MONTH(dataHora)= :mes AND YEAR(dataHora)= :ano ) as c3",
            nativeQuery = true)
    public BigDecimal getFaturamentoByContaAndMesAndAno(Long conta, Integer mes, Integer ano);

    @Query(value = "SELECT (c1.valor - c2.valor  - c3.valor) as 'Faturamento' FROM "
            + "(SELECT COALESCE(SUM(valor), 0) as valor FROM Transacao WHERE descricao LIKE 'Recebimento consulta%' AND MONTH(dataHora)= :mes AND YEAR(dataHora)= :ano ) as c1, "
            + "(SELECT COALESCE(SUM(valor), 0) as valor FROM Transacao WHERE descricao LIKE 'Pagamento comissão%' AND MONTH(dataHora)= :mes AND YEAR(dataHora)= :ano ) as c2, "
            + "(SELECT COALESCE(SUM(valor), 0) as valor FROM Transacao WHERE descricao LIKE 'Desconto%' AND MONTH(dataHora)= :mes AND YEAR(dataHora)= :ano ) as c3",
            nativeQuery = true)
    public BigDecimal getFaturamentoByMesAndAno(Integer mes, Integer ano);
    
    @Query("SELECT t FROM Transacao t WHERE t.descricao LIKE CONCAT('%', ': ', :consulta)")
    public Set<Transacao> findAllByConsulta(Long consulta);

}
