package com.alessiojr.account.resource;

import com.alessiojr.account.model.Pessoa;
import com.alessiojr.account.model.PessoaDTO;
import com.alessiojr.account.service.PessoaService;
import com.alessiojr.security.model.Usuario;
import java.util.List;
import java.util.Optional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/pessoas")
public class PessoaResource {

    @Autowired
    private PessoaService pessoas;

    @GetMapping(params = {"nome", "pagina"})
    public Page<Pessoa> findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.pessoas.findAllByNome(nome, pagina);
    }

    /*
    @GetMapping("/informacoes/estados")
    public List<Object> countPessoasByEstados() {
        return pessoas.countPessoasByEstados();
    }

    @GetMapping("/informacoes/generos")
    public List<Object> countPessoasByGenero() {
        return pessoas.countPessoasByGenero();
    }

    @GetMapping("/informacoes/como-conheceu")
    public List<Object> countPessoasByComoConheceu() {
        return pessoas.countPessoasByComoConheceu();
    }
*/
    @PostMapping
    public ResponseEntity<Pessoa> insert(@RequestBody Pessoa pessoa) {
        try {
            return ResponseEntity
                    .status(HttpStatus.CREATED)
                    .body(pessoas.insert(pessoa));
            
        } catch (Exception e) {
            return ResponseEntity.badRequest().build();
        }
    }

    @GetMapping("/{id}")
    public ResponseEntity<Pessoa> findById(@PathVariable Long id) {
        Optional<Pessoa> pessoa = pessoas.findByIdUsuario(id);
        if (!pessoa.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(pessoa.get());
    }

    @GetMapping("/validar-login/{login}")
    public ResponseEntity loginValidate(@PathVariable String login) {
        Optional<Usuario> pessoa = pessoas.loginValidate(login);
        if (!pessoa.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok().build();
    }

    @GetMapping("/validar-cpf/{cpf}")
    public ResponseEntity cpfValidate(@PathVariable String cpf) {
        Optional<Pessoa> op = pessoas.findByCPF(cpf);
        if (!op.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok().build();
    }

    @GetMapping("/cpf/{cpf}")
    public ResponseEntity<Pessoa> findByCPF(@PathVariable String cpf) {
        Optional<Pessoa> op = pessoas.findByCPF(cpf);
        if (!op.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(op.get());
    }

    @GetMapping("/validar-email/{email}")
    public ResponseEntity emailValidate(@PathVariable String email) {
        Optional<Usuario> pessoa = pessoas.emailValidate(email);
        if (!pessoa.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok().build();
    }

    @PutMapping("/{id}")
//    @PreAuthorize("authentication.name == #pessoa.login")
    public ResponseEntity<Pessoa> update(
            @RequestBody PessoaDTO pessoa,
            @PathVariable Long id,
            @RequestParam Boolean alterarSenha) {

        Optional<Pessoa> optional = pessoas.findByIdUsuario(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        Pessoa existente = optional.get();

        Optional<Pessoa> aux = pessoas.update(pessoa, existente, alterarSenha);
        if (!aux.isPresent()) {
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.ok(aux.get());
    }

    @DeleteMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Pessoa> delete(@PathVariable Long id) {
        Optional<Pessoa> pessoa = pessoas.findByIdUsuario(id);
        if (!pessoa.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            pessoas.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }

}
