package com.alessiojr.account.serializer;

import com.alessiojr.account.model.Conta;
import com.alessiojr.account.model.Pessoa;
import com.alessiojr.account.model.Transacao;
import com.alessiojr.security.model.Usuario;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import org.springframework.beans.BeanUtils;

public class TransacaoSerializer extends StdSerializer<Transacao> {

    public TransacaoSerializer() {
        this(null);
    }

    public TransacaoSerializer(Class<Transacao> t) {
        super(t);
    }

    @Override
    public void serialize(Transacao t, JsonGenerator jg, SerializerProvider sp) throws IOException {
        jg.writeStartObject();
        jg.writeNumberField("idTransacao", t.getIdTransacao());
        jg.writeObjectField("tipo", t.getTipo());
        jg.writeStringField("dataHora", t.getDataHora().toString());
        jg.writeStringField("descricao", t.getDescricao());
        jg.writeNumberField("valor", t.getValor());

        if (t.getConta() != null) {
            Pessoa u;
            if (t.getConta().getUsuario() != null) {
                u = new Pessoa();
                BeanUtils.copyProperties(t.getConta().getUsuario(), u, "conta");
            } else {
                u = null; // caso da conta Nutrilight
            }

            Conta temp = new Conta();
            BeanUtils.copyProperties(t.getConta(), temp, "transacoes", "usuario"); // auxiliar

            temp.setUsuario(u);

            jg.writeObjectField("conta", temp);
        }

        jg.writeEndObject();
    }

}
