package com.alessiojr.apertium.resource;

import com.alessiojr.apertium.model.LemmaDTO;
import com.alessiojr.apertium.model.LemmaDef;
import com.alessiojr.apertium.model.MyDictionary;
import com.alessiojr.apertium.model.ParDef;
import com.alessiojr.apertium.repository.LemmaDefRepository;
import com.alessiojr.apertium.repository.MyDictionaryRepository;
import com.alessiojr.apertium.repository.ParDefRepository;
import com.alessiojr.apertium.util.DicLoader;
import com.alessiojr.apertium.util.GitConnector;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.repository.UsuarioRepository;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 *
 * @author vinicius
 */
@CrossOrigin
@RestController
@RequestMapping("/lemma")
public class LemmaController {

    @Autowired
    private UsuarioRepository usuarioRepository;
    @Autowired
    private LemmaDefRepository lemmaDefRepository;
    @Autowired
    private MyDictionaryRepository myDictionaryRepository;
    @Autowired
    private ParDefRepository parDefRepository;

    @GetMapping("")
    public ResponseEntity<List<LemmaDTO>> findAll(@RequestParam long myDictionary_id, @RequestParam boolean inflections) {
        MyDictionary myDictionary;
        myDictionary = (MyDictionary) this.myDictionaryRepository.findById(myDictionary_id).orElse(null);
        if (myDictionary == null) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body(null);
        }
        return ResponseEntity.ok(LemmaDTO.listConstructor(this.lemmaDefRepository.findAllByMyDictionary(myDictionary), inflections));
    }

    @PostMapping("")
    public ResponseEntity create(@RequestParam String name, @RequestParam String invariant, @RequestParam long myDictionary_id, @RequestParam long parDef_id) {
        Authentication auth = SecurityContextHolder.getContext().getAuthentication();
        Usuario user = (Usuario) this.usuarioRepository.findByLogin((String) auth.getPrincipal()).orElse(null);
        if (user == null) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).build();
        }
        MyDictionary myDix = (MyDictionary) this.myDictionaryRepository.findById(myDictionary_id).orElse(null);
        if (myDix == null || user.getIdUsuario() != myDix.getUser().getIdUsuario()) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
        }
        ParDef parDef = (ParDef) this.parDefRepository.findById(parDef_id).orElse(null);
        if (parDef == null || parDef.getMyDictionary().getId() != myDictionary_id) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
        }
        LemmaDef lemmaDef = (LemmaDef) this.lemmaDefRepository.findByName(name).orElse(null);
        if (lemmaDef != null || name.trim().isEmpty()|| invariant.trim().isEmpty()) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
        }
        lemmaDef = new LemmaDef(name, invariant, myDix, parDef);
        DicLoader dicLoader = new DicLoader(null, null, null);
        GitConnector gitConnector = new GitConnector();
        if (!dicLoader.add_lemma(myDix, lemmaDef) || !gitConnector.dix_commit(user.getLogin() + myDictionary_id, myDix)) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).build();
        }
        this.lemmaDefRepository.save(lemmaDef);
        return ResponseEntity.status(HttpStatus.CREATED).build();
    }

}
