package com.alessiojr.apertium.resource;

import com.alessiojr.apertium.model.MyDictionary;
import com.alessiojr.apertium.model.MyDictionaryDTO;
import com.alessiojr.apertium.model.OfficialDictionary;
import com.alessiojr.apertium.repository.LemmaDefRepository;
import com.alessiojr.apertium.repository.MyDictionaryRepository;
import com.alessiojr.apertium.repository.OfficialDictionaryRepository;
import com.alessiojr.apertium.repository.ParDefRepository;
import com.alessiojr.apertium.repository.SymDefRepository;
import com.alessiojr.apertium.util.DicLoader;
import com.alessiojr.apertium.util.GitConnector;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.repository.UsuarioRepository;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 *
 * @author vinicius
 */
@CrossOrigin
@RestController
@RequestMapping("/mydictionary")
public class MyDictionaryController {

    @Autowired
    private UsuarioRepository usuarioRepository;
    @Autowired
    private MyDictionaryRepository myDictionaryRepository;
    @Autowired
    private OfficialDictionaryRepository officialDictionaryRepository;
    @Autowired
    private SymDefRepository symDefRepository;
    @Autowired
    private ParDefRepository parDefRepository;
    @Autowired
    private LemmaDefRepository lemmaDefRepository;

    @PostMapping("")
    public ResponseEntity<MyDictionaryDTO> create(@RequestParam String name, @RequestParam long officialDictionary_id) {
        MyDictionary dix;
        OfficialDictionary official_dix;
        GitConnector git;
        Usuario user;
        Authentication auth;
        try {
            if (name.trim().isEmpty()) {
                return ResponseEntity.status(HttpStatus.BAD_REQUEST).body(null);
            }
            auth = SecurityContextHolder.getContext().getAuthentication();
            user = (Usuario) this.usuarioRepository.findByLogin((String) auth.getPrincipal()).orElse(null);
            if (user == null) {
                return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
            }
            official_dix = (OfficialDictionary) this.officialDictionaryRepository.findById(officialDictionary_id).orElse(null);
            if (official_dix == null) {
                return ResponseEntity.status(HttpStatus.BAD_REQUEST).body(null);
            }

            dix = new MyDictionary();
            git = new GitConnector();
            dix.setName(name);
            dix.setUser(user);
            dix.setOfficialDictionary(official_dix);
            this.myDictionaryRepository.save(dix);
            if (git.dix_import(official_dix.getLanguage(), official_dix.getFileName(), official_dix.getReference(), user.getIdUsuario(), dix.getId())
                    && git.branch_create(official_dix.getLanguage(), user.getLogin() + dix.getId(), official_dix.getReference())) {
                return ResponseEntity.status(HttpStatus.CREATED).body(new MyDictionaryDTO(dix));
            } else {
                return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
        }
    }

    @GetMapping("")
    public List<MyDictionaryDTO> findAll() {
        Authentication auth = SecurityContextHolder.getContext().getAuthentication();
        Usuario user = (Usuario) this.usuarioRepository.findByLogin((String) auth.getPrincipal()).orElse(null);
        if (user == null) {
            return null;
        }
        return MyDictionaryDTO.listConstructor(this.myDictionaryRepository.findByUser(user));
    }

    @PostMapping("/load/{myDictionary_id}")
    public ResponseEntity load(@PathVariable long myDictionary_id) {
        DicLoader dicLoader;
        MyDictionary myDictionary;
        myDictionary = (MyDictionary) this.myDictionaryRepository.findById(myDictionary_id).orElse(null);
        if (myDictionary == null) {
            return new ResponseEntity(HttpStatus.BAD_REQUEST);
        }
        dicLoader = new DicLoader(this.symDefRepository, this.parDefRepository, this.lemmaDefRepository);
        dicLoader.load_dic(myDictionary);
        return new ResponseEntity(HttpStatus.OK);
    }

}
