package com.alessiojr.apertium.resource;

import com.alessiojr.apertium.config.Config;
import com.alessiojr.apertium.model.OfficialDictionary;
import com.alessiojr.apertium.repository.OfficialDictionaryRepository;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.configurationprocessor.json.JSONArray;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 *
 * @author vinicius
 */
@CrossOrigin
@RestController
@RequestMapping("/officialdictionary")
public class OfficialDictionaryController {

    @Autowired
    private OfficialDictionaryRepository officialDictionaryRepository;

    @GetMapping("")
    public List<OfficialDictionary> findAll() {
        return this.officialDictionaryRepository.findAll();
    }

    @PostMapping("/refresh")
    public ResponseEntity refresh() {
        URL url;
        HttpURLConnection con;
        BufferedReader br;
        StringBuilder sb;
        String output, json;
        JSONArray jsonarray;
        OfficialDictionary dix;

        try {
            for (String language : Config.REMOTE_URL.keySet()) {

                url = new URL(Config.REMOTE_URL.get(language) + "/repository/tags");
                con = (HttpURLConnection) url.openConnection();
                con.setRequestProperty("Private-Token", Config.PRIVATE_TOKEN);
                con.setRequestMethod("GET");

                br = new BufferedReader(new InputStreamReader((con.getInputStream())));
                sb = new StringBuilder();
                while ((output = br.readLine()) != null) {
                    sb.append(output);
                }
                json = sb.toString();
                jsonarray = new JSONArray(json);
                for (int i = 0; i < jsonarray.length(); i++) {
                    dix = (OfficialDictionary) this.officialDictionaryRepository.findByReference(jsonarray.getJSONObject(i).getString("target")).orElse(new OfficialDictionary());
                    dix.setVersion(jsonarray.getJSONObject(i).getString("name"));
                    dix.setLanguage(language);
                    dix.setReference(jsonarray.getJSONObject(i).getString("target"));
                    dix.setFileName(Config.REMOTE_FILENAME.get(language));
                    this.officialDictionaryRepository.save(dix);
                }
            }
        } catch (Exception e) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
        }
        
        return ResponseEntity.ok().build();
    }
}
