package com.alessiojr.apertium.util;

import com.alessiojr.apertium.config.Config;
import com.alessiojr.apertium.model.LemmaDef;
import com.alessiojr.apertium.model.LemmaInflection;
import com.alessiojr.apertium.model.MyDictionary;
import com.alessiojr.apertium.model.ParDef;
import com.alessiojr.apertium.model.ParEntry;
import com.alessiojr.apertium.model.SymDef;
import com.alessiojr.apertium.repository.LemmaDefRepository;
import com.alessiojr.apertium.repository.ParDefRepository;
import com.alessiojr.apertium.repository.SymDefRepository;
import dics.elements.dtd.Dictionary;
import dics.elements.dtd.DixElement;
import dics.elements.dtd.E;
import dics.elements.dtd.I;
import dics.elements.dtd.Par;
import dics.elements.dtd.Pardef;
import dics.elements.dtd.S;
import dics.elements.dtd.Sdef;
import dics.elements.dtd.Section;
import dics.elements.dtd.TextElement;
import dictools.utils.DicOpts;
import dictools.utils.DictionaryReader;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import springfox.documentation.swagger.web.UiConfiguration.Constants;

/**
 *
 * @author vinicius
 */
public class DicLoader {

    private final SymDefRepository symDefRepository;
    private final ParDefRepository parDefRepository;
    private final LemmaDefRepository lemmaDefRepository;

    private DictionaryReader dicReader;
    private Dictionary dic;
    private Map<String, SymDef> symbolsMap;
    private Map<String, ParDef> parDefMap;

    public DicLoader(SymDefRepository symDefRepository, ParDefRepository parDefRepository, LemmaDefRepository lemmaDefRepository) {
        this.symDefRepository = symDefRepository;
        this.parDefRepository = parDefRepository;
        this.lemmaDefRepository = lemmaDefRepository;
    }

    public void load_dic(MyDictionary myDictionary) {
        this.dicReader = new DictionaryReader(Config.LOCAL_REPO_FILE + myDictionary.getLocal_file());
        this.dic = dicReader.readDic();

        this.symbolsMap = new HashMap<>();
        this.parDefMap = new HashMap<>();

        this.parDefRepository.deleteAllByMyDictionary(myDictionary);
        this.symDefRepository.deleteAllByMyDictionary(myDictionary);
        this.lemmaDefRepository.deleteAllByMyDictionary(myDictionary);
        this.load_symbol(myDictionary);
        this.load_par(myDictionary);
        this.load_lemma(myDictionary);
        this.symbolsMap = null;
        this.parDefMap = null;
    }

    private void load_symbol(MyDictionary myDictionary) {
        SymDef symDef;
        for (Sdef s : this.dic.sdefs.elements) {
            symDef = new SymDef();
            symDef.setName(s.getValue());
            symDef.setMyDictionary(myDictionary);
            this.symbolsMap.put(symDef.getName(), symDef);
        }
        this.symDefRepository.saveAll(this.symbolsMap.values());
    }

    private void load_par(MyDictionary myDictionary) {
        ParDef parDef;
        ParEntry entry;

        for (Pardef el : this.dic.pardefs.elements) {
            parDef = new ParDef();
            parDef.setName(el.name);
            parDef.setParEntry(new LinkedList<>());
            for (int i = 0; i < el.elements.size(); i++) {
                entry = new ParEntry();
                entry.setL(el.elements.get(i).getFirstPartAsL().getValue());

                entry.setRSymbols(new LinkedList<>());

                for (DixElement e : el.elements.get(i).getFirstPartAsR().children) {
                    if (e instanceof S) {

                        if (!this.symbolsMap.containsKey(e.getValue())) {
                            // o simbolo usado nao foi definido
                        } else {
                            entry.getRSymbols().add(this.symbolsMap.get(e.getValue()));
                        }
                    }
                }
                entry.setParDef(parDef);
                parDef.getParEntry().add(entry);
            }
            parDef.setMyDictionary(myDictionary);
            this.parDefMap.put(parDef.getName(), parDef);
        }
        this.parDefRepository.saveAll(this.parDefMap.values());
    }

    private void load_lemma(MyDictionary myDictionary) {
        List<LemmaDef> lemmasDefs;
        LemmaDef lemmaDef;

        lemmasDefs = new LinkedList<>();

        for (Section section : this.dic.sections) {
            for (E entry : section.elements) {
                if (entry.getFirstI() == null
                        || !this.parDefMap.containsKey(entry.getFirstParadigm().getValue())
                        || entry.getFirstI().children.size() < 1) {
                    continue;
                }
                lemmaDef = new LemmaDef();
                lemmaDef.setMyDictionary(myDictionary);
                lemmaDef.setInflections(new LinkedList<>());
                lemmaDef.setName(entry.lemma.replaceAll("\\P{Print}", ""));
                lemmaDef.setParDef(this.parDefMap.get(entry.getFirstParadigm().getValue()));
                lemmaDef.setInvariant(entry.getFirstI().getValue().replaceAll("\\P{Print}", ""));
                for (int i = 0; i < this.parDefMap.get(entry.getFirstParadigm().getValue()).getParEntry().size(); i++) {
                    lemmaDef.getInflections().add(new LemmaInflection(lemmaDef, entry.getFirstI().children.get(0).getValue().replaceAll("\\P{Print}", "") + this.parDefMap.get(entry.getFirstParadigm().getValue()).getParEntry().get(i).getL().replaceAll("\\P{Print}", "")));
                }
                lemmasDefs.add(lemmaDef);
            }

        }
        this.lemmaDefRepository.saveAll(lemmasDefs);
    }

    public boolean add_lemma(MyDictionary myDictionary, LemmaDef lemmaDef) {
        this.dicReader = new DictionaryReader(Config.LOCAL_REPO_FILE + myDictionary.getLocal_file());
        this.dic = dicReader.readDic();
        ArrayList<E> list = dic.getEntriesInMainSection();
        E e = new E();
        I i = new I();
        TextElement ic = new TextElement(lemmaDef.getInvariant());
        i.children.add(ic);
        e.children.add(i);
        Par par = new Par(lemmaDef.getParDef().getName());
        e.children.add(par);
        e.lemma = lemmaDef.getName();
        list.add(e);
        dic.printXMLToFile(Config.LOCAL_REPO_FILE + myDictionary.getLocal_file(), DicOpts.STD);
        return true;
    }

//    public static void main(String[] args) {
//        DictionaryReader dicReader = new DictionaryReader("/home/vinicius/ApertiumFiles/1/1.xml");
//        Dictionary dic = dicReader.readDic();
//
//        for (Section section : dic.sections) {
//            for (E entry : section.elements) {
//                if (entry.getFirstI() == null || entry.getFirstI().children.size() < 1) {
//                    continue;
//                }
//                System.out.println(entry.lemma+" "+entry.getFirstI().getValue());
//            }
//
//        }
//    }
}
