package com.alessiojr.apertium.util;

import com.alessiojr.apertium.model.MyDictionary;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import com.alessiojr.apertium.config.Config;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Scanner;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.configurationprocessor.json.JSONArray;
import org.springframework.boot.configurationprocessor.json.JSONObject;
import springfox.documentation.swagger.web.UiConfiguration.Constants;

/**
 *
 * @author vinicius
 */
public class GitConnector {

    private static final Logger logger = LoggerFactory.getLogger(GitConnector.class);

    public boolean dix_import(String dix_language, String remote_file_name, String ref, long userid, long dic_id) {
        URL url;
        HttpURLConnection con;
        File file;
        BufferedReader br;
        BufferedWriter bw;
        String line;
        try {
            url = new URL(Config.REMOTE_URL.get(dix_language) + "/repository/files/" + remote_file_name + "/raw?ref=" + ref);
            con = (HttpURLConnection) url.openConnection();
            con.setRequestProperty("Private-Token", Config.PRIVATE_TOKEN);
            con.setRequestMethod("GET");
            file = new File(Config.LOCAL_REPO_FILE + "/" + userid + "/" + dic_id + ".xml");
            file.getParentFile().mkdirs();
            file.createNewFile();
            br = new BufferedReader(new InputStreamReader((con.getInputStream())));
            bw = new BufferedWriter(new FileWriter(file));
            while ((line = br.readLine()) != null) {
                bw.write(line);
                bw.newLine();
            }
            br.close();
            bw.close();
        } catch (Exception e) {
            StringWriter errors = new StringWriter();
            e.printStackTrace(new PrintWriter(errors));
            GitConnector.logger.error(errors.toString());
            return false;
        }
        return true;
    }

    public boolean branch_create(String dix_language, String branch_name, String ref) {
        URL url;
        HttpURLConnection con;
        try {
            url = new URL(Config.REMOTE_URL.get(dix_language) + "/repository/branches?branch=" + branch_name + "&ref=" + ref);
            con = (HttpURLConnection) url.openConnection();
            con.setRequestProperty("Private-Token", Config.PRIVATE_TOKEN);
            con.setRequestMethod("POST");
            if (con.getResponseCode() != 201) {
                GitConnector.logger.error("branch_create GitLab API response: " + con.getResponseCode() + ": " + con.getResponseMessage());
                return false;
            }
        } catch (Exception e) {
            StringWriter errors = new StringWriter();
            e.printStackTrace(new PrintWriter(errors));
            GitConnector.logger.error(errors.toString());
            return false;
        }
        return true;
    }

    public boolean dix_commit(String branch, MyDictionary myDictionary) {
        try {
            String content = new Scanner(new File(Config.LOCAL_REPO_FILE + myDictionary.getLocal_file())).useDelimiter("\\Z").next();
            JSONObject json = new JSONObject();
            json.accumulate("branch", branch);
            json.accumulate("commit_message", "commit_message");
            JSONArray actions = new JSONArray();
            JSONObject action = new JSONObject();
            action.accumulate("action", "update");
            action.accumulate("file_path", "apertium-por.por.dix");
            action.accumulate("content", content);
            actions.put(action);
            json.put("actions", actions);
            URL url = new URL(Config.REMOTE_URL.get(myDictionary.getOfficialDictionary().getLanguage()) + "/repository/commits");
            HttpURLConnection con = (HttpURLConnection) url.openConnection();
            con.setRequestMethod("POST");
            con.setRequestProperty("Private-Token", Config.PRIVATE_TOKEN);
            con.setRequestProperty("Content-type", "application/json");
            con.setDoOutput(true);
            OutputStreamWriter writer = new OutputStreamWriter(con.getOutputStream(), "UTF-8");
            writer.write(json.toString());
            writer.close();
            if (con.getResponseCode() != 201) {
                return false;
            }
            
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
        return true;
    }
}
