package com.alessiojr.config;

import com.alessiojr.config.property.AppProperties;
import com.alessiojr.config.token.CustomTokenEnhancer;
import java.util.Arrays;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.oauth2.config.annotation.configurers.ClientDetailsServiceConfigurer;
import org.springframework.security.oauth2.config.annotation.web.configuration.AuthorizationServerConfigurerAdapter;
import org.springframework.security.oauth2.config.annotation.web.configurers.AuthorizationServerEndpointsConfigurer;
import org.springframework.security.oauth2.provider.token.TokenEnhancer;
import org.springframework.security.oauth2.provider.token.TokenEnhancerChain;
import org.springframework.security.oauth2.provider.token.TokenStore;
import org.springframework.security.oauth2.provider.token.store.JwtAccessTokenConverter;
import org.springframework.security.oauth2.provider.token.store.JwtTokenStore;

@Configuration
public class AuthorizationServerConfig extends AuthorizationServerConfigurerAdapter {

    private static final Logger log = LoggerFactory.getLogger(AuthorizationServerConfig.class);
    
    @Autowired
    private AuthenticationManager authenticationManager;

    @Autowired
    private UserDetailsService userDetailsService;

    @Autowired
    private AppProperties properties;

    @Override
    public void configure(ClientDetailsServiceConfigurer clients) throws Exception {
        log.info("Carregando Configurações");
        clients.inMemory()
                .withClient("angular")
                .secret("{bcrypt}$2a$04$UP5RYPw8uA1Pp1eapPI04.ZaTSw9u8JsGhYgVxX2D7sXX6xG23IFi") // senha: @C3f3tMG@
                .scopes("read", "write")
                .authorizedGrantTypes("password", "refresh_token")
                .accessTokenValiditySeconds(properties.getSecurity().getTempoExpiracaoToken())
                .refreshTokenValiditySeconds(properties.getSecurity().getTempoExpiracaoRefreshToken())
            .and()
                .withClient("mobile")
                .secret("{bcrypt}$2a$04$UP5RYPw8uA1Pp1eapPI04.ZaTSw9u8JsGhYgVxX2D7sXX6xG23IFi") // senha: @C3f3tMG@
                .scopes("read", "write")
                .authorizedGrantTypes("password", "refresh_token")
                .accessTokenValiditySeconds(properties.getSecurity().getTempoExpiracaoToken())
                .refreshTokenValiditySeconds(properties.getSecurity().getTempoExpiracaoRefreshToken())
            .and()
                .withClient("swagger")
                .secret("{bcrypt}$2a$04$UP5RYPw8uA1Pp1eapPI04.ZaTSw9u8JsGhYgVxX2D7sXX6xG23IFi") // senha: @C3f3tMG@
                .scopes("read", "write")
                .authorizedGrantTypes("password", "refresh_token")
                .accessTokenValiditySeconds(properties.getSecurity().getTempoExpiracaoToken())
                .refreshTokenValiditySeconds(properties.getSecurity().getTempoExpiracaoRefreshToken()); // 3600s -> 1h
    }

    @Override
    public void configure(AuthorizationServerEndpointsConfigurer endpoints) throws Exception {
        TokenEnhancerChain tokenEnhancerChain = new TokenEnhancerChain();
        tokenEnhancerChain.setTokenEnhancers(Arrays.asList(tokenEnhancer(), accessTokenConverter()));

        endpoints
                .tokenStore(tokenStore())
                .tokenEnhancer(tokenEnhancerChain)
                .reuseRefreshTokens(false)
                .userDetailsService(userDetailsService)
                .authenticationManager(authenticationManager);

    }

    //@Override
    //public void configure(AuthorizationServerSecurityConfigurer oauthServer) throws Exception {
    //    oauthServer.allowFormAuthenticationForClients();
    //}
  
    @Bean
    public JwtAccessTokenConverter accessTokenConverter() {
        JwtAccessTokenConverter accessTokenConverter = new JwtAccessTokenConverter();
        accessTokenConverter.setSigningKey("cefetmg"); // chave de validacao para o JWT
        return accessTokenConverter;
    }

    @Bean
    public TokenStore tokenStore() {
        return new JwtTokenStore(accessTokenConverter());
    }

    @Bean
    public TokenEnhancer tokenEnhancer() {
        return new CustomTokenEnhancer();
    }

}
