package com.alessiojr.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.security.access.expression.method.MethodSecurityExpressionHandler;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.http.SessionCreationPolicy;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.crypto.factory.PasswordEncoderFactories;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.security.oauth2.config.annotation.web.configuration.ResourceServerConfigurerAdapter;
import org.springframework.security.oauth2.config.annotation.web.configurers.ResourceServerSecurityConfigurer;
import org.springframework.security.oauth2.provider.expression.OAuth2MethodSecurityExpressionHandler;

@Configuration
public class ResourceServerConfig extends ResourceServerConfigurerAdapter {

    @Autowired
    private UserDetailsService userDetailsService;

    @Autowired
    public void configure(AuthenticationManagerBuilder auth) throws Exception {
        auth.userDetailsService(userDetailsService).passwordEncoder(passwordEncoder());
    }

    @Override
    public void configure(HttpSecurity http) throws Exception {
        
             http
                .authorizeRequests()
                    .and()
                    .authorizeRequests()
                .antMatchers(
                        "/**",
                        "/testes/ola**",
                        "/images/**",
                        "/usuarios/foto/**",
                        "/usuarios-franquia/assinatura/**",
                        "/pessoas/validar-login/**",
                        "/pessoas/validar-email/**",
                        "/pessoas/validar-cpf/**",
                        "/usuarios/recuperar-senha/**")
                .permitAll()
                .antMatchers(HttpMethod.GET, // metodos relacionados a agendamento
                        "/cidades",
                        "/cidades/**",
                        "/estados"
                )
                .permitAll()
                .antMatchers(HttpMethod.GET, // submissão ipc -- permitir obtenção das fotos dos diagramas
                        "/submission/**/class-diagram.png",
                        "/submission/**/class-diagram-thumbnail.png",
                        "/submission/**/sequence-diagram.png",
                        "/submission/**/sequence-diagram-thumbnail.png"
                )
                .permitAll()
                .antMatchers(HttpMethod.POST,
                        "/pessoas")
                .permitAll()
                .antMatchers( // liberar swagger ui
                        HttpMethod.GET,
                        "/v2/api-docs",
                        "/swagger-resources/**",
                        "/swagger-ui.html**",
                        "/webjars/**",
                        "favicon.ico"
                ).permitAll()
                //.anyRequest().authenticated()
                 //   .and()
                 //   .csrf().disable()
                     ;
    }

    @Override
    public void configure(ResourceServerSecurityConfigurer resources) throws Exception {
        resources.stateless(true);
    }

    @Bean
    public PasswordEncoder passwordEncoder() {
        return PasswordEncoderFactories.createDelegatingPasswordEncoder();
    }

    @Bean
    public MethodSecurityExpressionHandler createExpressionHandler() {
        return new OAuth2MethodSecurityExpressionHandler();
    }

}
