package com.alessiojr.config;

import com.alessiojr.config.property.AppProperties;
import static com.google.common.collect.Lists.newArrayList;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import static java.util.Collections.singletonList;
import java.util.List;
import java.util.Locale;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpHeaders;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.LocaleResolver;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
import org.springframework.web.servlet.i18n.LocaleChangeInterceptor;
import org.springframework.web.servlet.i18n.SessionLocaleResolver;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.AuthorizationCodeGrantBuilder;
import springfox.documentation.builders.OAuthBuilder;
import springfox.documentation.builders.ParameterBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.builders.ResponseMessageBuilder;
import springfox.documentation.schema.ModelRef;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.ApiKey;
import springfox.documentation.service.AuthorizationCodeGrant;
import springfox.documentation.service.AuthorizationScope;
import springfox.documentation.service.GrantType;
import springfox.documentation.service.OAuth;
import springfox.documentation.service.Parameter;
import springfox.documentation.service.ResourceOwnerPasswordCredentialsGrant;
import springfox.documentation.service.ResponseMessage;
import springfox.documentation.service.SecurityReference;
import springfox.documentation.service.SecurityScheme;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spi.service.contexts.SecurityContext;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger.web.ApiKeyVehicle;
import springfox.documentation.swagger.web.SecurityConfiguration;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

@Configuration
@EnableSwagger2
public class SwaggerConfig implements WebMvcConfigurer {
      
    private static final Logger log = LoggerFactory.getLogger(SwaggerConfig.class);
        
    @Autowired
    private AppProperties properties;

    @Override
    public void addResourceHandlers(ResourceHandlerRegistry registry) {

        registry
                .addResourceHandler("swagger-ui.html")
                .addResourceLocations("classpath:/META-INF/resources/");

        registry
                .addResourceHandler("/webjars/**")
                .addResourceLocations("classpath:/META-INF/resources/webjars/");
    }
    
    
    public LocaleResolver localeResolver() {
        SessionLocaleResolver localeResolver = new SessionLocaleResolver();
        localeResolver.setDefaultLocale(new Locale("pt-BR"));
        return localeResolver;
    }
    
    @Bean
    public LocaleChangeInterceptor localeChangeInterceptor() {
       LocaleChangeInterceptor lci = new LocaleChangeInterceptor();
       lci.setParamName("lang");
       return lci;
    }
    
    @Override
    public void addInterceptors(InterceptorRegistry registry) {
       registry.addInterceptor(localeChangeInterceptor());
    }
   
    private List<ResponseMessage> defaultResponseList(RequestMethod method){
        List<ResponseMessage> list = new java.util.ArrayList<>();
        
        //list.add(new ResponseMessageBuilder().code(401).message("Unauthorized")
        //        .responseModel(new ModelRef("Result")).build());
        //list.add(new ResponseMessageBuilder().code(406).message("Not Acceptable")
        //        .responseModel(new ModelRef("Result")).build());
        //list.add(new ResponseMessageBuilder().code(500).message("500 Server Error message")
        //        .responseModel(new ModelRef("Result")).build());
 
        //        new ResponseMessageBuilder().code(204).message("There is no content.").build(),
//				new ResponseMessageBuilder().code(405).message("Parameter is invalid.").build(),
//				new ResponseMessageBuilder().code(500).message("Failed to process request").build()
  //          		)


        switch(method){
            case POST:
                list.add(new ResponseMessageBuilder().code(201).message("Sucessicul Created")
                 .responseModel(new ModelRef("Result")).build());
                break;
            case GET:

                break;
            case PUT:
                break;
            case DELETE:
                break;
        }

        return list;
    }
    
    private List<Parameter> parameterBuilder() {
        return null;
    }
    
    @Bean
    public Docket apisSecurity() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Security API")
                .select()
                .apis(RequestHandlerSelectors.any())
                .paths(PathSelectors.regex(".*oauth.*"))
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
        
    @Bean
    public Docket apisApertium() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Apertium API")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.apertium"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder()) //Desligado a permissão de acesso
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisAccount() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Contas de Usuários Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.account"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisPedlandia() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Pedlandia API")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.pedlandia"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisLocation() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Location API")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.location"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
   
    @Bean
    public Docket apisTestes() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("API de Testes")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.freeTests"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisEstoque() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("API de Estoques")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.estoque"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisInfluenzer() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Influenzer API")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.influenzer"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisGamePoints() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Game Points API")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.gamepoints"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
     @Bean
    public Docket apisLaboratory() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Laboratory API")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.laboratory"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisFull() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("Full api")
                .select()
                .apis(RequestHandlerSelectors.any())
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisDrDebug() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("DrDebug Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.drDebug"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }

    @Bean
    public Docket apisIpcBlockly() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Blockly Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.blockly"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }

    @Bean
    public Docket apisIpcGame() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Game Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.game"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
     
    @Bean
    public Docket apisIpcProblemManager() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Problem Manager Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.problemManager"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisIpcDataAnalytics() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Data Analytics  Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.dataAnalytics"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    
    @Bean
    public Docket apisIpcQuestions() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Questions  Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.question"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisIpcSchool() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC School Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.school"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisIpcContent() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Content  Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.content"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisIpcCompeticao() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Competicao Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.competicao"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    @Bean
    public Docket apisIpcSubmission() {
        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("IPC Submission  Api")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.alessiojr.ipc.submission"))
                .paths(PathSelectors.any())
                .build()
                .securitySchemes(securitySchema())
                .securityContexts(Collections.singletonList(securityContext())).pathMapping("/")
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .globalOperationParameters(parameterBuilder())
                .globalResponseMessage(RequestMethod.GET, defaultResponseList(RequestMethod.GET))
                .globalResponseMessage(RequestMethod.POST, defaultResponseList(RequestMethod.POST))
                ;                
    }
    
    private ApiInfo apiInfo() {
        return new ApiInfoBuilder()
            .title(properties.getTituloApi())
            .description(properties.getDescricao())
            .contact(properties.getContact().createContactModel())
            .termsOfServiceUrl("https://www.example.com/api")
            .license(properties.getLicense().getName())
            .licenseUrl(properties.getLicense().getUrl())
            .version(properties.getVersao())
            .build();
    }
    
    @Bean
    List<GrantType> grantTypes() {
	
        List<GrantType> grantTypes = new ArrayList<>();
        String AUTH_SERVER = this.properties.getUrlApi() + "/oauth";        
       
        grantTypes.add(new ResourceOwnerPasswordCredentialsGrant(AUTH_SERVER+"/token"));
       
        return grantTypes;
    }
        
    private SecurityContext securityContext() {
        return SecurityContext.builder()
                .securityReferences(defaultAuth())
                .forPaths(PathSelectors.any())
            .build();
               
    }

    @Bean
    public SecurityConfiguration security() {
        
        return new SecurityConfiguration(
                properties.getSecurity().getClientId(), 
                properties.getSecurity().getClientSecret()
                , "","",
                "Bearer access_token", //"Bearer " + token, 
                ApiKeyVehicle.HEADER,
                HttpHeaders.AUTHORIZATION,
                ","); 
       
        //return SecurityConfigurationBuilder.builder()
            //.clientId(properties.getSecurity().getClientId())
            //.clientSecret(properties.getSecurity().getClientSecret())
            //.realm("test-app-realm")
            //.appName("test-app")
            //.scopeSeparator(",")
            //.additionalQueryStringParams(null)
            //.useBasicAuthenticationWithAccessCodeGrant(false)
            //.build();
    }

    private List<SecurityScheme> securitySchema() {
        List<SecurityScheme> lista = new ArrayList<SecurityScheme>();
        lista.add(new OAuth("oauth2schema", newArrayList(scopes()), grantTypes()));
        
        //lista.add(new ApiKey("Bearer %token", "Authorization", "Header"));
        
        return lista;
    }
        
    private List<SecurityReference> defaultAuth() {
        List<SecurityReference> lista = new ArrayList<SecurityReference>();
        lista.add(new SecurityReference("oauth2schema", scopes()));
        //lista.add(new SecurityReference("Bearer", scopes()));
        
        return lista;
    }
  
    private AuthorizationScope[] scopes() {
        AuthorizationScope[] scopes = {
            //new AuthorizationScope("read", "for read operations"), 
            //new AuthorizationScope("write", "for write operations"),
            //new AuthorizationScope("global", "for write operations"),
            //new AuthorizationScope("trust", "trust all")
        };
        
        return scopes;
    }
   
}
