package com.alessiojr.drDebug.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.enums.OpcaoTipoAtividade;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "AtividadePraticaa", columnNames = "id")
        })
@ApiModel(description = "Class representing a practical activity.")
public class AtividadePraticaa implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database practical activity ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Nome da Atividade")
    @Column(length = 128)
    private String nome;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Disciplina da Atividade")
    @Column(length = 128)
    private String disciplina;
    
    @ApiModelProperty(notes = "Valor da Atividade")
    private double valor;  
    
    @Column(name="dtAvaliacao", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data")
    private Date dtAvaliacao;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo de Atividade")
    private OpcaoTipoAtividade tipo;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
        
    public AtividadePraticaa() {
    }

    public AtividadePraticaa(long id, String nome, String disciplina, double valor, Date dtAvaliacao) {
        this.nome = nome;
        this.disciplina = disciplina;
        this.valor = valor;
        this.dtAvaliacao = dtAvaliacao;
    }

}
