package com.alessiojr.drDebug.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.enums.OpcaoLocal;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_DueloDePontos_jogador1", columnNames = "jogador1")
        })
@ApiModel(description = "Class representing a duelo de pontos.")
public class DueloDePontos implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated pessoa ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @Column(length = 128)
    @ApiModelProperty(notes = "Full Name of jogador 1")
    private String jogador1;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @Column(length = 128)
    @ApiModelProperty(notes = "Full Name of jogador 2")
    private String jogador2;
    
    @ApiModelProperty(notes = "Pontos")
    private int pontos;  

    @Column(name="Data", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data")
    private Date dataDoDuelo;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of vencedor")
    @Column(length = 128)
    private String vencedor;
       
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Local")
    private OpcaoLocal local;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
        
    public DueloDePontos() {
    }

    public DueloDePontos(long id) {
        this.id = id;
    }

     public DueloDePontos(long id, String jogador1, String jogador2, int pontos, Date dataDoDuelo, String vencedor) {
        this.id = id;
        this.jogador1 = jogador1;
        this.jogador2 = jogador2;
        this.pontos = pontos;
        this.dataDoDuelo = dataDoDuelo;
        this.vencedor = vencedor;
    }

}
