package com.alessiojr.drDebug.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.enums.OpcaoTipoEmpresa;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CNPJ;
import org.hibernate.validator.constraints.Email;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Empresa_cnpj", columnNames = "cnpj")
        })
@ApiModel(description = "Class representing a company.")
public class Empresa implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated empresa ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 128)
    @ApiModelProperty(notes = "Nome da Empresa")
    @Column(length = 128)
    private String nome;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 256)
    @ApiModelProperty(notes = "Endereço da empresa")
    @Column(length = 128)
    private String endereco;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 256)
    @ApiModelProperty(notes = "Telefone da empresa")
    @Column(length = 128)
    private String tel;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 128)
    @ApiModelProperty(notes = "Email da empresa")
    @Column(length = 128)
    @Email(message = "Email inválido")
    private String email;

    @NotEmpty
    @ApiModelProperty(notes = "CNPJ válido da empresa")
    @CNPJ(message = "Erro no CNPJ")
    private String cnpj;
    
    @Column(name="dataCriacao", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de Criacao")
    private Date dataCriacao;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo")
    private OpcaoTipoEmpresa tipo;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
        
    public Empresa() {
    }

    public Empresa(long id, String nome,String endereco, String tel, String email, String cnpj,OpcaoTipoEmpresa tipo, Date dataCriacao) {
        this.id = id;
        this.nome = nome;
        this.endereco = endereco;
        this.tel = tel;
        this.email = email;
        this.cnpj = cnpj;
        this.dataCriacao = dataCriacao;
        this.tipo = tipo;
    }
}