package com.alessiojr.drDebug.model;

import com.alessiojr.drDebug.util.Type_Game;
import com.alessiojr.drDebug.util.Type_Nivel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import com.alessiojr.drDebug.util.Type_Game;
import com.alessiojr.drDebug.util.Type_Nivel;
import com.alessiojr.ipc.school.model.Disciplina;
import com.fasterxml.jackson.databind.JsonMappingException.Reference;
import com.sun.istack.Nullable;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@AllArgsConstructor
@Entity
@Getter
@Setter
@ApiModel(description = "Class representing a person")
public class Game implements Serializable {

    @Id
    @Column(updatable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @NotEmpty
    @NotBlank
    @Size(min = 2, max = 80)
    private String nome;

    @ApiModelProperty(notes = "Previsão de tempo gasto para resolver o problema")
    private int prev_dias;

    @ApiModelProperty(notes = "Quantidade de níveis presentes em um Game")
    private int qtd_Niveis;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Nível de conhecimento")
    private Type_Nivel nivel;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo de Game")
    private Type_Game tipo;

    @ApiModelProperty(notes = "Descrição breve do problema")
    @Size(min = 1, max = 255)
    private String descricao;

    @ManyToOne
    @JoinColumn(foreignKey = @ForeignKey(name = "FK_Game_Disciplina"), name = "disciplina_id", nullable = false, referencedColumnName = "id")
    private Disciplina disciplina;

}
