package com.alessiojr.drDebug.model;

import com.alessiojr.common.enums.Status;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;

@Entity
@Getter
@Setter
@Table(uniqueConstraints = { @UniqueConstraint(name = "UK_GameNivel", columnNames = "id") })
@ApiModel(description = "Class representing a nivel.")
public class GameNivel implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "O programa gerou o ID no Nivel")
    private long id;

    @NotEmpty
    @NotBlank
    @Size(min = 5, max = 128)
    @ApiModelProperty(notes = "Nome do nível")
    private String nome;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 255)
    @ApiModelProperty(notes = "Descrição do nível")
    private String descricao;

    @Column(updatable = false, nullable = false)
    @ApiModelProperty(notes = "Experiência mínima para passar de nível")
    private long exp;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(updatable = false, nullable = false)
    @ApiModelProperty(notes = "Tempo aberto")
    private Date tempo;

    @NotEmpty
    @NotBlank
    @Size(min = 5, max = 255)
    @ApiModelProperty(notes = "acao")
    private String acao;

    @NotEmpty
    @NotBlank
    @ApiModelProperty(notes = "Icone do Nível")
    private String icone;

    @NotNull
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Status do Nível do game")
    private Status status;

    @ManyToOne
    @JoinColumn(foreignKey = @ForeignKey(name = "FK_GameNivel_GameNivelgame"), name = "game_id", nullable = false, referencedColumnName = "id")
    private Game game;

    public GameNivel() {
    }

    public GameNivel(String nome, String descricao, long exp, String acao, String icone) {
        this.nome = nome;
        this.descricao = descricao;
        this.exp = exp;
        this.acao = acao;
        this.icone = icone;
    }
}
