package com.alessiojr.drDebug.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.OpcaoCategoriaTime;
import com.alessiojr.drDebug.model.OpcaoFiliacaoTime;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
    uniqueConstraints = {
        //@UniqueConstraint(name = "UK_Pessoa_cpf", columnNames = "cpf")
        @UniqueConstraint(name = "UK_Time_id", columnNames = "id")
    })
@ApiModel(description = "Class representing a time.")
public class Time implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated software ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of Software")
    @Column(length = 128)
    private String nome;
    
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Categoria")
    private OpcaoCategoriaTime categoria;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @Column(length = 128)
    @ApiModelProperty(notes = "País")
    private String pais;    
    
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Filiação")
    private OpcaoFiliacaoTime filiacao;

    @ApiModelProperty(notes = "Conquistas")
    private int conquistas;
    
    @Column(name="Data", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de Criação")
    private Date data;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;

    
    public Time() {
    }

    public Time(long id, String nome, String pais, int conquistas, Date data) {
        this.id = id;
        this.nome = nome;
        this.pais = pais;
        this.conquistas = conquistas;
        this.data = data;
    }
/*
    public Software(String nome, String cpf) {
        this.nome = nome;
        this.cpf = cpf;
    }
*/

}
