package com.alessiojr.drDebug.resource;

import com.alessiojr.drDebug.model.DueloDePontos;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.alessiojr.drDebug.service.DueloDePontossService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.RequestParam;

@CrossOrigin
@RestController
@RequestMapping("/drdebug/dueloDePontos")
@Api(value = "/drdebug/dueloDePontos", tags = "Duelo De Pontos",  description = "Operações sobre a Entidade Duelo de pontos")
public class DueloDePontosController {
    
    private static final Logger log = LoggerFactory.getLogger(DueloDePontosController.class);
    
    @Autowired
    private DueloDePontossService dueloDePontoss;

    //GET - Read all resource
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<DueloDePontos> findAll(
            @RequestParam Long id,
            @RequestParam Integer pagina) {
        return this.dueloDePontoss.findByIdContaining(id, pagina);
    }
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<DueloDePontos >findAll(
            @RequestParam Integer pagina) {
        return this.dueloDePontoss.findAll(pagina);
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<DueloDePontos> findById(@PathVariable Long id){
        log.info("Passei no /drdebug/dueloDePontos/" + id);
        Optional<DueloDePontos> dueloDePontos = dueloDePontoss.findById(id);
       
        if (!dueloDePontos.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(dueloDePontos.get());
    }


    @DeleteMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /drdebug/dueloDePontos/" + id);
        Optional<DueloDePontos> parceiro = dueloDePontoss.findById(id);
        if (!parceiro.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            dueloDePontoss.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
    
    //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<DueloDePontos> update(@RequestBody @Valid DueloDePontos dueloDePontos, @PathVariable Long id) {
        Optional<DueloDePontos> optional = dueloDePontoss.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        DueloDePontos existente = optional.get();
        return ResponseEntity.ok(dueloDePontoss.update(dueloDePontos, existente));
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single duelo de pontos", response = DueloDePontos.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe um duelo de pontos para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public ResponseEntity<DueloDePontos>  create(
        @ApiParam(value = "Pessoas com elementos Nome e CPf") @Valid @RequestBody DueloDePontos dueloDePontos) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(dueloDePontoss.insert(dueloDePontos));
	}
}


//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/