package com.alessiojr.drDebug.resource;

import com.alessiojr.drDebug.model.Game;
import com.alessiojr.drDebug.repository.GameRepository;
import java.util.List;
import java.util.Optional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RequestBody;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import javax.validation.Valid;
import org.springframework.http.HttpStatus;
import org.springframework.web.server.ResponseStatusException;

/**
 *
 * @author adrlvma
 */

@CrossOrigin
@RestController
@RequestMapping("/drdebug/game")
@Api(value = "/Game", tags = "Game Controller", description = "Operações sobre os objetos Game")
public class GameController {

    @Autowired //Manda o Spring boot gerenciar a linha abaixo.
    private GameRepository gameRepository;

    @ApiOperation(value = "View", response = List.class)
    @GetMapping("/")
    public List<Game> findAll() {
        return this.gameRepository.findAll();
    }

    @GetMapping("/{nome}")
    public ResponseEntity<Game> findByName(@PathVariable String Nome) {
        Optional<Game> game = gameRepository.findByNome(Nome);

        if (!game.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(game.get());

    }

    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id) {
        this.gameRepository.deleteById(id);
    }

    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody Game game) {

        Optional<Game> gameExistente = gameRepository.findById(id);

        if (gameExistente.isPresent()) {
            Game g = gameExistente.get();
            g.setId(game.getId());
            g.setNome(game.getNome());
            g.setPrev_dias(game.getPrev_dias());
            gameRepository.save(g);
            return ResponseEntity.ok("Product updated successfully");
        } else {
            return ResponseEntity.notFound().build();
        }

    }

    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Game", response = Game.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma Game para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public Game create(
            @ApiParam(value = "Jogos com descrição.") @Valid @RequestBody Game game) {
        Optional gameExistente = gameRepository.findById(game.getId());

        if (gameExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST, "Já existe game com essa descrição.");
        }
        return gameRepository.save(game);
    }
}
