package com.alessiojr.drDebug.resource;

import com.alessiojr.drDebug.model.LinguagemProgramacao;
import com.alessiojr.drDebug.repository.LinguagemProgramacaoRepository;
import com.alessiojr.drDebug.service.LinguagemProgramacaosService;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/linguagemProgramacao")
@Api(value = "/linguagemProgramacao", tags = "Linguagem Programacao Controler",  description = "Operações sobre a Entidade Linguagem Programacao")
public class LinguagemProgramacaoController {
    
    private static final Logger log = LoggerFactory.getLogger(AtividadePraticaController.class);
    
    @Autowired
    private LinguagemProgramacaosService linguagemprogramacaos;

    //GET - Read all resource
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"Nomelinguagem", "pagina"})
    public Page<LinguagemProgramacao> findAll(
            @RequestParam String Nomelinguagem,
            @RequestParam Integer pagina) {
        return this.linguagemprogramacaos.findByNomeContaining(Nomelinguagem, pagina);
    }
    
    //GET - Read a resource    
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<LinguagemProgramacao> findById(@PathVariable Long id){
        log.info("Passei no /atividadePratica/" + id);
        Optional<LinguagemProgramacao> p = linguagemprogramacaos.findById(id);
       
        if (!p.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(p.get());
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /drdebug/atividadePratica/" + id);
        Optional<LinguagemProgramacao> parceiro = linguagemprogramacaos.findById(id);
        if (!parceiro.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            linguagemprogramacaos.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
    //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<LinguagemProgramacao> update(@RequestBody @Valid LinguagemProgramacao linguagemProgramacao, @PathVariable Long id) {
        Optional<LinguagemProgramacao> optional = linguagemprogramacaos.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        LinguagemProgramacao existente = optional.get();
        return ResponseEntity.ok(linguagemprogramacaos.update(linguagemProgramacao, existente));
    }
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Atividade Pratica", response = LinguagemProgramacao.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma stividade com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public ResponseEntity<LinguagemProgramacao> create(
            @ApiParam(value = "Atividades com elementos Nome e Id") @Valid @RequestBody LinguagemProgramacao p) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(linguagemprogramacaos.insert(p));
	}
}
//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/


//LinguagemProgramacaoController