package com.alessiojr.drDebug.resource;

import com.alessiojr.drDebug.model.Time;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alessiojr.drDebug.repository.TimesRepository;
import com.alessiojr.drDebug.service.TimesService;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.resource.PessoaTesteResource;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/drdebug/time")
@Api(value = "/drdebug/time", tags = "Times",  description = "Operações sobre a Entidade Time")
public class TimesController {
    
    private static final Logger log = LoggerFactory.getLogger(TimesController.class);
    
    @Autowired
    private TimesService times;

    //GET - Read all resource
    //Veja uma lista de produtos disponíveis
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<Time >findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.times.findByNomeContaining(nome, pagina);
    }
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<Time >findAll(
            @RequestParam Integer pagina) {
        return this.times.findAll(pagina);
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Time> findById(@PathVariable Long id){
        log.info("Passei no /drdebug/time" + id);
        Optional<Time> time = times.findById(id);
       
        if (!time.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(time.get());
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /drdebug/time" + id);
        Optional<Time> parceiro = times.findById(id);
        if (!parceiro.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            times.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity<Time> update(@RequestBody @Valid Time time, @PathVariable Long id) {
        Optional<Time> optional = times.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Time existente = optional.get();
        return ResponseEntity.ok(times.update(time, existente));
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Time", response = Time.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe um Software para esta com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public ResponseEntity<Time>  create(
        @ApiParam(value = "Times com elementos Nome, país, conquistas e data") @Valid @RequestBody Time time) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(times.insert(time));
	}
}


//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/