package com.alessiojr.drDebug.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.AtividadePraticaa;
import com.alessiojr.drDebug.repository.AtividadePraticaRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class AtividadesPraticasService {

    @Autowired
    private AtividadePraticaRepository<AtividadePraticaa> atividadesPraticas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<AtividadePraticaa> findByNomeContaining(String nome, Integer pagina) {
       
        return this.atividadesPraticas.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<AtividadePraticaa> findAll(Integer pagina) {
        return this.atividadesPraticas.findAll(PageRequest.of(pagina, 10));
    }

    public AtividadePraticaa insert(AtividadePraticaa parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.atividadesPraticas.save(parceiro);
    }

    public Optional<AtividadePraticaa> findById(Long id) {
        Optional<AtividadePraticaa> parceiro = atividadesPraticas.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public AtividadePraticaa update(AtividadePraticaa parceiro, AtividadePraticaa existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.atividadesPraticas.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<AtividadePraticaa> op = this.atividadesPraticas.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.atividadesPraticas.save(op.get());
        }
    }

}
