package com.alessiojr.drDebug.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.DueloDePontos;
import com.alessiojr.drDebug.repository.DueloDePontosRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class DueloDePontossService {

    @Autowired
    private DueloDePontosRepository<DueloDePontos> dueloDePontoss;

    @Autowired
    private CurrentUserService currentUser;

    public Page<DueloDePontos> findByIdContaining(Long id, Integer pagina) {
       
        return this.dueloDePontoss.findByIdContaining(id, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<DueloDePontos> findAll(Integer pagina) {
        return this.dueloDePontoss.findAll(PageRequest.of(pagina, 10));
    }

    public DueloDePontos insert(DueloDePontos parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.dueloDePontoss.save(parceiro);
    }

    public Optional<DueloDePontos> findById(Long id) {
        Optional<DueloDePontos> parceiro = dueloDePontoss.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public DueloDePontos update(DueloDePontos parceiro, DueloDePontos existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.dueloDePontoss.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<DueloDePontos> op = this.dueloDePontoss.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.dueloDePontoss.save(op.get());
        }
    }

}
