package com.alessiojr.drDebug.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.Empresa;
import com.alessiojr.drDebug.repository.EmpresaRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class EmpresasService {

    @Autowired
    private EmpresaRepository<Empresa> empresas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Empresa> findByNomeContaining(String nome, Integer pagina) {
       
        return this.empresas.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Empresa> findAll(Integer pagina) { 
        return this.empresas.findAll(PageRequest.of(pagina, 10));
    }

    public Empresa insert(Empresa e) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                e.setStatus(Status.PUBLICO);
            } else {
                e.setStatus(Status.PRIVADO);
            }
        }

        return this.empresas.save(e);
    }

    public Optional<Empresa> findById(Long id) {
        Optional<Empresa> parceiro = empresas.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public Empresa update(Empresa parceiro, Empresa existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.empresas.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<Empresa> op = this.empresas.findById(id);
        if (op.isPresent()) {
            //op.get().setStatus(Status.INATIVO);
            this.empresas.save(op.get());
        }
    }

}
