package com.alessiojr.drDebug.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.GameNivel;
import com.alessiojr.drDebug.repository.GameNivelRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class GameNivelService {

    @Autowired
    private GameNivelRepository<GameNivel> gniveis;

    @Autowired
    private CurrentUserService currentUser;

    public Page<GameNivel> findByNomeContaining(String nome, Integer pagina) {
        return this.gniveis.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<GameNivel> findAll(Integer pagina) {
        return this.gniveis.findAll(PageRequest.of(pagina, 10));
    }

    public GameNivel insert(GameNivel parceiro) {
        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.gniveis.save(parceiro);
    }

    public Optional<GameNivel> findById(Long id) {
        Optional<GameNivel> parceiro = gniveis.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public GameNivel update(GameNivel parceiro, GameNivel existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.gniveis.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<GameNivel> op = this.gniveis.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.gniveis.save(op.get());
        }
    }

}
