package com.alessiojr.drDebug.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.LinguagemProgramacao;
import com.alessiojr.drDebug.repository.LinguagemProgramacaoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class LinguagemProgramacaosService {

    @Autowired
    private LinguagemProgramacaoRepository<LinguagemProgramacao> linguagemProgramacaos;

    @Autowired
    private CurrentUserService currentUser;

    public Page<LinguagemProgramacao> findByNomeContaining(String nome, Integer pagina) {
       
        return this.linguagemProgramacaos.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<LinguagemProgramacao> findAll(Integer pagina) {
        return this.linguagemProgramacaos.findAll(PageRequest.of(pagina, 10));
    }

    public LinguagemProgramacao insert(LinguagemProgramacao parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.linguagemProgramacaos.save(parceiro);
    }

    public Optional<LinguagemProgramacao> findById(Long id) {
        Optional<LinguagemProgramacao> parceiro = linguagemProgramacaos.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public LinguagemProgramacao update(LinguagemProgramacao parceiro, LinguagemProgramacao existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.linguagemProgramacaos.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<LinguagemProgramacao> op = this.linguagemProgramacaos.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.linguagemProgramacaos.save(op.get());
        }
    }

}
