package com.alessiojr.drDebug.service;

import com.alessiojr.freeTests.service.*;
import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.Time;
import com.alessiojr.drDebug.repository.TimesRepository;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.repository.PessoaTesteRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class TimesService {

    @Autowired
    private TimesRepository<Time> times;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Time> findByNomeContaining(String nome, Integer pagina) {
       
        return this.times.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Time> findAll(Integer pagina) {
        return this.times.findAll(PageRequest.of(pagina, 10));
    }

    public Time insert(Time parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.times.save(parceiro);
    }

    public Optional<Time> findById(Long id) {
        Optional<Time> parceiro = times.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public Time update(Time parceiro, Time existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.times.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<Time> op = this.times.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.times.save(op.get());
        }
    }

}
