package com.alessiojr.drDebug.util;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.nio.file.StandardCopyOption;
import javax.imageio.ImageIO;

public class Files {
    public static File getFile(String relativePath) {
        return new File("./" + relativePath);
    }

    public static String getRootPath() {
        String rootPath = new File(".").getAbsolutePath();
        return rootPath.replace("/.", "");
    }

    public static void resizeImageHeight(String inputImagePath, String outputImagePath, float newHeight)
            throws IOException {

        // reads input image
        File inputFile = new File(inputImagePath);
        BufferedImage inputImage = ImageIO.read(inputFile);
                
        float newWidth = newHeight / inputImage.getHeight() * inputImage.getWidth();


        // creates output image
        BufferedImage outputImage = new BufferedImage((int) newWidth, (int) newHeight, inputImage.getType());
 
        // scales the input image to the output image
        Graphics2D g2d = outputImage.createGraphics();
        g2d.drawImage(inputImage, 0, 0, (int) newWidth, (int) newHeight, null);
        g2d.dispose();
 
        // extracts extension of output file
        String formatName = outputImagePath.substring(outputImagePath
                .lastIndexOf(".") + 1);
 
        // writes to output file
        ImageIO.write(outputImage, formatName, new File(outputImagePath));
    }

    public static void createRelativeFolder(String folder) {
        new File(getRootPath() + "/" + folder).mkdirs();
    }

    public static void copyDirectory(String relativeSourceFolder, String relativeDestFolder) throws IOException {
        String rootPath = getRootPath();

        File sourceFolder = new File(rootPath + "/" + relativeSourceFolder);

        // Target directory where files should be copied
        File destinationFolder = new File(rootPath + "/" + relativeDestFolder);

        // Call Copy function
        copyFolderRecursively(sourceFolder, destinationFolder);
    }

    private static void copyFolderRecursively(File sourceFolder, File destinationFolder) throws IOException {
        if (sourceFolder.isDirectory()) {
            // Verify if destinationFolder is already present; If not then create it
            if (!destinationFolder.exists()) {
                destinationFolder.mkdir();
            }

            // Get all files from source directory
            String files[] = sourceFolder.list();

            // Iterate over all files and copy them to destinationFolder one by one
            for (String file : files) {
                File srcFile = new File(sourceFolder, file);
                File destFile = new File(destinationFolder, file);

                // Recursive function call
                copyFolderRecursively(srcFile, destFile);
            }
        } else {
            // Copy the file content from one place to another
            java.nio.file.Files.copy(sourceFolder.toPath(), destinationFolder.toPath(),
                    StandardCopyOption.REPLACE_EXISTING);
        }
    }
}