package com.alessiojr.estoque.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;

import com.alessiojr.common.enums.Status;
import com.alessiojr.estoque.enums.FormaDePagamento;
import com.fasterxml.jackson.annotation.JsonFormat;
import javax.persistence.ForeignKey;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import lombok.Getter;
import lombok.Setter;

/**
 *
 * @author Abner Kaizer
 */
@Getter
@Setter
@Entity
@Table(uniqueConstraints = {
    @UniqueConstraint(name = "UK_Compra_ID", columnNames = "compraid")})
@ApiModel(description = "Class representing a sale.")
public class Compra implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "Compra ID gerado")
    private Long compraid;
    @NotBlank
    @ApiModelProperty(notes = "Lista de produto na compra")
    private String produto;

    @ApiModelProperty(notes = "Quantidade do produto")
    private Integer quantidade;

    @JsonFormat(pattern = "dd/MM/yyyy")
    @ApiModelProperty(notes = "Data da compra")
    @Temporal(TemporalType.DATE)
    private Date data;

    @ApiModelProperty(notes = "Valor da compra")
    private Float valor;

    @ApiModelProperty(notes = "Desconto do produto")
    private Float desconto;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Formas de Pagamento")
    private FormaDePagamento formaDePagamento;

    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;

    public Compra() {

    }

    public Compra(String produto) {
        this.produto = produto;
    }

    public Compra(Long compraid, String produto) {
        this.compraid = compraid;
        this.produto = produto;
    }
}
