package com.alessiojr.estoque.resource;

import com.alessiojr.estoque.model.Produto;
import com.alessiojr.estoque.repository.ProdutoRepository;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.List;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;

/**
 *
 * @author jmoch
 */

@CrossOrigin
@RestController
@RequestMapping("/produto")
@Api(value = "/produto", tags = "Produto Controler",  description = "Operações sobre a Entidade Produto")
public class ProdutoController {

    @Autowired
    private ProdutoRepository produtoRepository;

    //GET - Read all resource
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<Produto> findAll() {
        return produtoRepository.findAll();
    }

    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<Produto> findById(@PathVariable Long id) {
        Optional<Produto> produto = produtoRepository.findById(id);

        if (!produto.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(produto.get());

    }

    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable long id) {
        this.produtoRepository.deleteById(id);
    }

    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long cdproduto, @RequestBody Produto produto) {

        Optional<Produto> produtoExistente = produtoRepository.findById(cdproduto);

        if (produtoExistente.isPresent()) {
            Produto p = produtoExistente.get();
            p.setId(produto.getId());
            p.setNome(produto.getNome());

            produtoRepository.save(p);
            return ResponseEntity.ok("Product updated successfully");
        } else {
            return ResponseEntity.notFound().build();
        }

    }

    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Product", response = Produto.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe um produto para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public Produto create(
            @ApiParam(value = "Produto com elementos Nome e Id") @Valid @RequestBody Produto produto) {

        Optional<Produto> produtoExistente = produtoRepository.findByNomeAndId(produto.getNome(),produto.getId());

        if (produtoExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                    "Já existe uma produto para este com a mesma descrição");
        }

        return produtoRepository.save(produto);
    }
}
