package com.alessiojr.estoque.service;

import java.util.Optional;

import com.alessiojr.common.enums.Status;
import com.alessiojr.estoque.model.Compra;
import com.alessiojr.estoque.repository.CompraRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

@Service
public class CompraService {

    @Autowired
    private CompraRepository<Compra> compras;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Compra> findByIdContaining(Long compraid, Integer pagina) {
        return this.compras.findByIdContaining(compraid, PageRequest.of(pagina, 10));
    }

    public Page<Compra> findAll(Integer pagina) {
        return this.compras.findAll(PageRequest.of(pagina, 10));
    }

    public Optional<Compra> findById(Long compraid) {
        Optional<Compra> compra = compras.findById(compraid);
        if (!compra.isPresent()) {
            return Optional.empty();
        }
        return compra;
    }

    public Compra insert(Compra compra) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                compra.setStatus(Status.PUBLICO);
            } else {
                compra.setStatus(Status.PRIVADO);
            }
        }

        return this.compras.save(compra);
    }

    public void deleteById(Long compraid) {
        Optional<Compra> op = this.compras.findById(compraid);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.compras.save(op.get());
        }
    }

    public Compra save(Compra compra) {
        return this.compras.save(compra);
    }

    public Compra update(Compra compra, Compra existente) {
        BeanUtils.copyProperties(compra, existente, "idCompra");
        return this.compras.save(compra);
    }
}
