package com.alessiojr.freeTests.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.enums.EstadoCivil;
import com.alessiojr.freeTests.serializer.PessoaTesteSerializer;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CPF;
import org.springframework.format.annotation.DateTimeFormat;
import static org.springframework.format.annotation.DateTimeFormat.ISO.DATE;
import static org.springframework.format.annotation.DateTimeFormat.ISO.DATE_TIME;
import static org.springframework.format.annotation.DateTimeFormat.ISO.TIME;
@Entity
@Getter @Setter

@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Pessoa_cpf", columnNames = "cpf")
        })
@ApiModel(description = "Class representing a person.")
public class PessoaTeste implements Serializable {

    @Id
    @Column(insertable = false, updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated pessoa ID", position = 0)
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @Column(length = 128)
    @ApiModelProperty(notes = "Full Name of Pessoa", position = 1)
    private String nome;

    @NotEmpty
    @ApiModelProperty(notes = "Cpf Válido de uma pessoa", position = 2)
    @CPF(message = "Erro no CPF")
    private String cpf;    

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Estado Civil")
    private EstadoCivil estadoCivil;
    
    @NotNull(message = "Informe o Status")
    @Enumerated(EnumType.STRING)
    private Status status;

    @DateTimeFormat(iso = DATE)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    private LocalDate dtNascimento;
    
   // @JsonSerialize(using = PessoaTesteSerializer.class)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(
        foreignKey = @ForeignKey(name = "FK_Pessoa_PessoaMae"),
        name = "mae_id",
        nullable = true,
        referencedColumnName = "id")
    @ApiModelProperty(dataType = "com.alessiojr.freeTests.model.PessoaTesteDTO")
    private PessoaTeste mae; 
//    
//    @OneToMany(mappedBy = "mae")
//    private List<PessoaTeste> filhos;
//    
    public PessoaTeste() {
    }

    public PessoaTeste(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public PessoaTeste(String nome, String cpf) {
        this.nome = nome;
        this.cpf = cpf;
    }
    
    public PessoaTesteDTO getMae(){
        if(this.mae != null){
            return new PessoaTesteDTO(this.mae);
        }else{
            return null;
        }
    }

}
