package com.alessiojr.freeTests.model;

import com.alessiojr.common.enums.Status;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CPF;

@Getter @Setter
@ApiModel(description = "Class representing a Resuming person.")
public class PessoaTesteDTO implements Serializable {

    @Column(updatable = false, nullable = false)
    @ApiModelProperty(notes = "The database generated pessoa ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Full Name of Pessoa")
    private String nome;

    @NotEmpty
    @ApiModelProperty(notes = "Cpf Válido de uma pessoa")
    @CPF(message = "Erro no CPF")
    private String cpf;    
    
    public PessoaTesteDTO() {
    }

    public PessoaTesteDTO(PessoaTeste pessoaTeste) {
        this.id = pessoaTeste.getId();
        this.nome = pessoaTeste.getNome();
        this.cpf = pessoaTeste.getCpf();
    }
    public PessoaTesteDTO(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public PessoaTesteDTO(String nome, String cpf) {
        this.nome = nome;
        this.cpf = cpf;
    }

}
