package com.alessiojr.freeTests.service;

import com.alessiojr.common.enums.OrderDirection;
import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.enums.PessoaTesteOrderBy;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.repository.PessoaTesteRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class PessoasTesteService {

    @Autowired
    private PessoaTesteRepository<PessoaTeste> pessoas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<PessoaTeste> findBySearchTerm(String nome, Integer pagina, Integer tamanho, 
            PessoaTesteOrderBy orderBy, Sort.Direction direction) {
        
        PageRequest pageRequest = PageRequest.of(
                pagina,
                tamanho,
                direction,
                orderBy.getOrderByCode());
        return this.pessoas.findBySearchTerm(nome, pageRequest);
    }

    public Page<PessoaTeste> findAll() {
        int page = 0;
        int size = 10;
        
        PageRequest pageRequest = PageRequest.of(
                page,
                size,
                Sort.Direction.ASC,
                "nome");
                
        return new PageImpl<>(pessoas.findAll(), pageRequest, size);
    }

    public PessoaTeste insert(PessoaTeste parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.pessoas.save(parceiro);
    }

    public Optional<PessoaTeste> findById(Long id) {
        Optional<PessoaTeste> parceiro = pessoas.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public PessoaTeste update(PessoaTeste parceiro, PessoaTeste existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.pessoas.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<PessoaTeste> op = this.pessoas.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.pessoas.save(op.get());
        }
    }

}
