package com.alessiojr.gamepoints.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.serializer.PessoaTesteSerializer;
import com.alessiojr.gamepoints.enums.OpcaoRuleMedalha;
import com.alessiojr.gamepoints.enums.OpcaoTypeMedalha;
import com.alessiojr.gamepoints.enums.OpcaoCategoryMedalha;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Medalha_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a person.")
public class Medalha implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated pessoa ID")
    private Long id;
    
    @JsonSerialize(using = PessoaTesteSerializer.class)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(
        foreignKey = @ForeignKey(name = "FK_Medalha_Pessoa"),
        name = "pessoa_id",
        nullable = true,
        referencedColumnName = "id")
    private PessoaTeste pessoa;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Full Name of Medalha")
    @Column(length = 128, name = "nome")
    private String nome;   
    
    @NotEmpty
    @NotBlank
    @Size(min = 5, max =256)
    @ApiModelProperty(notes = "Full Description of Medalha")
    @Column(length = 256, name = "descricao")
    private String description;   
    
    @Enumerated(EnumType.STRING)
    @Column(name = "categoria")
    @ApiModelProperty(notes = "Full Category of Medalha")
    private OpcaoCategoryMedalha category;
    
    @Enumerated(EnumType.STRING)
    @Column(name = "tipo")
    @ApiModelProperty(notes = "Full Type of Medalha")
    private OpcaoTypeMedalha type;
    
    @Enumerated(EnumType.STRING)
    @Column(name = "regra")
    @ApiModelProperty(notes = "Full Rule of Medalha")
    private OpcaoRuleMedalha rule;
  
    @Column(name="dataMedalha", columnDefinition = "date")
    @ApiModelProperty(notes = "Full Date of Medalha")
    private LocalDate dataMedalha;
        
    /*
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @ApiModelProperty(notes = "Full Date of Medalha")
    @Temporal(TemporalType.DATE)
    @Column(name = "data_registro")
    private Date data;
    */
    
    @ApiModelProperty(notes = "Full Level Points of Medalha")
    @Column(name = "levelpoints")
    private double levelPoints;  
    
    //icon
    //image
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
        
    public Medalha() {
    }
    
    public Medalha(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }
    
     public Medalha(String nome, String description) {
        this.nome = nome;
        this.description = description;
    }

    public Medalha(long id, String nome, String description, OpcaoCategoryMedalha category, OpcaoTypeMedalha type, OpcaoRuleMedalha rule, LocalDate dataMedalha, double levelPoints){
        this.id = id;
        this.nome = nome;
        this.description = description;
        this.dataMedalha = dataMedalha;
        this.category = category;
        this.type = type;
        this.rule = rule;
        this.levelPoints = levelPoints;
    }

}