package com.alessiojr.gamepoints.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.gamepoints.model.Medalha;
import com.alessiojr.gamepoints.repository.MedalhaRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class MedalhaService {

    @Autowired
    private MedalhaRepository<Medalha> medalhas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Medalha> findByNomeContaining(String nome, Integer pagina) {
       
        return this.medalhas.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Medalha> findAll(Integer pagina) {
        return this.medalhas.findAll(PageRequest.of(pagina, 10));
    }

    public Medalha insert(Medalha medalha) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                medalha.setStatus(Status.PUBLICO);
            } else {
                medalha.setStatus(Status.PRIVADO);
            }
        }

        return this.medalhas.save(medalha);
    }

    public Optional<Medalha> findById(Long id) {
        Optional<Medalha> medalha = medalhas.findById(id);
        if (!medalha.isPresent()) {
            return Optional.empty();
        }
        return medalha;
    }

    public Medalha update(Medalha medalha, Medalha existente) {
        BeanUtils.copyProperties(medalha, existente, "idMedalha");
        return this.medalhas.save(medalha);
    }
    
    public void deleteById(Long id) {
        Optional<Medalha> medalha = this.medalhas.findById(id);
        if (medalha.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.medalhas.deleteById(id);
                } else {
                     medalha.get().setStatus(Status.INATIVO);
                     this.medalhas.save(medalha.get());
                }
            }
        }
    }

}
