package com.alessiojr.influenzer.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.serializer.PessoaTesteSerializer;
import com.alessiojr.influenzer.enums.OpcaoAtualizacao;
import com.alessiojr.influenzer.serializer.CampanhaSerializer;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;

/**
 *
 * @author Pedro Paulo
 */
@Entity
@Getter @Setter
@Table
@ApiModel(description = "Classe Influenzer/Campanha")
public class Campanha implements Serializable {
    
    //id gerado
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "Id")
    private Long id;
    
    //nome
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Nome")
    @Column(length = 128)
    private String nome;
    
    //empresa
    @NotEmpty
    @NotBlank
    @Column(length = 128)
    @ApiModelProperty(notes = "Empresa")
    private String empresa;
    
    //data início
    @NotNull
    @ApiModelProperty(notes = "Data de Início")
    // inserir nesse formato 2015-06-13T17:50:25.057Z
    private LocalDate dtInicio;
    
    //data fim
    @NotNull
    @ApiModelProperty(notes = "Data de Fim")
    // inserir nesse formato 2015-06-13T17:50:25.057Z
    private LocalDate dtFim;
    
    //atualizaçao (diária, hora, semanal)
    @NotNull
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Atualização")
    private OpcaoAtualizacao atualizacao;
    
    //logo
    @NotEmpty
    @NotBlank
    @Column(length = 128)
    @ApiModelProperty(notes = "Logo")
    private String logo;
    
    //orçamento
    @NotNull
    @ApiModelProperty(notes = "Orçamento válido de uma campanha")
    @DecimalMin(value = "0",message="Orçamento mínimo de 0 reais")
    private double orcamento; 
    
    //status
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
    @JsonSerialize(using = CampanhaSerializer.class)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(
        foreignKey = @ForeignKey(name = "FK_Campanha_CampanhaProjeto"),
        name = "projeto_id",
        nullable = true,
        referencedColumnName = "id")
    private Campanha projeto;
        
    public Campanha() {
    }

    public Campanha(long id, String nome, String empresa) {
        this.id = id;
        this.nome = nome;
        this.empresa = empresa;
    }
    /*
    public Campanha(String nome, String empresa) {
        this.nome = nome;
        this.empresa = empresa;
    }
    */

}
