/*
 * The MIT License
 *
 * Copyright 2019 Usuario.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.alessiojr.influenzer.model;

import com.alessiojr.influenzer.model.premio;
import com.alessiojr.influenzer.model.*;
import com.alessiojr.influenzer.enums.PremioTipos;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CPF;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_premio_codigo", columnNames = "codigo")
        })
@ApiModel(description = "Class representing a person.")
public class premio implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated prêmio ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Full Name of prêmio")
    private String nome;

    @NotEmpty
    @ApiModelProperty(notes = "código Válido de um prêmio")
    @CPF(message = "Erro no código")
    private String codigo;    

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo de Prêmio")
    private PremioTipos Tipopremio;
        
    public premio() {
    }

    public premio(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }
    
    

    public premio(String nome, String codigo) {
        this.nome = nome;
        this.codigo = codigo;
    }
}