package com.alessiojr.influenzer.resource;

import com.alessiojr.influenzer.resource.*;
import com.alessiojr.influenzer.model.premio;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;
import com.alessiojr.influenzer.repository.PremioRepository;


@CrossOrigin
@RestController
@RequestMapping("/premios")
@Api(value = "/premios", tags = "premioControler",  description = "Operações sobre a Entidade premio")
public class PremioController {
    
    
    
    
    @Autowired
    private PremioRepository PremioRepository;

    //GET - Read all resource
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<premio> findAll(){
       return PremioRepository.findAll();
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<premio> findById(@PathVariable Long id){
       Optional<premio> premio = PremioRepository.findById(id);
       
       if (!premio.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(premio.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.PremioRepository.deleteById(id);
    }
    
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody premio premio){
        
        Optional<premio> PremioExistente = PremioRepository.findById(id);
	
        if (PremioExistente.isPresent()) {
            premio p = PremioExistente.get();
            p.setId(premio.getId());
            p.setNome(premio.getNome());
            p.setCodigo(premio.getCodigo());
            PremioRepository.save(p);
            return ResponseEntity.ok("Product updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }	
        
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single premio", response = premio.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe um premio para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public premio create(
            @ApiParam(value = "premios com elementos Nome e Código") @Valid @RequestBody premio premio) {
        
        Optional<premio> PremioExistente =  PremioRepository
            .findByNomeAndCodigo(premio.getNome(), 
            premio.getCodigo());
	
        if (PremioExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe um prêmio para este com a mesma descrição");
        }
		
		return PremioRepository.save(premio);
	}
}




//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/