/*
 * The MIT License
 *
 * Copyright 2019 vinicius.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.alessiojr.influenzer.resource;

import com.alessiojr.influenzer.resource.*;
import com.alessiojr.influenzer.model.Regra;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alessiojr.influenzer.repository.RegraRepository;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/regras")
@Api(value = "/regras", tags = "Regra Controler",  description = "Operações sobre a Entidade Regra")
public class RegraController {
    
    @Autowired
    private RegraRepository regraRepository;

    //GET - Read all resource
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<Regra> findAll(){
       return regraRepository.findAll();
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<Regra> findById(@PathVariable Long id){
       Optional<Regra> regra = regraRepository.findById(id);
       
       if (!regra.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(regra.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.regraRepository.deleteById(id);
    }
    
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody Regra regra){
        
        Optional<Regra> regraExistente = regraRepository.findById(id);
	
        if (regraExistente.isPresent()) {
            Regra p = regraExistente.get();
            p.setId(regra.getId());
            p.setNome(regra.getNome());
            p.setCodigo(regra.getCodigo());
            regraRepository.save(p);
            return ResponseEntity.ok("Product updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }	
        
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Regra", response = Regra.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma regra para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public Regra create(
            @ApiParam(value = "Regras com elementos Nome e CPf") @Valid @RequestBody Regra regra) {
        
        Optional<Regra> regraExistente = regraRepository
             .findByNomeAndCodigo(regra.getNome(), 
            regra.getCodigo());
	
        if (regraExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe uma regra para este com a mesma descrição");
        }
		
		return regraRepository.save(regra);
	}
}
