package com.alessiojr.influenzer.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.influenzer.model.Campanha;
import com.alessiojr.influenzer.repository.CampanhaRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

/**
 *
 * @author Pedro Paulo
 */
@Service
public class CampanhaService {

    @Autowired
    private CampanhaRepository<Campanha> campanhas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Campanha> findByNomeContaining(String nome, Integer pagina) {
       
        return this.campanhas.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Campanha> findAll(Integer pagina) {
        return this.campanhas.findAll(PageRequest.of(pagina, 10));
    }

    public Campanha insert(Campanha campanha) {
        
        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                campanha.setStatus(Status.PUBLICO);
            } else {
                campanha.setStatus(Status.PRIVADO);
            }
        }
        
        return this.campanhas.save(campanha);
    }

    public Optional<Campanha> findById(Long id) {
        Optional<Campanha> campanha = campanhas.findById(id);
        if (!campanha.isPresent()) {
            return Optional.empty();
        }
        return campanha;
    }

    public Campanha update(Campanha campanha, Campanha existente) {
        BeanUtils.copyProperties(campanha, existente, "idCampanha");
        return this.campanhas.save(campanha);
    }

    public void deleteById(Long id) {
        Optional<Campanha> op = this.campanhas.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.campanhas.save(op.get());
        }
    }

}
