package com.alessiojr.ipc.competicao.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.text.DateFormat;
import java.text.Format;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.ForeignKey;
//import javax.persistence.EnumType;
//import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
//import javax.persistence.Temporal;
//import javax.persistence.TemporalType;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
//import lombok.AllArgsConstructor;
import lombok.Getter;
//import lombok.NoArgsConstructor;
import lombok.Setter;

import com.alessiojr.ipc.competicao.serializer.CompeticaoSerializer;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import java.time.LocalDate;
import javax.persistence.FetchType;
import javax.validation.constraints.NotNull;


@Entity
//lombok
@Getter
@Setter
//@NoArgsConstructor // gera um construtor vazio
//@AllArgsConstructor //gera um construtor com todos atributos e aceita null neles

//@Table(name = "Competicao")
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Competicao_cid", columnNames = "cid")
        })


@ApiModel(description = "Classe de cadastro de competições")
public class Competicao implements Serializable {

    // =============================== ATRIBUTOS ===============================
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "ID da competição")
    private Long cid;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 64)
    @ApiModelProperty(notes = "Abreviação do nome da competição")
    private String short_name;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 128)
    @ApiModelProperty(notes = "Nome da competição")
    private String name;

    @ApiModelProperty(notes = "Momento de ativação")
    //@Temporal(TemporalType.TIMESTAMP)
    //@NotNull
    //private String active_time;
    //LocalDateTime active_time;
    //private java.util.Date active_time;
    private LocalDate active_time;

    @ApiModelProperty(notes = "Data e hora de início da competição")
    //private String start_time;
    //@Temporal(TemporalType.TIMESTAMP)
    private LocalDate start_time;

    @ApiModelProperty(notes = "Scoreboard freeze time")
    //private String freeze;
    //@Temporal(TemporalType.TIMESTAMP)
    private LocalDate freeze;

    @ApiModelProperty(notes = "Data e hora de fim da competição")
    //private String end_time;
    //@Temporal(TemporalType.TIMESTAMP)
    private LocalDate end_time;

    @ApiModelProperty(notes = "Scoreboard unfreeze time")
    //private String unfreeze;
    //@Temporal(TemporalType.TIMESTAMP)
    private LocalDate unfreeze;

    @ApiModelProperty(notes = "Deactive time")
    //private String deactive_time;
    //@Temporal(TemporalType.TIMESTAMP)
    private LocalDate deactive_time;

    @JsonSerialize(using = CompeticaoSerializer.class)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(
        foreignKey = @ForeignKey(name = "FK_Competicao_CompeticaoMae"),
        name = "mae_cid",
        nullable = true,
        referencedColumnName = "cid")
    private Competicao mae;
    
    
    
    
    /*
    
    @NotEmpty
    @NotBlank
    @ApiModelProperty(notes = "Nome of a Problema")
    private String nome;

    @Size(min = 1, max = 255)
    @ApiModelProperty(notes = "Pdf of a Problema")
    private String pdf;

    @Enumerated(EnumType.STRING) - Lista que não muda
    @ApiModelProperty(notes = "Theme of a Problema")
    private OpcaoTematica tematica;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Level of a Problema")
    private OpcaoNivel nivel;

     */
    // ============================ CONSTRUTORES ===============================
    // Construtor vazio
    public Competicao() {
    }

    public Competicao(
            Long cid,
            String short_name,
            String name,
            LocalDate active_time,
            LocalDate start_time,
            LocalDate freeze,
            LocalDate end_time,
            LocalDate unfreeze,
            LocalDate deactive_time
    ) throws ParseException {

      //  SimpleDateFormat formatData = new SimpleDateFormat("dd/MM/yyyy");

       // String exemplo = "2019-04-23 16:41:00 America/Sao_Paulo";

//        String data =    "Tue Nov 22 00:00:00 BRST 2011";
//        String pattern = "EEE MMM dd HH:mm:ss zzzz yyyy";
//        DateFormat df = new SimpleDateFormat(pattern);
//        Date date = df.parse(data);
//        
//        java.sql.Date data = new java.sql.Date(format.parse(dataStr).getTime());
//        
        //String data = "Nov 22 00:00:00 BRST 2011";
       // String padraoAdotado = "dd/MM/yyyy HH:mm:ss";
       // DateFormat df = new SimpleDateFormat(padraoAdotado);
        //Date date = df.parse(data);

//        this.cid = cid;
//        this.short_name = short_name;
//        this.name = name;
//        this.active_time = df.parse(active_time);
//        this.start_time = df.parse(start_time);
//        this.freeze = df.parse(freeze);
//        this.end_time = df.parse(end_time);
//        this.unfreeze = df.parse(unfreeze);
//        this.deactive_time = df.parse(deactive_time);

        this.cid = cid;
        this.short_name = short_name;
        this.name = name;
        this.active_time = active_time;
        this.start_time = start_time;
        this.freeze = freeze;
        this.end_time = end_time;
        this.unfreeze = unfreeze;
        this.deactive_time = deactive_time;
        
                
    }

}
