    package com.alessiojr.ipc.competicao.resource;

 // ################  MODELO NOVO  ###################



import com.alessiojr.ipc.competicao.model.Competicao;
import com.alessiojr.ipc.competicao.repository.CompeticaoRepository;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.alessiojr.ipc.competicao.service.CompeticoesService;
import io.swagger.annotations.ApiParam;
import java.sql.SQLIntegrityConstraintViolationException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.UnexpectedRollbackException;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.server.ResponseStatusException;



@CrossOrigin
@RestController
@RequestMapping("/ipc/competicao")

@Api(value = "/ipc/competicao", tags = "Competicao Controller", description = "Operações sobre a entidade Competicao")
public class CompeticaoController {

    private static final Logger log = LoggerFactory.getLogger(CompeticaoController.class);

    @Autowired
    private CompeticoesService competicoes;

    //GET - Read all resource
    @ApiOperation(value = "Visualizar a lista completa de competições cadastradas", response = List.class)
    @GetMapping(params = {"name", "pagina"})
    public Page<Competicao> findAll(
            @RequestParam String name,
            @RequestParam Integer pagina) {
        log.info("findAll");
        return this.competicoes.findByNameContaining(name, pagina);
       // return this.competicoes.findAll(pagina);
    }
    
    @ApiOperation(value = "Ver a lista de competições", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<Competicao> findAll(@RequestParam Integer pagina) {
        return this.competicoes.findAll(pagina);
    }
    
    
    //GET - Read a resource
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Competicao> findById(@PathVariable Long id) {
        //log.info("Passei no GET competicoes" + id);
        log.info("findById " + id);
        Optional<Competicao> competicao = competicoes.findById(id);

        log.info("teste "+competicao.get().getName());
        
        if (!competicao.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(competicao.get());
    }

    @DeleteMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        //log.info("Passei no Delete de competicoes" + id);
        log.info("Delete /ipc/competicoes/" + id);
        Optional<Competicao> competicao = competicoes.findById(id);
        if (!competicao.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            competicoes.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }

    //PUT - Update an existing resource
    @PutMapping("/{id}")
    //@PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    @ApiOperation(value = "Realizar alterações sob uma Competicao", response = Competicao.class)
    @ApiResponses(value = {
        @ApiResponse(code = 200, message = "Successfully"),
        @ApiResponse(code = 424, message = "Houve um problema com a Mãe"),
    })
    @ResponseStatus(code = HttpStatus.FAILED_DEPENDENCY, reason = "Houve um problema com a Mãe")
    public ResponseEntity<Competicao> update(@RequestBody @Valid Competicao competicao, @PathVariable Long id) {
       log.info("update" + id);
        
        Optional<Competicao> optional = competicoes.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Competicao existente = optional.get();

        try {
            return ResponseEntity.ok(competicoes.update(competicao, existente));
        } catch (UnexpectedRollbackException ex) {
            if (ex.getMostSpecificCause() instanceof SQLIntegrityConstraintViolationException) {
                if (ex.getMessage().contains("FK_Competicao_CompeticaoMae")) {
                    return ResponseEntity
                            .status(HttpStatus.FAILED_DEPENDENCY)
                            .build();
                }
            }
        }

        return ResponseEntity.status(500).build();

    }

    
//    // POST 
//    @PostMapping("/")
//    @ApiOperation(value = "Cria uma competição", response = Competicao.class)
//    @ResponseStatus(HttpStatus.CREATED)
//    public Competicao create(
//            @ApiParam(value = "Realiza o cadastro da competicao (cria) com seus respectivos atributos")
//            @Valid @RequestBody Competicao competicao) {
//
//        Optional<Competicao> competicaoExistente = competicaoRepository
//                .findByNameAndCid(competicao.getName(),
//                        competicao.getCid());
//
//        if (competicaoExistente.isPresent()) {
//            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
//                    "Já existe uma competicao para esta com a mesma descrição");
//        }
//
//        return competicaoRepository.save(competicao);
//    }
    
    
    
    
    
    
    
    
    
//    @PostMapping("/")
//    @ResponseStatus(HttpStatus.CREATED)
//    @ApiOperation(value = "Cria uma única Competição", response = Competicao.class)
//
//    @ApiResponses(value = {
//        @ApiResponse(code = 201, message = "Competicão criada com sucesso"),
//        @ApiResponse(code = 400, message = "Já existe uma competição com a mesma descrição"),
//        @ApiResponse(code = 401, message = "Você não é autorizado a visualizar esse recurso"),
//        @ApiResponse(code = 403, message = "Acessar o recurso que você estava tentado é proibido"),
//        @ApiResponse(code = 404, message = "O recurso que você estava querendo alcançar não foi achado")})
//
//    public ResponseEntity<Competicao> create(
//            @ApiParam(value = "Cria uma competição com seus respectivos atributos") @Valid @RequestBody Competicao competicao) {
//
//        return ResponseEntity
//                .status(HttpStatus.CREATED)
//                .body(competicoes.insert(competicao));
//    }

}

//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR
// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg
// Put Vs Post: https://restfulapi.net/rest-put-vs-post/

//GET 	/device-management/devices : Get all devices
//POST 	/device-management/devices : Create a new device
//
//GET 	/device-management/devices/{id} : Get the device information identified by "id"
//PUT 	/device-management/devices/{id} : Update the device information identified by "id"
//DELETE	/device-management/devices/{id} : Delete device by "id"




//* ########### MODELO ANTIGO ###################

//package com.alessiojr.drDebug.resource

/*
import com.alessiojr.ipc.competicao.model.Competicao;
import com.alessiojr.ipc.competicao.repository.CompeticaoRepository;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
//import java.util.List;
import java.util.Optional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import org.springframework.web.bind.annotation.DeleteMapping;
import javax.validation.Valid;

import com.alessiojr.ipc.competicao.model.Competicao;
import com.alessiojr.ipc.competicao.repository.CompeticaoRepository;
import com.alessiojr.ipc.competicao.service.CompeticoesService;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;

import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/ipc/competicoes")
@ApiResponses(value = {
    @ApiResponse(code = 201, message = "Criada com sucesso"),
    @ApiResponse(code = 400, message = "Já existe uma competição para esta com a mesma descrição"),
    @ApiResponse(code = 401, message = "Você não é autorizado a visualizar esse recurso"),
    @ApiResponse(code = 403, message = "Acessar o recurso que você estava tentando não é permitido"),
    @ApiResponse(code = 404, message = "O recurso que você estava tentando alcançar não foi encontrado")
})

@Api(value = "/competicoes", tags = "Competicao Controller", description = "Operações sobre a entidade competição.")
public class CompeticaoController {

    @Autowired
    private CompeticaoRepository competicaoRepository;
    
    @Autowired
    private CompeticoesService competicoes;

    //############################### GET ######################################
    //GET - Read all resource
    @ApiOperation(value = "Visualizar a lista completa de competições", response = Page.class)
    @GetMapping("/")
    public Page<Competicao> findAll(int pagina) {
        return competicaoRepository.findAll(PageRequest.of(pagina, 10));
    }

    //GET - Read a resource
    @GetMapping("/{cid}")
    public ResponseEntity<Competicao> findById(@PathVariable Long cid) {
        Optional<Competicao> competicao = competicaoRepository.findById(cid);

        if (!competicao.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(competicao.get());

    }

    //############################### POST #####################################
    @PostMapping("/")
    @ApiOperation(value = "Cria uma competição", response = Competicao.class)
    @ResponseStatus(HttpStatus.CREATED)
    public Competicao create(
            @ApiParam(value = "Realiza o cadastro da competicao (cria) com seus respectivos atributos")
            @Valid @RequestBody Competicao competicao) {

        Optional<Competicao> competicaoExistente = competicaoRepository
                .findByNameAndCid(competicao.getName(),
                        competicao.getCid());

        if (competicaoExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                    "Já existe uma competicao para esta com a mesma descrição");
        }

        return competicaoRepository.save(competicao);
    }

//################################# PUT ########################################
    @PutMapping(value = "/{cid}")
    @ApiOperation(value = "Altera os atributos de uma competição")
    public ResponseEntity update(@PathVariable Long cid, @RequestBody Competicao competicao) {

        Optional<Competicao> competicaoExistente = competicaoRepository.findByCid(cid);

        if (competicaoExistente.isPresent()) {
            Competicao comp = competicaoExistente.get();
            comp.setCid(competicao.getCid());
            comp.setCid(competicao.getCid());
            comp.setShort_name(competicao.getShort_name());
            comp.setName(competicao.getName());
            comp.setActive_time(competicao.getActive_time());
            comp.setStart_time(competicao.getStart_time());
            comp.setFreeze(competicao.getFreeze());
            comp.setEnd_time(competicao.getEnd_time());
            comp.setUnfreeze(competicao.getUnfreeze());
            comp.setDeactive_time(competicao.getDeactive_time());
            competicaoRepository.save(comp);
            return ResponseEntity.ok("Competição atualizada com sucesso");
        } else {
            return ResponseEntity.notFound().build();
        }
    }

    //################################ DELETE ##################################
//    @DeleteMapping("/{cid}")
//    @ApiOperation(value = "Excluir uma competição em específico, utilizando o ID")
//    public void delete(@PathVariable Long cid) {
//        this.competicaoRepository.deleteByCid(cid);
//    }
    
     @DeleteMapping("/{cid}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long cid) {
        //log.info("Passei no Delete de competicoes" + id);
        Optional<Competicao> competicao = competicaoRepository.findById(cid);
        if (!competicao.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            competicaoRepository.deleteById(cid);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    

}

*/


