/*
 * The MIT License
 *
 * Copyright 2019 dettoni.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.alessiojr.ipc.content.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.drDebug.model.Game;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.serializer.PessoaTesteSerializer;
import com.alessiojr.ipc.content.enums.Linguagem;
import com.alessiojr.ipc.content.enums.Nivel;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;
//import org.hibernate.validator.constraints.br.CPF;

/**
 *
 * @author dettoni
 */
@Entity
@Getter
@Setter
@ApiModel(description = "Class representing um conteudo.")
public class Conteudo implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated pessoa ID")
    private Long id;

 //   @NotEmpty
 //   @NotBlank
    @Size(min = 3, max = 128)
    @Column(nullable = false)
    @ApiModelProperty(notes = "Full Name of Pessoa")
    private String nome;

   //   @NotEmpty
    //@NotBlank
     @Column(name="dataCriacao", columnDefinition = "date")
   @JsonFormat(pattern = "yyyy-MM-dd")
    @Temporal(TemporalType.DATE)
       @ApiModelProperty(notes = "Data de criacao")
    private Date dataCriacao;
    
 ////   @NotEmpty
 //   @NotBlank
    @Size(min = 1)
     @Column(nullable = false, columnDefinition = "TEXT")
    @ApiModelProperty(notes = "Conteudo de criacao")
    private String conteudo;
    
 //   @NotEmpty
 //   @NotBlank
    @Size(min = 1)
     @Column(nullable = false, columnDefinition = "TEXT")
    @ApiModelProperty(notes = "Exemplo de entrada")
    private String exemplo;
    
   // @NotEmpty
   // @NotBlank
    @Enumerated(EnumType.STRING)
     @Column(nullable = false)
    private Linguagem linguagem;
    
  //  @NotEmpty
    //@NotBlank
    @Enumerated(EnumType.STRING)
     @Column(nullable = false)
    private Nivel nivel;
    
  //  @NotEmpty
  //  @NotBlank
    @Size(min = 1)

   @Column(columnDefinition = "TEXT", nullable = false)
    @ApiModelProperty(notes = "Topicos")
    private String topicos;
    
    
    
    @ManyToOne
   @JoinColumn(foreignKey = @ForeignKey(name = "FK_Conteudo_Game"), name = "gameConteudo_id", nullable = false, referencedColumnName = "id")
    private Game game;
    /* @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
     */
    //   @NotEmpty
    //   @ApiModelProperty(notes = "Cpf Válido de uma pessoa")
    // @CPF(message = "Erro no CPF")
    // private String cpf;    

   // @Enumerated(EnumType.STRING)
    //@ApiModelProperty(notes = "Estado Civil")
    //private OpcaoEstadoCivil estadoCivil;

    public Conteudo() {
    }

    public Conteudo(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public Conteudo(String nome) {
        this.nome = nome;
        //     this.cpf = cpf;
    }


}
