/*
 * The MIT License
 *
 * Copyright 2019 dettoni.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.alessiojr.ipc.content.resource;

/*
 * The MIT License
 *
 * Copyright 2019 dettoni.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */


import com.alessiojr.ipc.content.repository.ConteudoRepository;
import com.alessiojr.ipc.content.model.Conteudo;
import com.alessiojr.ipc.content.service.ConteudoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.sql.SQLIntegrityConstraintViolationException;
import java.util.List;
import java.util.Optional;
import javax.validation.Valid;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.UnexpectedRollbackException;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;

/**
 *
 * @author dettoni
 */
@CrossOrigin
@RestController
@RequestMapping("/conteudo")
@Api(value = "/conteudo", tags = "Conteudo Controler", description = "Operações sobre a Entidade Conteudo")
public class ConteudoController {
    private static final Logger log = LoggerFactory.getLogger(ConteudoController.class);
    @Autowired
    private ConteudoService conteudoService;

    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params ={"nome", "pagina"})
    
    public Page<Conteudo> findAll(@RequestParam String nome,
            @RequestParam Integer pagina) {
       return this.conteudoService.findByNomeContaining(nome, pagina);
    }
     @ApiOperation(value = "View a list of available campaign", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<Conteudo> findAll(@RequestParam Integer pagina) {
        return this.conteudoService.findAll(pagina);
    }
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Conteudo> findById(@PathVariable Long id) {
        Optional<Conteudo> conteudo = conteudoService.findById(id);

        if (!conteudo.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(conteudo.get());

    }
    
    @DeleteMapping("/{id}")
    public ResponseEntity delete(@PathVariable Long id){
        Optional<Conteudo> parceiro = conteudoService.findById(id);
        if (!parceiro.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            conteudoService.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    // PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    @ApiOperation(value = "Altera os atributos de um conteudo", response = Conteudo.class)
    @ApiResponses(value = { @ApiResponse(code = 200, message = "Successfully"),
            @ApiResponse(code = 424, message = "Houve um problema com o conteudo"), })
    @ResponseStatus(code = HttpStatus.FAILED_DEPENDENCY, reason = "Houve um problema com o conteudo")
      public ResponseEntity<Conteudo> update(@RequestBody @Valid Conteudo conteudo, @PathVariable Long id) {

          
        Optional<Conteudo> optional = conteudoService.findById(id);

        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Conteudo existente = optional.get();

        try {
            return ResponseEntity.ok(conteudoService.update(conteudo, existente));
        } catch (UnexpectedRollbackException ex) {
            if (ex.getMostSpecificCause() instanceof SQLIntegrityConstraintViolationException) {
                if (ex.getMessage().contains("FK_Conteudo_Game")) {
                    return ResponseEntity.status(HttpStatus.FAILED_DEPENDENCY).build();
                }
            }
        }

        return ResponseEntity.status(500).build();
    }
     
   
   
   @PostMapping("/")
       @ResponseStatus(HttpStatus.CREATED)
       @ApiOperation(value= "Create a Single Conteudo", response=Conteudo.class)
       @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma pessoa para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
   
       
       
       public ResponseEntity<Conteudo>  create(
        @ApiParam(value = "Conteudo elemento") @Valid @RequestBody Conteudo conteudo) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(conteudoService.insert(conteudo));
	}

}


