/*
 * The MIT License
 *
 * Copyright 2019 dettoni.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.alessiojr.ipc.content.service;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.alessiojr.ipc.content.model.Conteudo;
import com.alessiojr.ipc.content.repository.ConteudoRepository;
import org.springframework.data.domain.Page;
import com.alessiojr.security.enums.PermissionRoles;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import com.alessiojr.common.enums.Status;
import java.util.Optional;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import org.springframework.beans.BeanUtils;

/**
 *
 * @author dettoni
 */
@Service
public class ConteudoService {

    @Autowired
    private ConteudoRepository<Conteudo> conteudos;
    @Autowired
    private CurrentUserService currentUser;

    public Page<Conteudo> findByNomeContaining(String nome, Integer pagina) {

        return this.conteudos.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Conteudo> findAll(Integer pagina) {
        return this.conteudos.findAll(PageRequest.of(pagina, 10));
    }

    public Conteudo insert(Conteudo parceiro) {
/*
        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }
*/
        return this.conteudos.save(parceiro);
    }
     public Optional<Conteudo> findById(Long id) {
        Optional<Conteudo> parceiro = conteudos.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }
  public Conteudo update(Conteudo conteudo, Conteudo existente) {
        BeanUtils.copyProperties(conteudo, existente, "idConteudo");
        return this.conteudos.save(conteudo);
    }
     public void deleteById(Long id) {
        Optional<Conteudo> op = this.conteudos.findById(id);
        if (op.isPresent()) {
          //  op.get().setStatus(Status.INATIVO);
            this.conteudos.save(op.get());
        }
    }

}
