package com.alessiojr.ipc.problemManager.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.problemManager.enums.OpcaoVisibilidade;
import com.alessiojr.ipc.problemManager.enums.OpcaoVisibilidade;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CPF;
import java.util.Date;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_CasoDeTeste_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a person.")
public class CasoDeTeste implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated Caso de Teste ID")
    private Long id;

    @Size(min = 5, max =256)
    @ApiModelProperty(notes = "Descrição do Caso de Teste")
    @Column(length = 256)
    private String descricao;

    
    @ApiModelProperty(notes = "Peso final do Teste")
    private int pesoFinal;  
    

    @ApiModelProperty(notes = "Peso sugerido do Teste")
    private int pesoSugerido; 
    
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de realização do teste")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Column(name="DataDoTeste", columnDefinition = "date")
    private Date DataDoTeste;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Visibilidade do Caso de Teste")
    private OpcaoVisibilidade visibilidade;
    
    @ApiModelProperty(notes = "Tempo de execução do teste medido em minutos")
    private int tempo; 
    
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
     
    public CasoDeTeste() {
    }

  

    public CasoDeTeste(Long id,String descricao, int pesoFinal, int pesoSugerido,Date DataDoTeste, int tempo) {
        this.id=id;
        this.descricao = descricao;
        this.pesoFinal = pesoFinal;
        this.pesoSugerido = pesoSugerido;
        this.DataDoTeste = DataDoTeste;
        this.tempo = tempo;
    }

}
