package com.alessiojr.ipc.problemManager.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.problemManager.enums.OpcaoNivelDificuldade;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a test case.")
public class CasosTeste implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated pessoa ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 250)
    @ApiModelProperty(notes = "Data entry")
    @Column(length = 128)
    private String entradaDados;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 250)
    @ApiModelProperty(notes = "Data output")
    @Column(length = 128)
    private String saidaDados;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Difficulty level")
    private OpcaoNivelDificuldade nivelDificuldade;
    
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Description")
    @Column(length = 128)
    private String descricao;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Tags")
    @Column(length = 128)
    private String tags;   
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 250)
    @ApiModelProperty(notes = "Image test case")
    @Column(length = 128)
    private String imagem;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of test case")
    @Column(length = 128)
    private String nome;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
        
    public CasosTeste() {
    }

    public CasosTeste(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public CasosTeste(String nome, String descricao) {
        this.nome = nome; 
        this.descricao = descricao;
            
    }

}
