package com.alessiojr.ipc.problemManager.model;

import com.alessiojr.ipc.problemManager.enums.OpcaoCor;
import com.alessiojr.ipc.problemManager.enums.OpcaoNivel;
import com.alessiojr.ipc.problemManager.enums.OpcaoTematica;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import java.io.Serializable;

@Entity

//lombok
@Getter
@Setter
@NoArgsConstructor // gera um construtor vazio
@AllArgsConstructor //gera um construtor com todos atributos e aceita null neles

@Table(name = "Problema")
@ApiModel(description = "Class representing a problem")
public class Problema implements Serializable {

    @Id
    @Column(updatable = false,nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database Generated Problema ID")
    private Long idProblema;

    @NotEmpty
    @ApiModelProperty(notes = "Description of a Problema")
    private String descricao;

    @ApiModelProperty(notes = "Input of a Problema")
    private String entrada;

    @NotEmpty
    @ApiModelProperty(notes = "Statement of a Problema")
    private String enunciado;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Level of a Problema")
    private OpcaoNivel nivel;

    @NotEmpty
    @ApiModelProperty(notes = "Nome of a Problema")
    private String nome;

    @Size(min = 1 , max = 255)
    @ApiModelProperty(notes = "Pdf of a Problema")
    private String pdf;

    @ApiModelProperty(notes = "Output of a Problema")
    private String saida;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Theme of a Problema")
    private OpcaoTematica tematica;

    @ApiModelProperty(notes = "Parent Version of a Problema")
    private int versaoPai;

    @ApiModelProperty(notes = "Author id of Problema")
    private long autorTbIdAutor;

    @ApiModelProperty(notes = "Idiom id of Problema")
    private long linguaTbIdLingua;

    @ApiModelProperty(notes = "Id from URI website for a Problema")
    private long idUri;

    @ApiModelProperty(notes = "Contest id from where the Problema came")
    private long maratonaTbIdMaratona;

    @ApiModelProperty(notes = "Timelimit of a Problema in miliseconds")
    private double tempoLimite;

    @ApiModelProperty(notes = "Memory limit of a Problema in KB")
    private double memoriaLimite;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Color of a Problema in hexadecimal")
    private OpcaoCor cor;

    @ApiModelProperty(notes = "If the Problema is acepting submissions")
    private boolean isAberto;

}
