/*
 * The MIT License
 *
 * Copyright 2019 adamh.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.alessiojr.ipc.problemManager.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.problemManager.enums.OpcaoLinguagem;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;


@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Solucao_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a solucao.")

public class Solucao implements Serializable {
    
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated solução ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @ApiModelProperty(notes = "Código fonte")
    @Column(length = 128)
    private String codigofonte;

    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Linguagem")
    private OpcaoLinguagem opcaolinguagem;
    
    
    @Column(name="dtsubmissao", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de submissao")
    private Date dtsubmissao;
    
    @NotEmpty
    @NotBlank
    @ApiModelProperty(notes = "Compila")
    @Column(length = 128)
    private String compila;
    
    @NotEmpty
    @NotBlank    
    @ApiModelProperty(notes = "Roda")
    @Column(length = 128)
    private String roda;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
    
    
     public Solucao() {
    }

    public Solucao(long id, OpcaoLinguagem opcaolinguagem, String codigofonte, Date dtsubmissao, String compila, String roda) {
        this.id = id;
        this.opcaolinguagem = opcaolinguagem;
        this.codigofonte = codigofonte;
        this.dtsubmissao = dtsubmissao;
        this.compila = compila;
        this.roda = roda;
        
    }

    public Solucao(String linguagem) {
        
    }
    
       
}