package com.alessiojr.ipc.problemManager.resource;

import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;

import com.alessiojr.ipc.problemManager.model.CasosTeste;
import com.alessiojr.ipc.problemManager.repository.CasosTesteRepository;
import com.alessiojr.ipc.problemManager.service.CasosTestesService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestParam;

@CrossOrigin
@RestController
@RequestMapping("/ipc/problemManager/casostestes")
@Api(value = "/ipc/problemManager/casostestes", tags = "Casos Teste Controller",  description = "Operações sobre a Entidade Casos de Teste")
public class CasosTesteController {
    
    private static final Logger log = LoggerFactory.getLogger(CasosTesteController.class);
    
     @Autowired
    private CasosTestesService casosTestes;
  

     //GET - Read all resource
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<CasosTeste> findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.casosTestes.findByNomeContaining(nome, pagina);
    }
    
      //GET - Read all resource
     @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"pagina"})
     public Page<CasosTeste> findAll(@RequestParam Integer pagina) {
        return this.casosTestes.findAll(pagina);
    }
      
    //GET - Read a resource
     @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<CasosTeste> findById(@PathVariable Long id){
        log.info("Passei no /ipc/problemManager/casosTeste/" + id);
        
         Optional<CasosTeste> casosTeste = casosTestes.findById(id);
       
         if (!casosTeste.isPresent()){
           return ResponseEntity.notFound().build();
        }
         return ResponseEntity.ok(casosTeste.get());
    }
    
    
    @DeleteMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /problemManager/casosTeste/" + id);
        
        Optional<CasosTeste> casosTeste = casosTestes.findById(id);
        if (!casosTeste.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            casosTestes.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
    //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<CasosTeste> update(@RequestBody @Valid CasosTeste casosTeste, @PathVariable Long id) {
        Optional<CasosTeste> optional = casosTestes.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        CasosTeste existente = optional.get();
        return ResponseEntity.ok(casosTestes.update(casosTeste, existente));
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Test case", response = CasosTeste.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "There is already a test cases with the same description"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    
    public ResponseEntity<CasosTeste>  create(
        @ApiParam(value = "Casos de Testes com elementos Nome e Descriçao") @Valid @RequestBody CasosTeste casosTeste) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(casosTestes.insert(casosTeste));
	}
}
