package com.alessiojr.ipc.problemManager.resource;

import com.alessiojr.ipc.problemManager.model.Problema;
import com.alessiojr.ipc.problemManager.repository.Problema2Repository;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.server.ResponseStatusException;

import javax.validation.Valid;
import java.util.List;
import java.util.Optional;

@CrossOrigin
@RestController
@RequestMapping("/problemas2")
@Api(value = "/problemas2", description = "Operacoes sobre a entidade Problema")
public class ProblemaController2 {

    @Autowired
    private Problema2Repository problemaRepository;

    @ApiOperation(value = "lista todos problemas",response = List.class)
    @GetMapping("/")
    public List<Problema> findAll() {
        return problemaRepository.findAll();
    }

    @ApiOperation(value="lista problemas de determinada maratona")
    @GetMapping("/maratona/{idMaratona}")
    public List<Problema> findByIdMaratona(@PathVariable Long idMaratona) {
        return problemaRepository.findByMaratonaTbIdMaratona(idMaratona);
    }

    @GetMapping("/{idProblema}")
    public ResponseEntity<Problema> findById(@PathVariable Long idProblema) {
        Optional<Problema> problema = problemaRepository.findById(idProblema);

        if(!problema.isPresent())
            return ResponseEntity.notFound().build();

        return ResponseEntity.ok(problema.get());
    }

    @DeleteMapping("/{idProblema}")
    public void delete(@PathVariable Long idProblema) {
        this.problemaRepository.deleteById(idProblema);
    }

    @PutMapping(value="/{idProblema}")
    public ResponseEntity update(@PathVariable Long idProblema,@RequestBody Problema problema) {
        Optional<Problema> pExistente = problemaRepository.findById(idProblema);

        if(pExistente.isPresent()) {
            Problema p = pExistente.get();
            p.setIdProblema(problema.getIdProblema());
            p.setDescricao(problema.getDescricao());
            p.setEntrada(problema.getEntrada());
            p.setEnunciado(problema.getEnunciado());
            p.setNivel(problema.getNivel());
            p.setNome(problema.getNome());
            p.setPdf(problema.getPdf());
            p.setSaida(problema.getSaida());
            p.setTematica(problema.getTematica());
            p.setVersaoPai(problema.getVersaoPai());
            p.setAutorTbIdAutor(problema.getAutorTbIdAutor());
            p.setLinguaTbIdLingua(problema.getLinguaTbIdLingua());
            p.setIdUri(problema.getIdUri());
            p.setMaratonaTbIdMaratona(problema.getMaratonaTbIdMaratona());
            p.setTempoLimite(problema.getTempoLimite());
            p.setMemoriaLimite(problema.getMemoriaLimite());
            p.setCor(problema.getCor());
            p.setAberto(problema.isAberto());
            problemaRepository.save(p);
            return ResponseEntity.ok("Problema atualizado com sucesso");
        }

        return ResponseEntity.notFound().build();
    }

    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Cria um unico Problema", response = Problema.class)
    @ApiResponses(value = {
            @ApiResponse(code = 201, message = "Successfully Created"),
            @ApiResponse(code = 400, message = "Já existe um problema com este nome"),
            @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
            @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
            @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public Problema create(@ApiParam(value="Problema a ser criado") @Valid @RequestBody Problema problema) {
        Optional<Problema> pExistente = problemaRepository.findByNomeIgnoreCase(problema.getNome());

        if(pExistente.isPresent())
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,"Já existe um problema com este nome");

        return problemaRepository.save(problema);
    }

}
