 package com.alessiojr.ipc.problemManager.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.problemManager.model.CasoDeTeste;
import com.alessiojr.ipc.problemManager.repository.CasoDeTesteRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class CasoDeTesteService {

    @Autowired
    private CasoDeTesteRepository<CasoDeTeste> casosdeteste;

    @Autowired
    private CurrentUserService currentUser;

    public Page<CasoDeTeste> findByDescricaoContaining(String descricao, Integer pagina) {
       
        return this.casosdeteste.findByDescricaoContaining(descricao, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "descricao")));
    }

    public Page<CasoDeTeste> findAll(Integer pagina) {
        return this.casosdeteste.findAll(PageRequest.of(pagina, 10));
    }

    public CasoDeTeste insert(CasoDeTeste parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
       }


        return this.casosdeteste.save(parceiro);
    }

    public Optional<CasoDeTeste> findById(Long id) {
        Optional<CasoDeTeste> parceiro = casosdeteste.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public CasoDeTeste update(CasoDeTeste parceiro, CasoDeTeste existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.casosdeteste.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<CasoDeTeste> op = this.casosdeteste.findById(id);
        if (op.isPresent()) {
            //op.get().setStatus(Status.INATIVO);
            this.casosdeteste.save(op.get());
        }
    }

}

