 package com.alessiojr.ipc.problemManager.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.problemManager.model.CasosTeste;
import com.alessiojr.ipc.problemManager.repository.CasosTesteRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class CasosTestesService {

    @Autowired
    private CasosTesteRepository<CasosTeste> casosTestes;

    @Autowired
    private CurrentUserService currentUser;

    public Page<CasosTeste> findByNomeContaining(String nome, Integer pagina) {
       
        return this.casosTestes.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<CasosTeste> findAll(Integer pagina) {
        return this.casosTestes.findAll(PageRequest.of(pagina, 10));
    }

    public CasosTeste insert(CasosTeste casosTeste) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                casosTeste.setStatus(Status.PUBLICO);
            } else {
                casosTeste.setStatus(Status.PRIVADO);
            }
       }


        return this.casosTestes.save(casosTeste);
    }

    public Optional<CasosTeste> findById(Long id) {
        Optional<CasosTeste> casosTeste = casosTestes.findById(id);
        if (!casosTeste.isPresent()) {
            return Optional.empty();
        }
        return casosTeste;
    }

    public CasosTeste update(CasosTeste parceiro, CasosTeste existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.casosTestes.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<CasosTeste> op = this.casosTestes.findById(id);
        if (op.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.casosTestes.deleteById(id);
                } else {
                     op.get().setStatus(Status.INATIVO);
                     this.casosTestes.save(op.get());
                }
            }
        }
    }

}

