/*
 * The MIT License
 *
 * Copyright 2019 adamh.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this solucao and associated documentation files (the "Solucao"), to deal
 * in the Solucao without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Solucao, and to permit persons to whom the Solucao is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Solucao.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.alessiojr.ipc.problemManager.service;


import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.ipc.problemManager.model.Solucao;
import com.alessiojr.ipc.problemManager.repository.SolucaoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;


/**
 *
 * @author adamh
 */

@Service
public class SolucaoService {

    @Autowired
    private SolucaoRepository<Solucao> solucoes;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Solucao> findByCodigofonteContaining(String codigofonte, Integer pagina) {
       
        return this.solucoes.findByCodigofonteContaining(codigofonte, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "codigofonte")));
    }

    public Page<Solucao> findAll(Integer pagina) {
        return this.solucoes.findAll(PageRequest.of(pagina, 10));
    }

    public Solucao insert(Solucao s) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                s.setStatus(Status.PUBLICO);
            } else {
                s.setStatus(Status.PRIVADO);
            }
        }

        return this.solucoes.save(s);
    }

    public Optional<Solucao> findById(Long id) {
        Optional<Solucao> s = solucoes.findById(id);
        if (!s.isPresent()) {
            return Optional.empty();
        }
        return s;
    }

    public Solucao update(Solucao s, Solucao existente) {
        BeanUtils.copyProperties(s, existente, "idSolucao");
        return this.solucoes.save(s);
    }

    public void deleteById(Long id) {
        Optional<Solucao> op = this.solucoes.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.solucoes.save(op.get());
        }
    }

}