package com.alessiojr.ipc.question.resource;

import com.alessiojr.ipc.question.model.Aberta;
import com.alessiojr.ipc.question.repository.AbertaRepository;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.List;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/aberta")
@Api(value = "/aberta", tags = "Aberta Controler")
public class AbertaController {
    
    @Autowired
    private AbertaRepository abertaRepository;
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<Aberta> findAll(){
        return abertaRepository.findAll();
    }
    
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.abertaRepository.deleteById(id);
    }
    
    @GetMapping("/{id}")
    public ResponseEntity<Aberta> findById(@PathVariable Long id){
        Optional<Aberta> aberta = abertaRepository.findById(id);
        
        if (!aberta.isPresent()){
            return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(aberta.get());
    }
    
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody Aberta aberta){
        
        Optional<Aberta> AbertaExistente = abertaRepository.findById(id);
	
        if (AbertaExistente.isPresent()) {
            Aberta m = AbertaExistente.get();
            m.setId(aberta.getId());
            m.setEnunciado(aberta.getEnunciado());
            m.setResposta(aberta.getResposta());
            m.setDtCadastro(aberta.getDtCadastro());
            abertaRepository.save(m);
            return ResponseEntity.ok("Question updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }
    }
    
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Question", response = Aberta.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public Aberta create(
            @ApiParam(value = "Questão aberta") @Valid @RequestBody Aberta aberta) {
        
        Optional<Aberta> abertaExistente = abertaRepository
            .findByEnunciado(aberta.getEnunciado());
	
        if (abertaExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe um enunciado igual cadastrado");
        }
        
	return abertaRepository.save(aberta);
    }
}

