/*
package com.alessiojr.ipc.question.resource;

import com.alessiojr.ipc.question.model.MultiplaEscolha;
import com.alessiojr.ipc.question.repository.MultiplaEscolhaRepository;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/multiplaEscolha")
@Api(value = "/multiplaEscolha", tags = "MultiplaEscolha Controler",  description = "Operações sobre a Entidade Opções de Multipla Escolha")
public class MultiplaEscolhaController {
    
    @Autowired
    private MultiplaEscolhaRepository MultiplaEscolhaRepository;

    //GET - Read all resource
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<MultiplaEscolha> findAll(){
       return MultiplaEscolhaRepository.findAll();
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<MultiplaEscolha> findById(@PathVariable Long id){
       Optional<MultiplaEscolha> MultiplaEscolha = MultiplaEscolhaRepository.findById(id);
       
       if (!MultiplaEscolha.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(MultiplaEscolha.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.MultiplaEscolhaRepository.deleteById(id);
    }
    
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody MultiplaEscolha MultiplaEscolha){
        
        Optional<MultiplaEscolha> MultiplaEscolhaExistente = MultiplaEscolhaRepository.findById(id);
	
        if (MultiplaEscolhaExistente.isPresent()) {
            MultiplaEscolha m = MultiplaEscolhaExistente.get();
            m.setId(MultiplaEscolha.getId());
            m.setEnunciado(MultiplaEscolha.getEnunciado());
            m.setAlternativaCerta(MultiplaEscolha.getAlternativaCerta());
            m.setLetras(MultiplaEscolha.getLetras());
            m.setDtCadastro(MultiplaEscolha.getDtCadastro());
            MultiplaEscolhaRepository.save(m);
            return ResponseEntity.ok("Question updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }
        
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Question", response = MultiplaEscolha.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma disciplina para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public MultiplaEscolha create(
            @ApiParam(value = "Questão multipla escolha") @Valid @RequestBody MultiplaEscolha MultiplaEscolha) {
        
        Optional<MultiplaEscolha> MultiplaEscolhaExistente = MultiplaEscolhaRepository
            .findByEnunciado(MultiplaEscolha.getEnunciado());
	
        if (MultiplaEscolhaExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe um enunciado igual cadastrado");
        }
		
		return MultiplaEscolhaRepository.save(MultiplaEscolha);
	}
}


//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swa

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/
