package com.alessiojr.ipc.question.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.question.model.MultiplaEscolha;
import com.alessiojr.ipc.question.repository.MultiplaEscolhaRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class MultiplaEscolhaService {

    @Autowired
    private MultiplaEscolhaRepository<MultiplaEscolha> multiplaescolhas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<MultiplaEscolha> findByNomeContaining(String enunciado, Integer pagina) {
       
        return this.multiplaescolhas.findByEnunciadoContaining(enunciado, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "enunciado")));
    }

    public Page<MultiplaEscolha> findAll(Integer pagina) {
        return this.multiplaescolhas.findAll(PageRequest.of(pagina, 10));
    }

    public MultiplaEscolha insert(MultiplaEscolha parceiro) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.multiplaescolhas.save(parceiro);
    }

     public Optional<MultiplaEscolha> findById(Long id) {
        Optional<MultiplaEscolha> multiplaescolha = multiplaescolhas.findById(id);
        if (!multiplaescolha.isPresent()) {
            return Optional.empty();
        }
        return multiplaescolha;
    }


    public MultiplaEscolha update(MultiplaEscolha parceiro, MultiplaEscolha existente) {
        BeanUtils.copyProperties(parceiro, existente, "id");
        return this.multiplaescolhas.save(parceiro);
    }

 public void deleteById(Long id) {
        Optional<MultiplaEscolha> op = this.multiplaescolhas.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.multiplaescolhas.save(op.get());
        }
    }
}
