package com.alessiojr.ipc.school.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.school.enums.OpcaoCurso;
import com.alessiojr.ipc.school.enums.OpcaoSexo;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import java.util.List;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CPF;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Aluno_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a person.")
public class Aluno implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated aluno ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Full Name of Aluno")
    @Column(length = 128)
    private String nome;

    @NotEmpty
    @ApiModelProperty(notes = "Cpf Válido de um aluno")
    @CPF(message = "Erro no CPF")
    private String cpf;    

    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Full city of Aluno")
    @Column(length = 128)
    private String cidade;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Curso")
    private OpcaoCurso curso;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Sexo")
    private OpcaoSexo sexo;

    //@JsonFormat(pattern = "dd/MM/yyyy")
    //@Temporal(TemporalType.DATE)//import javax.persistence.Temporal;
    @ApiModelProperty(notes = "Full Date")
    @Column(name = "data_registro")
    private LocalDate dtnasc;

    @NotEmpty
    @NotBlank
    @Size(min = 11, max =11)    
    @ApiModelProperty(notes = "Telefone")
    @Column(length = 11)
    private String telefone;  

    @NotEmpty
    @NotBlank
    @Size(min = 12, max =12)
    @ApiModelProperty(notes = "Matrícula")
    @Column(length = 12)
    private String matricula; 
    
   //@ManyToOne(fetch = FetchType.LAZY)
    //private Aluno disciplina;
    
    //@OneToMany(mappedBy = "mae")
    //private List<Aluno> filhos;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    

    public Aluno() {
    }

    public Aluno(long id, String cpf, String nome, String cidade, String telefone, String sexo, String curso, LocalDate dtnasc, String matricula) {
        this.id = id;
        this.cpf = cpf;
        this.nome = nome;
        this.cidade = cidade;
        this.dtnasc = dtnasc;
        this.telefone = telefone;
        this.matricula = matricula;
        //this.disciplina = disciplina;
    }

}
