
package com.alessiojr.ipc.school.model;

import com.alessiojr.drDebug.util.Curso;
import com.alessiojr.drDebug.util.Disciplina;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.validator.constraints.br.CPF;

@Entity
@Getter
@Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "Profesor", columnNames = "nomeProfessor")
        })
@ApiModel(description = "Class representing a professor.")

public class CadastroTurmas implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "O programa gerou o ID da Turma")
    private Long id;

  
    @ApiModelProperty(notes =  "Numero de vagas da turma")
    private Integer numVagas;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max = 128)
    @ApiModelProperty(notes = "Nome completo do Professor")
    private String nomeProfessor;
   

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Curso")
    private Curso curso;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Disciplina")
    private Disciplina disciplica;

    public CadastroTurmas() {
    }

    public CadastroTurmas(Long id, int numVagas, String nomeProfessor, Curso curso, Disciplina disciplica) {
        this.id = id;
        this.numVagas = numVagas;
        this.nomeProfessor = nomeProfessor;
        this.curso = curso;
        this.disciplica = disciplica;
    }

   
    
    

}
