package com.alessiojr.ipc.school.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.school.enums.OpcaoNivelEnsino;
import com.alessiojr.ipc.school.enums.OpcaoTempo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table
@ApiModel(description = "Class representing a suject.")
public class Disciplina implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated suject ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of suject")
    @Column(length = 128)
    private String nome;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tempo")
    private OpcaoTempo tempo;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Nivel de Ensino")
    private OpcaoNivelEnsino nivelEnsino;
    
    @ApiModelProperty(notes = "Número de Alunos")
    private int nalunos;
    
    @Size(min = 10, max =250)
    @ApiModelProperty(notes = "Course description")
    @Column(length = 250)
    private String descricao;
    
    //@Column(name="dtCadastro", columnDefinition = "date")
    //@DateTimeFormat(pattern = "dd/MM/yyyy")
    //@Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de cadastro")
    private LocalDate dtCadastro;
    
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of course")
    @Column(length = 128)
    private String curso;
    
    @Size(min = 1, max =2)
    @ApiModelProperty(notes = "Ano/Período")
    @Column(length = 7)
    private String periodo;
    
     @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
        
        
    public Disciplina() {
    }

    public Disciplina(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public Disciplina(String nome, String curso) {
        this.nome = nome;
        this.curso = curso;
    }

}