package com.alessiojr.ipc.school.model;

import com.alessiojr.drDebug.util.Curso;
import com.alessiojr.drDebug.util.SiglaEstado;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.logging.Logger;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;


import lombok.Getter;
import lombok.Setter;

@Entity
@Getter
@Setter
@Table(name = "Universidade")
@ApiModel(description = "Class representing a university.")
public class Universidade implements Serializable{
    
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated universidade ID")
    private Long id;    
    
    @NotEmpty
    @NotBlank
    @ApiModelProperty(notes = "Full Name of Universidade")
    private String nome;
    
    /*
    @ApiModelProperty(notes = "Nome da cidade")
    private String cidade;
    */
    @ApiModelProperty(notes = "Nome do estado")
    private SiglaEstado estado;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Nome do Curso")
    private Curso curso;
    
    @ApiModelProperty(notes = "Numero de Cursos")
    private long numeroCursos;
    
    public Universidade(){
        
    }

    public Universidade(Long id, String nome, SiglaEstado estado, Curso curso, long numeroCursos) {
        this.id = id;
        this.nome = nome;
        this.estado = estado;
        this.curso = curso;
        this.numeroCursos = numeroCursos;
    }
    
    
    public Universidade(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }
    
    public Universidade(String nome, long numeroCursos){
        this.nome=nome;
        this.numeroCursos=numeroCursos;
    }    
}

