package com.alessiojr.ipc.school.resource;

import com.alessiojr.ipc.school.model.CadastroTurmas;
import com.alessiojr.ipc.school.repository.CadastroTurmasRepository;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.List;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/cadastroturmas")
@Api(value = "/cadastroturmas", tags = "CadastroTurmas Controler",  description = "Operações sobre a Entidade Cadastroturma")

public class CadastroTurmasController {
    
    
    @Autowired
    private CadastroTurmasRepository cadastroTurmasRepository;
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<CadastroTurmas> findAll(){
       return cadastroTurmasRepository.findAll();
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<CadastroTurmas> findById(@PathVariable Long id){
       Optional<CadastroTurmas> universidade = cadastroTurmasRepository.findById(id);
       
       if (!universidade.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(universidade.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.cadastroTurmasRepository.deleteById(id);
    }
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody CadastroTurmas Turmas){
        
        Optional<CadastroTurmas> universidadeExistente = cadastroTurmasRepository.findById(id);
	
        if (universidadeExistente.isPresent()) {
            CadastroTurmas u = universidadeExistente.get();
            u.setId(Turmas.getId());
            u.setDisciplica(Turmas.getDisciplica());
            u.setNomeProfessor(Turmas.getNomeProfessor());
            u.setCurso(Turmas.getCurso());
            u.setNumVagas(Turmas.getNumVagas());
            cadastroTurmasRepository.save(u);
            return ResponseEntity.ok("Product updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }	
        
    }
    
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "CRIAR UMA TURMA CARALHO", response = CadastroTurmas.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma turma para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    
    //Create a university
    public CadastroTurmas create(
            @ApiParam(value = "Universidade com elementos nomeUni e numeroCursos") @Valid @RequestBody CadastroTurmas turmas) {
        
        Optional<CadastroTurmas> turmaExistente = cadastroTurmasRepository
            .findByIdAndDisciplica(turmas.getId(), 
            turmas.getDisciplica());

        if (turmaExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe uma Turma para este com a mesma descrição");
        }
		
		return cadastroTurmasRepository.save(turmas);
	}  
}

