package com.alessiojr.ipc.school.resource;

import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import com.alessiojr.ipc.school.model.Disciplina;
import com.alessiojr.ipc.school.service.DisciplinaService;
import java.time.format.DateTimeFormatter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


@CrossOrigin
@RestController
@RequestMapping("/school/disciplina")
@Api(value = "/school/disciplina", tags = "Disciplina Controler",  description = "Operações sobre a Entidade Disciplina")
public class DisciplinaController {
    
    private static final Logger log = LoggerFactory.getLogger(DisciplinaController.class)
            ;
    @Autowired
    private DisciplinaService disciplinas;
 
    //GET - Read all resource
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<Disciplina> findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.disciplinas.findByNomeContaining(nome, pagina);
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Disciplina> findById(@PathVariable Long id){
        log.info("Passei no /school/disciplina" + id);
        Optional<Disciplina> disciplina = disciplinas.findById(id);
       
        if (!disciplina.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(disciplina.get());
    }
    
    @DeleteMapping("/{id}")
//  @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /school/disciplina" + id);
        Optional<Disciplina> disciplina = disciplinas.findById(id);
        if (!disciplina.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            disciplinas.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
     //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Disciplina> update(@RequestBody @Valid Disciplina diciplina, @PathVariable Long id) {
        Optional<Disciplina> optional = disciplinas.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Disciplina existente = optional.get();
        //diciplina.setStatus(existente.getStatus());
        return ResponseEntity.ok(disciplinas.update(diciplina, existente));
    }
    
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Disciplina", response = Disciplina.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma disciplina para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public ResponseEntity<Disciplina>  create(
        @ApiParam(value = "Disciplinas com elementos Nome e Curso") @Valid @RequestBody Disciplina disciplina) {
        //DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy MM dd");
        //String text = disciplina.getDtCadastro().format(formatter); 
        //disciplina.setDtCadastro(disciplina.getDtCadastro().parse(text, formatter));
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(disciplinas.insert(disciplina));
	}
}


//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/