package com.alessiojr.ipc.school.resource;

import com.alessiojr.ipc.school.model.Universidade;
import com.alessiojr.ipc.school.repository.UniversidadeRepository;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.List;
import java.util.Optional;
import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/school/universidades")
@Api(value = "/school/universidades", tags = "Universidade Controler",  description = "Operações sobre a Entidade Universidade")
public class UniversidadeController {
    
    @Autowired
    private UniversidadeRepository universidadeRepository;
    
    //GET - Read all resource    
    @ApiOperation(value = "Lista todas as universidades", response = List.class)
    @GetMapping("/")
    public List<Universidade> findAll(){
       return universidadeRepository.findAll();
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<Universidade> findById(@PathVariable Long id){
       Optional<Universidade> universidade = universidadeRepository.findById(id);
       
       if (!universidade.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(universidade.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.universidadeRepository.deleteById(id);
    }
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody Universidade universidade){
        
        Optional<Universidade> universidadeExistente = universidadeRepository.findById(id);
	
        if (universidadeExistente.isPresent()) {
            Universidade u = universidadeExistente.get();
            u.setId(universidade.getId());
            u.setNome(universidade.getNome());
            u.setNumeroCursos(universidade.getNumeroCursos());
            u.setCurso(universidade.getCurso());
            u.setEstado(universidade.getEstado());
            universidadeRepository.save(u);
            return ResponseEntity.ok("Product updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }	        
    }
    
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single University", response = Universidade.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma universidade para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    
    //Create a university
    public Universidade create(
            @ApiParam(value = "Universidade com elementos nome e numeroCursos") @Valid @RequestBody Universidade universidade) {
        
        Optional<Universidade> universidadeExistente = universidadeRepository
            .findByNome(universidade.getNome());
	
        if (universidadeExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe uma universidade para este com a mesma descrição");
        }		
		return universidadeRepository.save(universidade);
	}  
}

