package com.alessiojr.ipc.school.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.school.model.Aluno;
import com.alessiojr.ipc.school.repository.AlunoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class AlunoService {

    @Autowired
    private AlunoRepository<Aluno> alunos;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Aluno> findByNomeContaining(String nome, Integer pagina) {
       
        return this.alunos.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Aluno> findAll(Integer pagina) {
        return this.alunos.findAll(PageRequest.of(pagina, 10));
    }

    public Aluno insert(Aluno aluno) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                aluno.setStatus(Status.PUBLICO);
            } else {
                aluno.setStatus(Status.PRIVADO);
            }
        }

        return this.alunos.save(aluno);
    }

    public Optional<Aluno> findById(Long id) {
        Optional<Aluno> aluno = alunos.findById(id);
        if (!aluno.isPresent()) {
            return Optional.empty();
        }
        return aluno;
    }

    public Aluno update(Aluno aluno, Aluno existente) {
        BeanUtils.copyProperties(aluno, existente, "idParceiro");
        return this.alunos.save(aluno);
    }

    //public void deleteById(Long id) {
    //    Optional<Aluno> op = this.alunos.findById(id);
    //    if (op.isPresent()) {
    //        op.get().setStatus(Status.INATIVO);
    //        this.alunos.save(op.get());
    //    }
    //}

    public void deleteById(Long id) {
        Optional<Aluno> aluno = this.alunos.findById(id);
        if (aluno.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.alunos.deleteById(id);
                } else {
                     aluno.get().setStatus(Status.INATIVO);
                     this.alunos.save(aluno.get());
                }
            }
        }
    }
}
