package com.alessiojr.ipc.school.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.ipc.school.model.Disciplina;
import com.alessiojr.ipc.school.repository.DiciplinaRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class DisciplinaService {

    @Autowired
    private DiciplinaRepository<Disciplina> disciplinas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Disciplina> findByNomeContaining(String nome, Integer pagina) {
       
        return this.disciplinas.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Disciplina> findAll(Integer pagina) {
        return this.disciplinas.findAll(PageRequest.of(pagina, 10));
    }

    public Disciplina insert(Disciplina disciplina) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                disciplina.setStatus(Status.PUBLICO);
            } else {
                disciplina.setStatus(Status.PRIVADO);
            }
        }

        return this.disciplinas.save(disciplina);
    }

     public Optional<Disciplina> findById(Long id) {
        Optional<Disciplina> disciplina = disciplinas.findById(id);
        if (!disciplina.isPresent()) {
            return Optional.empty();
        }
        return disciplina;
    }


    public Disciplina update(Disciplina disciplina, Disciplina existente) {
        BeanUtils.copyProperties(disciplina, existente, "idDisciplina");
        return this.disciplinas.save(disciplina);
    }

     public void deleteById(Long id) {
        Optional<Disciplina> op = this.disciplinas.findById(id);
        if (op.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.disciplinas.deleteById(id);
                } else {
                     op.get().setStatus(Status.INATIVO);
                     this.disciplinas.save(op.get());
                }
            }
        }
    }

}
