package com.alessiojr.ipc.submission.util.submissionEngine;

import com.sjsu.umlgenerator.parser.model.AppInfo;
import com.sjsu.umlgenerator.parser.model.ClassInfo;

import com.sjsu.umlgenerator.parser.IPackageParser;
import com.sjsu.umlgenerator.parser.PackageJavaParser;

public class ClassDiagram extends PlantUMLDiagram {

    private static final IPackageParser javaParser = new PackageJavaParser();

    private AppInfo appInfo;

    public ClassDiagram(String inputFolder) throws Exception {
        this.appInfo = javaParser.buildAppInfo(inputFolder);

        if (this.appInfo == null) {
            throw new Exception("[Diagrama de classes] Falha ao construir aplicação");
        }

        this.generatePlantUML();
    }

    private void generatePlantUML() {
        final StringBuffer str = new StringBuffer("@startuml\n");

        appInfo.getClassInfoList().stream().forEach(v -> {
            str.append(convertClasstoPlantUml(v).append("\n"));

        });

        str.append(convertRelationtoPlantUML(appInfo));
        str.append("@enduml");

        super.setPlantUML(str.toString());
    }

    private StringBuffer convertClasstoPlantUml(ClassInfo classInfo) {
        final StringBuffer buffer = new StringBuffer();
        buffer.append(classInfo.getType() + " " + classInfo.getName() + "{\n");

        classInfo.getAttributeInfos().stream().forEach(v -> {
            if (v.isCollection()) {

                buffer.append(" " + getScopePlantUml(v.getScope()) + " ").append(v.getName()).append(" : ")
                        .append(v.getType() + "[" + v.getCollectionLabel() + "]").append("\n");
            } else {
                buffer.append(" " + getScopePlantUml(v.getScope()) + " ").append(v.getName()).append(" : ")
                        .append(v.getType()).append("\n");

            }
        });

        classInfo.getMethods().stream().forEach(v -> {
            String argument = "";
            for (final String argu : v.getArguemnts()) {
                argument += argu + ",";
            }

            if (argument.length() > 1) {
                argument = argument.substring(0, argument.length() - 1);
            }
            final String plantUMLScope = getScopePlantUml(v.getScope());
            if (v.isConstructor()) {
                buffer.append(" " + plantUMLScope + " ").append(v.getName()).append("(" + argument + ") ").append(" ")
                        .append(" ").append("\n");

            } else {
                final String isstatic = v.isStatic() ? "{static}" : "";
                buffer.append(isstatic + " " + plantUMLScope + " ").append(v.getName()).append("(" + argument + ") : ")
                        .append(v.getReturnType()).append(" ").append("\n");
            }
        });

        buffer.append("}\n");

        return buffer;

    }

    public StringBuffer convertRelationtoPlantUML(AppInfo appInfo) {
        final StringBuffer buffer = new StringBuffer();

        appInfo.getRelationsList().stream().forEach(v -> {
            if (v.getType().equals("association")) {
                buffer.append(v.getSource() + "  \"" + v.getLabelSource() + "\" " + getRelationSymbol(v.getType())
                        + "  \"" + v.getLabelDestination() + "\"  " + v.getDestination() + "\n");
            } else {
                buffer.append(v.getSource() + getRelationSymbol(v.getType()) + v.getDestination() + "\n");
            }
        });

        buffer.append("\n");

        return buffer;
    }

    public String getRelationSymbol(String relation) {

        String result = ".";

        if (relation != null) {
            switch (relation) {
                case "extends":
                    result = "<|--";
                    break;
                case "contains":
                    result = "*--";
                    break;
                case "implements":
                    result = " ..|>";
                    break;
                case "uses":
                    result = "..>";
                    break;
                case "association":
                    result = "--";
                    break;
            }
        }

        return result;
    }

    public String getScopePlantUml(String scope) {
        String result = "~";

        if (scope != null) {
            switch (scope) {
                case "PRIVATE":
                    result = "-";
                    break;
                case "PUBLIC":
                    result = "+";
                    break;
                case "PROTECTED":
                    result = "#";
                    break;
            }
        }

        return result;
    }
}