package com.alessiojr.ipc.submission.util.submissionEngine;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SequenceDiagram extends PlantUMLDiagram {
    private static final Logger log = LoggerFactory.getLogger(SequenceDiagram.class);

    private String inputFolder;

    public SequenceDiagram(String inputFolder) {
        this.inputFolder = inputFolder;

        String plantUML = this.runAspectRunner();
        super.setPlantUML(plantUML);
    }

    private String runAspectRunner() {
        final String file = new File(".").getAbsolutePath();

        final String newFile = file.replace("/.", "");

        final String fileRunner = newFile + "/aspectj/runner.sh";
        final String aspectLib = newFile + "/aspectj/lib";
        final String interceptorPath = newFile + "/aspectj";

        ProcessBuilder pb = new ProcessBuilder("sh", fileRunner, this.inputFolder, aspectLib, interceptorPath,
                "MethodInterceptor.aj");

        String result = executeCommand(pb);
        return result;
    }

    private String executeCommand(ProcessBuilder pb) {
        final StringBuffer output = new StringBuffer();

        Process p;
        try {
            p = pb.start();
            p.waitFor();

            final BufferedReader reader = new BufferedReader(new InputStreamReader(p.getInputStream()));
            BufferedReader errorStream = new BufferedReader(new InputStreamReader(p.getErrorStream()));

            if (errorStream.lines().count() != 0) {
                String l;

                System.err.println("Erro encontrado ");
                while ((l = errorStream.readLine()) != null) {
                    log.debug("Falha ao executar comando de geração do diagrama de sequências" + l);
                }

            }

            output.append("@startuml" + "\n");
            String line = "";

            while ((line = reader.readLine()) != null) {
                if (line.contains("ASPECJ_TRACE:")) {
                    line = line.replace("ASPECJ_TRACE:", "");
                    output.append(line + "\n");
                }
            }

            output.append("@enduml");

        } catch (final Exception e) {
            e.printStackTrace();
        }

        return output.toString();
    }
}