package com.alessiojr.ipc.submission.util.submissionEngine;

import java.io.File;
import java.util.List;

import com.alessiojr.ipc.submission.model.Submission;
import com.alessiojr.ipc.submission.repository.SubmissionRepository;
import com.alessiojr.drDebug.util.Files;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Component
@EnableScheduling
public class SubmissionObserver extends Thread {
    private static final Logger log = LoggerFactory.getLogger(SequenceDiagram.class);

    private final long SEGUNDO = 1000;
    private final long MINUTO = SEGUNDO * 60;
    private final long HORA = MINUTO * 60;


    /**
     * Intervalo entre as verificações das submissões
     */
    private final int delayTimeMs = 5000;

    @Autowired
    private SubmissionRepository submissionRepository;

    // @Override
    // public void run() {
    //     log.info("[Submission Observer] Thread inicializada");
    //     while (true) {
    //         log.info("[Submission Observer] Loop da thread para verificação de submissões");

    //         try {
    //             this.verify();
    //             sleep(delayTimeMs);
    //         } catch (Exception e) {
    //             e.printStackTrace();
    //         }
    //     }
    // }

    @Scheduled(fixedDelay = MINUTO)
    private void verify() {
        log.info("\n\n[Submission Observer] Iniciando verificação de submissões pendentes...");
        List<Submission> submissions = submissionRepository.findByExecuted(false);

        submissions.forEach(s -> {
            log.info("[Submission Observer] Iniciando execução da submissão " + s.getSubmitid() + "...");

            try {
                this.execute(s);
            } catch(NoClassDefFoundError e)  {
                log.error("Pacote /libs/umlgenerator.jar deve ser instalado");
            } catch (Exception e) {
                log.debug("[Submission Observer] Falha na execução da submissão " + s.getSubmitid());
                log.debug(e.getStackTrace().toString());
            }

            log.info("[Submission Observer] Execução da submissão " + s.getSubmitid() + " finalizada");
        });

        log.info("[Submission Observer] Submissões pendentes processadas...");
    }

    private void execute(Submission s) throws InterruptedException {
        String rootFolder = new File(".").getAbsolutePath();
        rootFolder = rootFolder.replace("/.", "");

        final String submissionFolder = rootFolder + "/" + s.getSubmission_files_path();
        final String inputFolder = submissionFolder + "/source";
        
        ClassDiagram classDiagram;
        SequenceDiagram sequenciaDiagram;

        try {
            classDiagram = new ClassDiagram(inputFolder);
            sequenciaDiagram = new SequenceDiagram(inputFolder);

            s.setPlantuml_classdiagram(classDiagram.getPlantUML());
            classDiagram.generateFile(submissionFolder + "/classDiagram");
            // Redimensionar a imagem para gerar a miniatura adequada
            Files.resizeImageHeight(submissionFolder + "/classDiagram.png",
                    submissionFolder + "/classDiagramThumbnail.png", 250);

            s.setPlantuml_sequencediagram(sequenciaDiagram.getPlantUML());
            sequenciaDiagram.generateFile(submissionFolder + "/sequenceDiagram");
            // Redimensionar a imagem para gerar a miniatura adequada
            Files.resizeImageHeight(submissionFolder + "/sequenceDiagram.png",
                    submissionFolder + "/sequenceDiagramThumbnail.png", 250);
        } catch (Exception e) {
            log.error(e.getStackTrace().toString());
        }

        s.setExecuted(true);

        // Delay para simular o tempo de execução
        sleep(10000);
        this.submissionRepository.save(s);
    }
}