package com.alessiojr.laboratory.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.enums.OpcaoCor;
import com.alessiojr.laboratory.enums.OpcaoMarca;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

/**
 *
 * @author Julio
 */
@Entity
@Getter @Setter
@Table()
@ApiModel(description = "Classe Representando um Computador")

 public class Computador implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "ID do Computador gerado pelo banco de dados")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Modelo do Computador")
    private String modelo;

    @NotNull
    @ApiModelProperty(notes = "Preco Válido de um Computador")
    @DecimalMin(value = "0",message="Preço mínimo de 0 reais")
    private double preco;   
    
    @NotNull
    @ApiModelProperty(notes = "Data Válida de Fabricação")
    private Date dtFabricacao;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Cor")
    private OpcaoCor cor;
    
    @NotNull
      @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Marca")
    private OpcaoMarca marca;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
    
        
    public Computador() {
    }

    public Computador(long id, String modelo, double preco, Date dtFabricacao, OpcaoCor cor, OpcaoMarca marca) {
        this.id = id;
        this.modelo = modelo;
        this.preco = preco;
        this.dtFabricacao = dtFabricacao;
        this.cor = cor;
        this.marca = marca;
    }

  

}
