package com.alessiojr.laboratory.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.enums.OpcaoTipoHardware;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter 
@Setter
@Table(
    uniqueConstraints = {
        @UniqueConstraint(name = "UK_Hardware_Id", columnNames = "Id")
    }
)
@ApiModel(description = "Classe representando um Hardware")
public class Hardware implements Serializable {
    
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "Id gerado pelo banco de dados para o Hardware")
    private Long Id;
    
    @ApiModelProperty(notes = "Marca do Hardware")
    @Column(length = 128)
    private String marca;
    
    @ApiModelProperty(notes = "Modelo do Hardware")
    private String modelo;
    
    @ApiModelProperty(notes = "Id do Computador do Hardware")
    private long computador;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo do Hardware")
    private OpcaoTipoHardware tipoHardware;
    
    @ApiModelProperty(notes = "Preço do Hardware")
    private double preco;
    
    @Column(name="dtFabricacao", columnDefinition = "date")
    //@JsonFormat(shape=JsonFormat.Shape.STRING, timezone="-03.00 GMT")
    @ApiModelProperty(notes = "Data de fabricação")
    private Date dtFabricacao;
    
    @Enumerated(EnumType.STRING)
    private Status status;
    
    public Hardware () {
    }

    public Hardware(long id, String marca, String modelo, long computador, Date dtFab, double valor) {
        this.Id = id;
        this.marca = marca;
        this.modelo = modelo;
        this.computador = computador;
        this.preco = valor;
        this.dtFabricacao = dtFab;
    }
}