package com.alessiojr.laboratory.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.enums.OpcaoLaboratorio;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;


@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            //@UniqueConstraint(name = "UK_Pessoa_cpf", columnNames = "cpf")
            @UniqueConstraint(name = "UK_Instalacao_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a softaware installation.")
public class Instalacao implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated installation ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of Installed Software")
    @Column(length = 128)
    private String software;
    
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Laboratório")
    private OpcaoLaboratorio laboratorio;
    
    @Column(name="Data", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data")
    private Date data;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "solicitante")
    @Column(length = 128)
    private String solicitante;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;

    
    public Instalacao() {
    }

    public Instalacao(long id, String software, Date data, String solicitante) {
        this.id = id;
        this.software = software;
        this.data = data;
        this.solicitante = solicitante;
    }
/*
    public Software(String nome, String cpf) {
        this.nome = nome;
        this.cpf = cpf;
    }
*/

}
