package com.alessiojr.laboratory.model;

import com.alessiojr.laboratory.enums.OpcaoMarca;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            //@UniqueConstraint(name = "UK_Pessoa_cpf", columnNames = "cpf")
            @UniqueConstraint(name = "UK_Laboratorio_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a Laboratorio.")
public class Laboratorio implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated Laboratorio ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of Laboratory")
    @Column(length = 128)
    private String lab;
    
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Marca")
    private OpcaoMarca marca;
    
    @NotEmpty
    @NotBlank
    @Column(length = 128)
    @ApiModelProperty(notes = "modelo")
    private String modelo;    
    
    @ApiModelProperty(notes = "Numero de maquinas no laboratorio  ")
    private int numeroM;
    
    
        
    @Column(name="Data", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data")
    private Date dtUpdate;

    
    public Laboratorio() {
    }

    public Laboratorio(long id, String lab, OpcaoMarca marca, String modelo, Date dtUpdate, int numeroM) {
        this.id = id;
        this.numeroM = numeroM;
        this.lab = lab;
        this.marca = marca;
        this.modelo = modelo;
        this.dtUpdate = dtUpdate;
    }


}