package com.alessiojr.laboratory.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.serializer.PessoaTesteSerializer;
import com.alessiojr.laboratory.enums.OpcaoTipoProblema;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;

@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_id", columnNames = "id")
        })
@ApiModel(description = "Classe representa uma entidade problema")
public class ProblemaTecnico implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    //auto incremento
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "Id do problema")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =50)
    @ApiModelProperty(notes = "Título do problema")
    @Column(length = 50)
    private String titulo;

    @NotEmpty
    @NotBlank
    @Size(min = 10, max =200)
    @ApiModelProperty(notes = "Descrição do problema")
    @Column(length = 200)
    private String descricao;    
    
    //@DateTimeFormat(pattern = "dd/MM/yyyy")
   // @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data em que foi realizado a reclamação do problema")
    private LocalDate data;

    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo do problema")
    private OpcaoTipoProblema tipoProblema;
  
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
    @JsonSerialize(using = PessoaTesteSerializer.class)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(
        foreignKey = @ForeignKey(name = "FK_ProblemaTecnico_Autor"),
        name = "autor_id",
        nullable = true,
        referencedColumnName = "id")
    private PessoaTeste autor;

    
    //@OneToMany(mappedBy = "autor")
    // private List<Pessoa> problemasTecnicos;
        
    public ProblemaTecnico() {
    }

    public ProblemaTecnico(long id, String titulo) {
        this.id = id;
        this.titulo = titulo;
    }

    public ProblemaTecnico(String titulo, String descricao, LocalDate data, OpcaoTipoProblema tipoProblema, String foto) {
        this.titulo = titulo;
        this.descricao = descricao;
        this.data = data;
        this.tipoProblema = tipoProblema;
    }
}
