package com.alessiojr.laboratory.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.enums.OpcaoTitulacao;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import java.time.LocalDateTime;
import java.time.LocalDate;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table
@ApiModel(description = "Class representing a professor.")
public class Professor implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated suject ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Nome do professor")
    @Column(length = 128)
    private String nome;

    @Size(min = 2, max =128)
    @ApiModelProperty(notes = "Escola")
    @Column(length = 7)
    private String escola;

    @Size(min = 2, max =128)
    @ApiModelProperty(notes = "Area do Conhecimento")
    @Column(length = 7)
    private String area;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Titulação")
    private OpcaoTitulacao titulacao;
            
    @ApiModelProperty(notes = "Full Date")
    //@Column(name = "data_registro")
    @Column(name="dtNasc", columnDefinition = "date")
    private LocalDate dtnasc;
//    @Column(name="dtNasc", columnDefinition = "date")
//    @DateTimeFormat(pattern = "dd/MM/yyyy")
//    @Temporal(TemporalType.DATE)
//    @ApiModelProperty(notes = "Data de Nascimento")
//    private Date dtNasc;
    
   @ManyToOne(fetch = FetchType.LAZY)
    private Professor universidade;
    
    //@OneToMany(mappedBy = "mae")
    //private List<Aluno> filhos;
    
     @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
      
    public Professor() {
    }

    public Professor(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public Professor(String nome, String escola) {
        this.nome = nome;
        this.escola = escola;
    }
    
}
