package com.alessiojr.laboratory.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.serializer.PessoaTesteSerializer;
import com.alessiojr.laboratory.enums.OpcaoSistemaOperacional;
import com.alessiojr.laboratory.enums.OpcaoTipo;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table
@ApiModel(description = "Class representing a software.")
public class Software implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated software ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of Software")
    @Column(length = 128)
    private String nome;
    
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Sistema Operacional")
    private OpcaoSistemaOperacional sistemaoperacional;
    
    @NotEmpty
    @NotBlank
    @Column(length = 128)
    @ApiModelProperty(notes = "Versão")
    private String versao;    
    
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Tipo")
    private OpcaoTipo tipo;

    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Disciplina")
    @Column(length = 128)
    private String disciplina;
    
    @ApiModelProperty(notes = "data")
    private LocalDate data;
    
    @JsonSerialize(using = PessoaTesteSerializer.class)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(
        foreignKey = @ForeignKey(name = "FK_Software_PessoaT"),
        name = "pessoat_id",
        nullable = true,
        referencedColumnName = "id")
    private PessoaTeste pessoat;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;

    
    public Software() {
    }

    public Software(long id, String nome, String versao, String disciplina, LocalDate data) {
        this.id = id;
        this.nome = nome;
        this.versao = versao;
        this.disciplina = disciplina;
        this.data = data;
    }
/*
    public Software(String nome, String cpf) {
        this.nome = nome;
        this.cpf = cpf;
    }
*/

}
