package com.alessiojr.laboratory.resource;

import com.alessiojr.laboratory.model.Computador;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.alessiojr.laboratory.service.ComputadorService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestParam;

@CrossOrigin
@RestController
@RequestMapping("/laboratory/computadores")
@Api(value = "/laboratory/computadores", tags = "Computador Controler",  description = "Operações sobre a Entidade Computador")
public class ComputadorController {
      private static final Logger log = LoggerFactory.getLogger(ComputadorController.class);
    
    @Autowired
    private ComputadorService computadores;

    //GET - Read all resource
    
    @ApiOperation(value = "Ver uma lista de computadores disponíveis", response = List.class)
    @GetMapping(params = {"modelo", "pagina"})
    public Page<Computador> findAll(
            @RequestParam String modelo,
            @RequestParam Integer pagina) {
        return this.computadores.findByModeloContaining(modelo, pagina);
    }
    
    //GET - Read a resource
     @ApiOperation(value = "Procurar computador por id", response = List.class)
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Computador> findById(@PathVariable Long id){
       Optional<Computador> computador = computadores.findById(id);
        log.info("Entrou em  /laboratory/computadores/" + id);
       if (!computador.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(computador.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.computadores.deleteById(id);
    }
    
    //PUT - Update an existing resource
       //PUT - Update an existing resource
    @ApiOperation(value = "Editar um computador", response = List.class)
    @PutMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Computador> update(@RequestBody @Valid Computador computador, @PathVariable Long id) {
        Optional<Computador> optional = computadores.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Computador existente = optional.get();
        return ResponseEntity.ok(computadores.update(computador, existente));
    }
        
      
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Criar um Computador", response = Computador.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe um computador com o mesmo modelo"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    
     public ResponseEntity<Computador>  create(
        @ApiParam(value = "Criar um computador com modelo, marca, id, cor") @Valid @RequestBody Computador computador) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(computadores.insert(computador));
	}
}
