package com.alessiojr.laboratory.resource;

import com.alessiojr.laboratory.model.Laboratorio;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alessiojr.laboratory.repository.LaboratorioRepository;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;

@CrossOrigin
@RestController
@RequestMapping("/laboratorios")
@Api(value = "/laboratorios", tags = "Laboratorio Controler",  description = "Operações sobre a Entidade Laboratorios")
public class LaboratorioController {
    
    @Autowired
    private LaboratorioRepository laboratorioRepository;

    //GET - Read all resource
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping("/")
    public List<Laboratorio> findAll(){
       return laboratorioRepository.findAll();
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    public ResponseEntity<Laboratorio> findById(@PathVariable Long id){
       Optional<Laboratorio> laboratorio = laboratorioRepository.findById(id);
       
       if (!laboratorio.isPresent()){
          return ResponseEntity.notFound().build();
       }
       return ResponseEntity.ok(laboratorio.get());
       
    }
    
    //GET - Read a resource
    @DeleteMapping("/{id}")
    public void delete(@PathVariable Long id){
        this.laboratorioRepository.deleteById(id);
    }
    
    //PUT - Update an existing resource
    @PutMapping(value = "/{id}")
    public ResponseEntity update(@PathVariable Long id, @RequestBody Laboratorio laboratorio){
        
        Optional<Laboratorio> laboratorioExistente = laboratorioRepository.findById(id);
	
        if (laboratorioExistente.isPresent()) {
            Laboratorio lab = laboratorioExistente.get();
            lab.setId(laboratorio.getId());
            lab.setLab(laboratorio.getLab());
            lab.setNumeroM(laboratorio.getNumeroM());
            lab.setModelo(laboratorio.getModelo());
            lab.setMarca(laboratorio.getMarca());
            lab.setDtUpdate(laboratorio.getDtUpdate());
            laboratorioRepository.save(lab);
            return ResponseEntity.ok("Product updated successfully");
        }else{
            return ResponseEntity.notFound().build();
        }	
        
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Laboratorio", response = Laboratorio.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma laboratorio para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public Laboratorio create(
            @ApiParam(value = "Laboratorios com elementos Nome e Marca") @Valid @RequestBody Laboratorio laboratorio) {
        
        Optional<Laboratorio> laboratorioExistente = laboratorioRepository
            .findByLab(laboratorio.getLab());
	
        if (laboratorioExistente.isPresent()) {
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST,
                "Já existe um laboratorio para este com a mesma descrição");
        }
		
		return laboratorioRepository.save(laboratorio);
	}
}