package com.alessiojr.laboratory.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.model.Computador;
import com.alessiojr.laboratory.repository.ComputadorRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class ComputadorService {

    @Autowired
    private ComputadorRepository<Computador> computadores;

    @Autowired
    private CurrentUserService currentUser;

   public Page<Computador> findByModeloContaining(String modelo, Integer pagina) {
       
        return this.computadores.findByModeloContaining(modelo, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "modelo")));
    }

    public Page<Computador> findAll(Integer pagina) {
        return this.computadores.findAll(PageRequest.of(pagina, 10));
    }

    public Computador insert(Computador computador) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                computador.setStatus(Status.PUBLICO);
            } else {
                computador.setStatus(Status.PRIVADO);
            }
        }

        return this.computadores.save(computador);
    }

    public Optional<Computador> findById(Long id) {
        Optional<Computador> computador = computadores.findById(id);
        if (!computador.isPresent()) {
            return Optional.empty();
        }
        return computador;
    }

    public Computador update(Computador computador, Computador existente) {
        BeanUtils.copyProperties(computador, existente, "idComputador");
        return this.computadores.save(computador);
    }

    public void deleteById(Long id) {
        Optional<Computador> c = this.computadores.findById(id);
        if (c.isPresent()) {
            c.get().setStatus(Status.INATIVO);
            this.computadores.save(c.get());
        }
    }

}
