package com.alessiojr.laboratory.service;

import com.alessiojr.laboratory.service.*;
import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.model.Hardware;
import com.alessiojr.laboratory.repository.HardwareRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class HardwareService {

    @Autowired
    private HardwareRepository<Hardware> hardwares;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Hardware> findByModeloContaining(String modelo, Integer pagina) {
       
        return this.hardwares.findByModeloContaining(modelo, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "modelo")));
    }

    public Page<Hardware> findAll(Integer pagina) {
        return this.hardwares.findAll(PageRequest.of(pagina, 10));
    }

    public Hardware insert(Hardware parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.hardwares.save(parceiro);
    }

    public Optional<Hardware> findById(Long id) {
        Optional<Hardware> parceiro = hardwares.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public Hardware update(Hardware parceiro, Hardware existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.hardwares.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<Hardware> op = this.hardwares.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.hardwares.save(op.get());
        }
    }

}
