package com.alessiojr.laboratory.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.laboratory.model.Instalacao;
import com.alessiojr.laboratory.repository.InstalacaoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class InstalacoesService {

    @Autowired
    private InstalacaoRepository<Instalacao> instalacoes;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Instalacao> findBySoftwareContaining(String software, Integer pagina) {
       
        return this.instalacoes.findBySoftwareContaining(software, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "software")));
    }

    public Page<Instalacao> findAll(Integer pagina) {
        return this.instalacoes.findAll(PageRequest.of(pagina, 10));
    }

    public Instalacao insert(Instalacao s) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                s.setStatus(Status.PUBLICO);
            } else {
                s.setStatus(Status.PRIVADO);
            }
        }

        return this.instalacoes.save(s);
    }

    public Optional<Instalacao> findById(Long id) {
        Optional<Instalacao> s = instalacoes.findById(id);
        if (!s.isPresent()) {
            return Optional.empty();
        }
        return s;
    }

    public Instalacao update(Instalacao s, Instalacao existente) {
        BeanUtils.copyProperties(s, existente, "idInstalacao");
        return this.instalacoes.save(s);
    }

    public void deleteById(Long id) {
        Optional<Instalacao> op = this.instalacoes.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.instalacoes.save(op.get());
        }
    }

}
