package com.alessiojr.laboratory.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.model.ProblemaTecnico;
import com.alessiojr.laboratory.repository.ProblemaTecnicoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class ProblemaTecnicoService {

    @Autowired
    private ProblemaTecnicoRepository<ProblemaTecnico> problemas;

    @Autowired
    private CurrentUserService currentUser;

    public Page<ProblemaTecnico> findByTituloContaining(String titulo, Integer pagina) {
       
        return this.problemas.findByTituloContaining(titulo, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "titulo")));
    }

    public Page<ProblemaTecnico> findAll(Integer pagina) {
        return this.problemas.findAll(PageRequest.of(pagina, 10));
    }

    public ProblemaTecnico insert(ProblemaTecnico problema) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                problema.setStatus(Status.PUBLICO);
            } else {
                problema.setStatus(Status.PRIVADO);
            }
        }

        return this.problemas.save(problema);
    }

    public Optional<ProblemaTecnico> findById(Long id) {
        Optional<ProblemaTecnico> problema = problemas.findById(id);
        if (!problema.isPresent()) {
            return Optional.empty();
        }
        return problema;
    }

    public ProblemaTecnico update(ProblemaTecnico problema, ProblemaTecnico existente) {
        BeanUtils.copyProperties(problema, existente, "idProblema");
        return this.problemas.save(problema);
    }

    public void deleteById(Long id) {
        Optional<ProblemaTecnico> op = this.problemas.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.problemas.save(op.get());
        }
    }

}
