package com.alessiojr.laboratory.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.laboratory.model.Professor;
import com.alessiojr.laboratory.repository.ProfessorRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import java.time.LocalDate;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class ProfessoresService {

    @Autowired
    private ProfessorRepository<Professor> professores;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Professor> findByNomeContaining(String nome, Integer pagina) {
       
        return this.professores.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Professor> findAll(Integer pagina) {
        return this.professores.findAll(PageRequest.of(pagina, 10));
    }

    public Professor insert(Professor s) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                s.setStatus(Status.PUBLICO);
            } else {
                s.setStatus(Status.PRIVADO);
            }
        }

        return this.professores.save(s);
    }

    public Optional<Professor> findById(Long id) {
        Optional<Professor> s = professores.findById(id);
        if (!s.isPresent()) {
            return Optional.empty();
        }
        return s;
    }

    public Professor update(Professor s, Professor existente) {
        BeanUtils.copyProperties(s, existente, "idProfessor");
        return this.professores.save(s);
    }

    public void deleteById(Long id) {
        Optional<Professor> op = this.professores.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.professores.save(op.get());
        }
    }

}
