package com.alessiojr.laboratory.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.laboratory.model.Software;
import com.alessiojr.laboratory.repository.SoftwareRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class SoftwaresService {

    @Autowired
    private SoftwareRepository<Software> softwares;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Software> findByNomeContaining(String nome, Integer pagina) {
       
        return this.softwares.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Software> findAll(Integer pagina) {
        return this.softwares.findAll(PageRequest.of(pagina, 10));
    }

    public Software insert(Software s) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                s.setStatus(Status.PUBLICO);
            } else {
                s.setStatus(Status.PRIVADO);
            }
        }

        return this.softwares.save(s);
    }

    public Optional<Software> findById(Long id) {
        Optional<Software> s = softwares.findById(id);
        if (!s.isPresent()) {
            return Optional.empty();
        }
        return s;
    }

    public Software update(Software s, Software existente) {
        BeanUtils.copyProperties(s, existente, "idSoftware");
        return this.softwares.save(s);
    }

    public void deleteById(Long id) {
        Optional<Software> op = this.softwares.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.softwares.save(op.get());
        }
    }

}
