package com.alessiojr.location.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.enums.OpcaoEstado;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@ApiModel(description = "Class representando endereço")
public class Endereso implements Serializable {
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "ID de endereço gerado pelo banco")
    private Long id;
    
    //@NotBlank
    @Size(max = 40)
    @ApiModelProperty(notes = "Nome do proprietário")
    private String proprietario;
    
    @Column(name = "dtPosse", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de Posse")
    private Date dtPosse;
    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Sigla do estado")
    private OpcaoEstado uf;
    
    @NotEmpty
    @NotBlank
    @Size(min = 4, max = 60)
    @ApiModelProperty(notes = "Nome da cidade")
    private String cidade;
    
    //@NotEmpty
    @ApiModelProperty(notes = "Nome do bairro")
    private String bairro;
    
    @NotEmpty
    @ApiModelProperty(notes = "CEP")
    private String cep;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
    public Endereso(){
    }
    
    public Endereso(Long id, String proprietario, Date dtPosse, String cidade, String bairro, String cep){
        this.id = id;
        this.proprietario = proprietario;
        this.dtPosse = dtPosse;
        this.cidade = cidade;
        this.bairro = bairro;
        this.cep = cep;
    }
}