package com.alessiojr.location.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.enums.OpcaoTipoEstado;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Table(name = "Estado",
        uniqueConstraints = {
            @UniqueConstraint(name = "UK_Estado_nome", columnNames = "nome"),
            @UniqueConstraint(name = "UK_Estado_uf", columnNames = "uf")}
)
@Getter
@Setter
@EqualsAndHashCode(onlyExplicitlyIncluded = true)
@ApiModel(description = "Class representing a UF.")
public class Estado implements Serializable {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated suject ID")
    @EqualsAndHashCode.Include
    private Long idEstado;
    
    @NotEmpty
    @NotBlank
    @NotNull
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Nome do estado")
    @Column(length = 128)
    private String nome;
    
    @NotNull
    @Column(length=2)
    @Size(min = 2, max =2)
    @NotEmpty
    @ApiModelProperty(notes = "Sigla do Estado")
    private String uf;

    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Regiao")
    private OpcaoTipoEstado regiao;
            
    @Column(name="data", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de Criação")
    private Date data;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;    

    public Estado() {
    }

    public Estado(long idEstado, String nome) {
        this.idEstado = idEstado;
        this.nome = nome;
    }

    public Estado(String nome, String uf) {
        this.nome = nome;
        this.uf = uf;
    }
    public Estado(String nome, String sigla, Date data) {
        this.nome = nome;
        this.uf = sigla;
        this.data= data;
    }

}

