package com.alessiojr.location.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.enums.OpcaoLingua;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

@Entity
@Getter @Setter
@Table
@ApiModel(description = "Class representing a suject.")
public class Pais implements Serializable {

    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated suject ID")
    private Long id;
    
    @NotEmpty
    @NotBlank
    @Size(min = 3, max =128)
    @ApiModelProperty(notes = "Name of suject")
    @Column(length = 128)
    private String nome;

    
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "Nivel de Ensino")
    private OpcaoLingua lingua;
    
    @Size(min = 2, max =2)
    @ApiModelProperty(notes = "Course description")
    @Column(length = 2)
    private String sigla;
    
    @Column(name="dtCriacao", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de criação")
    private Date dtCriacao;
    
     @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
        
        
    public Pais() {
    }

    public Pais(long id, String nome) {
        this.id = id;
        this.nome = nome;
    }

    public Pais(String nome, String sigla) {
        this.nome = nome;
        this.sigla = sigla;
    }

}