package com.alessiojr.location.model;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.enums.OpcaoUf;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
//import javax.validation.constraints.NotBlank;
//import javax.validation.constraints.Size;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;


@Entity
@Getter @Setter
@Table(
        uniqueConstraints = {
            //@UniqueConstraint(name = "UK_Pessoa_cpf", columnNames = "cpf")
            @UniqueConstraint(name = "UK_Sidade_id", columnNames = "id")
        })
@ApiModel(description = "Class representing a sidade.")

public class Sidade implements Serializable {
    
    @Id
    @Column(updatable = false, nullable = false)
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty(notes = "The database generated suject ID")
    private Long id;
   
    
    @NotBlank
    @Size(min = 3, max =60)//A cidade com o nome mais comprido do mundo é: Llanfairpwllgwyngyllgogerychwyrndrobwllllantysiliogogogoch (58 letras)
    @ApiModelProperty(notes = "Nome da cidade")
    @Column(length = 60)
    private String nome;
    
    @NotEmpty
    //@Min(value = 0)
    @ApiModelProperty(notes = "Populacão")
    private int populcao;

    
    @NotBlank
    @Size(min = 3, max =45)//O páis com o nome mais comprido do mundo é: Ilhas Menores Distantes dos Estados Unidos (43 letras)
    @ApiModelProperty(notes = "Nome do país")
    @Column(length = 45)
    private String nomePais;
    
    @ApiModelProperty(notes = "Latitude")
    @Column(length = 45)
    private String latitude;
    
    @ApiModelProperty(notes = "Longitude")
    @Column(length = 45)
    private String longitude;
        
    @Enumerated(EnumType.STRING)
    @ApiModelProperty(notes = "UF")
    private OpcaoUf uf;
            
    @Column(name="dtFundacao", columnDefinition = "date")
    @DateTimeFormat(pattern = "dd/MM/yyyy")
    @Temporal(TemporalType.DATE)
    @ApiModelProperty(notes = "Data de Fundação")
    private Date dtFundacao;
    
    @NotNull
    @Enumerated(EnumType.STRING)
    private Status status;
    
    
    public Sidade() {
    }


   public Sidade(String nome, int populcao, String nomePais, String latitude, String longitude) {
        this.nome = nome;
        this.populcao = populcao;
        this.nomePais = nomePais;
        this.latitude = latitude;
        this.longitude = longitude;
        
    }    
    
    
}