package com.alessiojr.location.resource;
import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.alessiojr.location.model.Endereso;
import com.alessiojr.location.service.EnderesosService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.RequestParam;


@CrossOrigin
@RestController
@RequestMapping("/location/endereso")
@Api(value = "/location/endereso", tags = "Endereso Controller",  description = "Operações sobre a Entidade Endereso")
public class EnderesoController {
    
    private static final Logger log = LoggerFactory.getLogger(EnderesoController.class);

    
    @Autowired
    private EnderesosService enderesos;

    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<Endereso> findAll(@RequestParam Integer pagina) {
        //return this.enderesos.findByProprietarioContaining(proprietario, pagina);
        return this.enderesos.findAll(pagina);
    }
    
      @GetMapping("/{id}")
    public ResponseEntity<Endereso> findById(@PathVariable Long id){
        log.info("Passei no /location/endereso" + id);
        Optional<Endereso> endereso = enderesos.findById(id);
       
        if (!endereso.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(endereso.get());
    }
    
    @DeleteMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /location/endereso" + id);
        Optional<Endereso> end = enderesos.findById(id);
        if (!end.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            enderesos.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
    //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Endereso> update(@RequestBody @Valid Endereso endereso, @PathVariable Long id) {
        Optional<Endereso> optional = enderesos.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Endereso existente = optional.get();
        return ResponseEntity.ok(enderesos.update(endereso, existente));
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Endereso", response = Endereso.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe um endereço com o mesmo CEP"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    
    
  public ResponseEntity<Endereso> create(
        @ApiParam(value = "Endereços com elementos Proprietario, Cidade, Bairro, Data de Posse, CEP") @Valid @RequestBody Endereso endereso) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(enderesos.insert(endereso));
	}
}
