package com.alessiojr.location.resource;

import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import com.alessiojr.location.model.Estado;
import com.alessiojr.location.service.EstadoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


@CrossOrigin
@RestController
@RequestMapping("/location/estado")
@Api(value = "/location/estado", tags = "Estado Controler",  description = "Operações sobre a Entidade Estado")
public class EstadoResource {
    
    private static final Logger log = LoggerFactory.getLogger(EstadoResource.class)
            ;
    @Autowired
    private EstadoService estados;
 
    //GET - Read all resource
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<Estado> findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.estados.findByNomeContaining(nome, pagina);
    }
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<Estado >findAll(
            @RequestParam Integer pagina) {
        return this.estados.findAll(pagina);
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Estado> findById(@PathVariable Long id){
        log.info("Passei no /location/estado" + id);
        Optional<Estado> estado = estados.findById(id);
       
        if (!estado.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(estado.get());
    }
    
    @DeleteMapping("/{id}")
//  @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /location/estado" + id);
        Optional<Estado> estado = estados.findById(id);
        if (!estado.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            estados.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
     //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Estado> update(@RequestBody @Valid Estado estado, @PathVariable Long id) {
        Optional<Estado> optional = estados.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Estado existente = optional.get();
        //estado.setStatus(existente.getStatus());
        return ResponseEntity.ok(estados.update(estado, existente));
    }
    
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Estado", response = Estado.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma estado para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public ResponseEntity<Estado>  create(
        @ApiParam(value = "Estados com elementos Nome e Curso") @Valid @RequestBody Estado estado) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(estados.insert(estado));
	}
}
