package com.alessiojr.location.resource;

import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import com.alessiojr.location.model.Pais;
import com.alessiojr.location.service.PaisService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.server.ResponseStatusException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


@CrossOrigin
@RestController
@RequestMapping("/location/pais")
@Api(value = "/location/pais", tags = "Pais Controler",  description = "Operações sobre a Entidade Pais")
public class PaisController {
    
    private static final Logger log = LoggerFactory.getLogger(PaisController.class)
            ;
    @Autowired
    private PaisService paises;
 
    //GET - Read all resource
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<Pais> findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.paises.findByNomeContaining(nome, pagina);
    }
    
    //GET - Read a resource
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Pais> findById(@PathVariable Long id){
        log.info("Passei no /location/pais" + id);
        Optional<Pais> pais = paises.findById(id);
       
        if (!pais.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(pais.get());
    }
    
    @DeleteMapping("/{id}")
//  @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /location/pais" + id);
        Optional<Pais> pais = paises.findById(id);
        if (!pais.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            paises.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
     //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Pais> update(@RequestBody @Valid Pais diciplina, @PathVariable Long id) {
        Optional<Pais> optional = paises.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Pais existente = optional.get();
        //diciplina.setStatus(existente.getStatus());
        return ResponseEntity.ok(paises.update(diciplina, existente));
    }
    
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Pais", response = Pais.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma pais para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    public ResponseEntity<Pais>  create(
        @ApiParam(value = "Paises com elementos Nome e Curso") @Valid @RequestBody Pais pais) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(paises.insert(pais));
	}
}


//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/