package com.alessiojr.location.resource;

import java.util.List;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import java.util.Optional;
import javax.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.alessiojr.location.model.Sidade;
import com.alessiojr.location.repository.SidadeRepository;
import com.alessiojr.location.service.SidadesService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.RequestParam;


@CrossOrigin
@RestController
@RequestMapping("/location/sidade")
@Api(value = "/location/sidade", tags = "Sidade Controler",  description = "Operações sobre a Entidade Sidade")
public class SidadeController {
    
        private static final Logger log = LoggerFactory.getLogger(SidadeController.class);

    
    @Autowired
    private SidadesService sidades;

     @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"nome", "pagina"})
    public Page<Sidade> findAll(
            @RequestParam String nome,
            @RequestParam Integer pagina) {
        return this.sidades.findByNomeContaining(nome, pagina);
    }
    
    @ApiOperation(value = "View a list of available products", response = List.class)
    @GetMapping(params = {"pagina"})
    public Page<Sidade >findAll(
            @RequestParam Integer pagina) {
        return this.sidades.findAll(pagina);
    }
    
      @GetMapping("/{id}")
    public ResponseEntity<Sidade> findById(@PathVariable Long id){
        log.info("Passei no /location/sidade" + id);
        Optional<Sidade> sidade = sidades.findById(id);
       
        if (!sidade.isPresent()){
           return ResponseEntity.notFound().build();
        }
        return ResponseEntity.ok(sidade.get());
    }
    
    @DeleteMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity delete(@PathVariable Long id) {
        log.info("Passei no Delete /location/sidade" + id);
        Optional<Sidade> s = sidades.findById(id);
        if (!s.isPresent()) {
            return ResponseEntity.notFound().build();
        }

        try {
            sidades.deleteById(id);
        } catch (Exception e) {
            System.out.println(e.getClass().getName() + ": " + e.getMessage());
            return ResponseEntity.badRequest().build();
        }

        return ResponseEntity.noContent().build();
    }
    
    //PUT - Update an existing resource
    @PutMapping("/{id}")
//    @PreAuthorize("hasAuthority('ROLE_ADMINISTRADOR')")
    public ResponseEntity<Sidade> update(@RequestBody @Valid Sidade sidade, @PathVariable Long id) {
        Optional<Sidade> optional = sidades.findById(id);
        if (!optional.isPresent()) {
            return ResponseEntity.notFound().build();
        }
        Sidade existente = optional.get();
        return ResponseEntity.ok(sidades.update(sidade, existente));
    }
        
    @PostMapping("/")
    @ResponseStatus(HttpStatus.CREATED)
    @ApiOperation(value = "Create a Single Sidade", response = Sidade.class)
    @ApiResponses(value = {
        @ApiResponse(code = 201, message = "Successfully Created"),
        @ApiResponse(code = 400, message = "Já existe uma pessoa para este com a mesma descrição"),
        @ApiResponse(code = 401, message = "You are not authorized to view the resource"),
        @ApiResponse(code = 403, message = "Accessing the resource you were trying to reach is forbidden"),
        @ApiResponse(code = 404, message = "The resource you were trying to reach is not found")
    })
    
    
  public ResponseEntity<Sidade>  create(
        @ApiParam(value = "Softwares com elementos Nome, Versão, Disciplina, Data") @Valid @RequestBody Sidade sidade) {
        return ResponseEntity
                .status(HttpStatus.CREATED)
                .body(sidades.insert(sidade));
	}
}


//200 - SUCESS
//404 - RESOURCE NOT FOUND
//400 - BAD REQUEST
//201 - CREATED
//401 - UNAUTHORIZED
//415 - UNSUPPORTED TYPE - Representation not supported for the resource
//500 - SERVER ERROR

// https://github.com/swagger-api/swagger-core/wiki/annotations
// https://github.com/swagger-api/swagger-core/wiki/Swagger-2.X---Annotations
//https://dzone.com/articles/spring-boot-2-restful-api-documentation-with-swagg

// Put Vs Post: https://restfulapi.net/rest-put-vs-post/
/*
GET 	/device-management/devices : Get all devices
POST 	/device-management/devices : Create a new device

GET 	/device-management/devices/{id} : Get the device information identified by "id"
PUT 	/device-management/devices/{id} : Update the device information identified by "id"
DELETE	/device-management/devices/{id} : Delete device by "id"*/