package com.alessiojr.location.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.model.Endereso;
import com.alessiojr.location.repository.EnderesoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class EnderesosService {

    @Autowired
    private EnderesoRepository<Endereso> enderesos;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Endereso> findByProprietarioContaining(String proprietario, Integer pagina) {
       
        return this.enderesos.findByProprietarioContaining(proprietario, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "proprietario")));
    }

    public Page<Endereso> findAll(Integer pagina) {
        return this.enderesos.findAll(PageRequest.of(pagina, 10));
    }

    public Endereso insert(Endereso e) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                e.setStatus(Status.PUBLICO);
            } else {
                e.setStatus(Status.PRIVADO);
            }
        }

        return this.enderesos.save(e);
    }

    public Optional<Endereso> findById(Long id) {
        Optional<Endereso> e = enderesos.findById(id);
        if (!e.isPresent()) {
            return Optional.empty();
        }
        return e;
    }

    public Endereso update(Endereso e, Endereso existente) {
        BeanUtils.copyProperties(e, existente, "idEndereso");
        return this.enderesos.save(e);
    }

    public void deleteById(Long id) {
        Optional<Endereso> op = this.enderesos.findById(id);
        if (op.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.enderesos.deleteById(id);
                } else {
                     op.get().setStatus(Status.INATIVO);
                     this.enderesos.save(op.get());
                }
            }
        }
    }

}
