package com.alessiojr.location.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.model.Estado;
import com.alessiojr.location.repository.EstadoRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class EstadoService {

    @Autowired
    private EstadoRepository<Estado> estados;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Estado> findByNomeContaining(String nome, Integer pagina) {
       
        return this.estados.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Estado> findAll(Integer pagina) {
        return this.estados.findAll(PageRequest.of(pagina, 10));
    }

    public Estado insert(Estado estado) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                estado.setStatus(Status.PUBLICO);
            } else {
                estado.setStatus(Status.PRIVADO);
            }
        }

        return this.estados.save(estado);
    }

     public Optional<Estado> findById(Long id) {
        Optional<Estado> estado = estados.findById(id);
        if (!estado.isPresent()) {
            return Optional.empty();
        }
        return estado;
    }


    public Estado update(Estado estado, Estado existente) {
        BeanUtils.copyProperties(estado, existente, "idEstado");
        return this.estados.save(estado);
    }

     public void deleteById(Long id) {
        Optional<Estado> op = this.estados.findById(id);
        if (op.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.estados.deleteById(id);
                } else {
                     op.get().setStatus(Status.INATIVO);
                     this.estados.save(op.get());
                }
            }
        }
    }

}
