package com.alessiojr.location.service;

import com.alessiojr.common.enums.Status;
import com.alessiojr.location.model.Pais;
import com.alessiojr.location.repository.PaisRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class PaisService {

    @Autowired
    private PaisRepository<Pais> paises;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Pais> findByNomeContaining(String nome, Integer pagina) {
       
        return this.paises.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Pais> findAll(Integer pagina) {
        return this.paises.findAll(PageRequest.of(pagina, 10));
    }

    public Pais insert(Pais disciplina) {

       Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                disciplina.setStatus(Status.PUBLICO);
            } else {
                disciplina.setStatus(Status.PRIVADO);
            }
        }

        return this.paises.save(disciplina);
    }

     public Optional<Pais> findById(Long id) {
        Optional<Pais> disciplina = paises.findById(id);
        if (!disciplina.isPresent()) {
            return Optional.empty();
        }
        return disciplina;
    }


    public Pais update(Pais disciplina, Pais existente) {
        BeanUtils.copyProperties(disciplina, existente, "idPais");
        return this.paises.save(disciplina);
    }

     public void deleteById(Long id) {
        Optional<Pais> op = this.paises.findById(id);
        if (op.isPresent()) {
            Optional<Usuario> criador = this.currentUser.getCurrentUser();
            if (criador.isPresent()) {
                if (criador.get().getPermissoes().stream()
                        .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                    this.paises.deleteById(id);
                } else {
                     op.get().setStatus(Status.INATIVO);
                     this.paises.save(op.get());
                }
            }
        }
    }

}
