package com.alessiojr.location.service;

import com.alessiojr.freeTests.service.*;
import com.alessiojr.common.enums.Status;
import com.alessiojr.location.model.Sidade;
import com.alessiojr.location.repository.SidadeRepository;
import com.alessiojr.freeTests.model.PessoaTeste;
import com.alessiojr.freeTests.repository.PessoaTesteRepository;
import com.alessiojr.security.enums.PermissionRoles;
import com.alessiojr.security.model.Usuario;
import com.alessiojr.security.service.CurrentUserService;
import java.util.Optional;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

@Service
public class SidadesService {

    @Autowired
    private SidadeRepository<Sidade> sidades;

    @Autowired
    private CurrentUserService currentUser;

    public Page<Sidade> findByNomeContaining(String nome, Integer pagina) {
       
        return this.sidades.findByNomeContaining(nome, PageRequest.of(pagina, 10, Sort.by(Sort.Direction.ASC, "nome")));
    }

    public Page<Sidade> findAll(Integer pagina) {
        return this.sidades.findAll(PageRequest.of(pagina, 10));
    }

    public Sidade insert(Sidade parceiro) {

        Optional<Usuario> criador = this.currentUser.getCurrentUser();
        if (criador.isPresent()) {
            if (criador.get().getPermissoes().stream()
                    .anyMatch(p -> p.getPermissao() == PermissionRoles.ROLE_ADMINISTRADOR)) {
                parceiro.setStatus(Status.PUBLICO);
            } else {
                parceiro.setStatus(Status.PRIVADO);
            }
        }

        return this.sidades.save(parceiro);
    }

    public Optional<Sidade> findById(Long id) {
        Optional<Sidade> parceiro = sidades.findById(id);
        if (!parceiro.isPresent()) {
            return Optional.empty();
        }
        return parceiro;
    }

    public Sidade update(Sidade parceiro, Sidade existente) {
        BeanUtils.copyProperties(parceiro, existente, "idParceiro");
        return this.sidades.save(parceiro);
    }

    public void deleteById(Long id) {
        Optional<Sidade> op = this.sidades.findById(id);
        if (op.isPresent()) {
            op.get().setStatus(Status.INATIVO);
            this.sidades.save(op.get());
        }
    }

}
