package com.alessiojr.security.model;

import com.alessiojr.account.model.Conta;
import com.alessiojr.account.serializer.ContaSerializer;
import com.alessiojr.security.model.Auditable;
import com.alessiojr.common.enums.Status;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import java.util.Set;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.ForeignKey;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.Email;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.OnDelete;
import org.hibernate.annotations.OnDeleteAction;

@Entity
@Table(
        name = "Usuario",
        uniqueConstraints = {
            @UniqueConstraint(columnNames = {"email"}, name = "UK_Usuario_email"),
            @UniqueConstraint(columnNames = {"login"}, name = "UK_Usuario_login")
        })
@Inheritance(strategy = InheritanceType.JOINED)
@Getter
@Setter
@EqualsAndHashCode(callSuper = true, onlyExplicitlyIncluded = true)
public class Usuario extends Auditable{

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @EqualsAndHashCode.Include
    protected Long idUsuario;

    @NotNull
    @NotEmpty
    @Size(min = 3, max = 128, message = "Digite um Nome Válido")
    @Column(length = 128)
    protected String nome;

    @NotNull
    @NotEmpty
    @Column(length=64)
    protected String login;

    @NotNull
    @NotEmpty
    @Column(length=128)
    @Email(message = "Email should be valid")
    protected String email;

    @NotNull
    @NotEmpty
    @Size(min = 3)
    protected String senha;
    
    protected String urlFoto;

    @NotNull
    @Enumerated(EnumType.STRING)
    protected Status status;

    @ManyToMany(fetch = FetchType.EAGER)
    @OnDelete(action = OnDeleteAction.CASCADE)
    @JoinTable(name = "Usuario_has_Permissoes",
            joinColumns = @JoinColumn(name = "Usuario_idUsuario", foreignKey = @ForeignKey(name = "fk_Usuario_has_Permissoes_Usuario")),
            inverseJoinColumns = @JoinColumn(name = "Permissao_idPermissao", foreignKey = @ForeignKey(name = "fk_Usuario_has_Permissoes_Permissao")))
    protected Set<Permission> permissoes;

}
