package com.alessiojr.security.repository;


import com.alessiojr.security.model.Usuario;
import com.alessiojr.common.enums.Status;
import java.util.Optional;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.transaction.annotation.Transactional;

@Transactional
public interface UsuarioRepository<T extends Usuario> extends JpaRepository<Usuario, Long> {

    @Query("SELECT u FROM Usuario u WHERE (u.login = :login OR u.email = :login) AND u.status = 'ATIVO'")
    public Optional<Usuario> doLogin(String login);

    public Optional<T> findByLogin(String login);

    public Optional<T> findByEmail(String email);

    @Query(value = "SELECT u FROM Usuario u WHERE u.nome LIKE CONCAT('%', :nome, '%')",
           countQuery = "SELECT COUNT(u) FROM Usuario u WHERE u.nome LIKE CONCAT('%', :nome, '%')")
    public Page<T> findByNome(String nome, Pageable pageable);

    @Query(value = "SELECT u FROM Usuario u WHERE u.nome LIKE CONCAT('%', :nome, '%') AND "
            + "u.status = :status",
            countQuery = "SELECT COUNT(u) FROM Usuario u WHERE u.nome LIKE CONCAT('%', :nome, '%') AND "
            + "u.status = :status")
    public Page<T> findByNomeAndStatus(String nome, Status status, Pageable pageable);

}
